Documentation
¶
Index ¶
Constants ¶
const (
SuccessMsg string = "successfully provisioned"
)
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type ConfigOption ¶
type ConfigOption func(*Options)
ConfigOption wraps a function that sets a value in the options struct
func WithSecretClient ¶
func WithSecretClient(secretClient secrets.SecretClient) ConfigOption
WithSecretClient can be used to pass in a KeyVault SecretClient
type KubeParent ¶
type KubeParent struct {
Key types.NamespacedName
Target client.Object
}
type Options ¶
type Options struct {
SecretClient secrets.SecretClient
}
Options contains the inputs available for passing to Ensure optionally
Directories
¶
| Path | Synopsis |
|---|---|
|
apim
|
|
|
azuresql
|
|
|
Package config manages loading configuration from environment and command-line params
|
Package config manages loading configuration from environment and command-line params |
|
psql
|
|
Click to show internal directories.
Click to hide internal directories.