Documentation
¶
Overview ¶
Code generated by azure-service-operator-codegen. DO NOT EDIT. Copyright (c) Microsoft Corporation. Licensed under the MIT license.
Code generated by azure-service-operator-codegen. DO NOT EDIT. Copyright (c) Microsoft Corporation. Licensed under the MIT license.
Code generated by azure-service-operator-codegen. DO NOT EDIT. Copyright (c) Microsoft Corporation. Licensed under the MIT license.
Code generated by azure-service-operator-codegen. DO NOT EDIT. Copyright (c) Microsoft Corporation. Licensed under the MIT license.
Code generated by azure-service-operator-codegen. DO NOT EDIT. Copyright (c) Microsoft Corporation. Licensed under the MIT license.
Code generated by azure-service-operator-codegen. DO NOT EDIT. Copyright (c) Microsoft Corporation. Licensed under the MIT license.
Index ¶
- Constants
- type ErrorAdditionalInfo_STATUS
- type ErrorDetail_STATUS
- type ErrorDetail_STATUS_Unrolled
- type FleetHubProfile
- type FleetHubProfile_STATUS
- type FleetMemberProperties
- type FleetMemberProperties_STATUS
- type FleetMemberProvisioningState_STATUS
- type FleetProperties
- type FleetProperties_STATUS
- type FleetProvisioningState_STATUS
- type Fleet_STATUS
- type Fleet_Spec
- type FleetsMember_STATUS
- type FleetsMember_Spec
- type FleetsUpdateRun_STATUS
- type FleetsUpdateRun_Spec
- type ManagedClusterUpdate
- type ManagedClusterUpdate_STATUS
- type ManagedClusterUpgradeSpec
- type ManagedClusterUpgradeSpec_STATUS
- type ManagedClusterUpgradeType
- type ManagedClusterUpgradeType_STATUS
- type MemberUpdateStatus_STATUS
- type SystemData_CreatedByType_STATUS
- type SystemData_LastModifiedByType_STATUS
- type SystemData_STATUS
- type UpdateGroup
- type UpdateGroupStatus_STATUS
- type UpdateGroup_STATUS
- type UpdateRunProperties
- type UpdateRunProperties_STATUS
- type UpdateRunProvisioningState_STATUS
- type UpdateRunStatus_STATUS
- type UpdateRunStrategy
- type UpdateRunStrategy_STATUS
- type UpdateStage
- type UpdateStageStatus_STATUS
- type UpdateStage_STATUS
- type UpdateState_STATUS
- type UpdateStatus_STATUS
- type WaitStatus_STATUS
Constants ¶
const ( FleetProvisioningState_STATUS_Canceled = FleetProvisioningState_STATUS("Canceled") FleetProvisioningState_STATUS_Creating = FleetProvisioningState_STATUS("Creating") FleetProvisioningState_STATUS_Deleting = FleetProvisioningState_STATUS("Deleting") FleetProvisioningState_STATUS_Failed = FleetProvisioningState_STATUS("Failed") FleetProvisioningState_STATUS_Succeeded = FleetProvisioningState_STATUS("Succeeded") FleetProvisioningState_STATUS_Updating = FleetProvisioningState_STATUS("Updating") )
const ( SystemData_CreatedByType_STATUS_Application = SystemData_CreatedByType_STATUS("Application") SystemData_CreatedByType_STATUS_Key = SystemData_CreatedByType_STATUS("Key") SystemData_CreatedByType_STATUS_ManagedIdentity = SystemData_CreatedByType_STATUS("ManagedIdentity") SystemData_CreatedByType_STATUS_User = SystemData_CreatedByType_STATUS("User") )
const ( SystemData_LastModifiedByType_STATUS_Application = SystemData_LastModifiedByType_STATUS("Application") SystemData_LastModifiedByType_STATUS_Key = SystemData_LastModifiedByType_STATUS("Key") SystemData_LastModifiedByType_STATUS_ManagedIdentity = SystemData_LastModifiedByType_STATUS("ManagedIdentity") SystemData_LastModifiedByType_STATUS_User = SystemData_LastModifiedByType_STATUS("User") )
const ( FleetMemberProvisioningState_STATUS_Canceled = FleetMemberProvisioningState_STATUS("Canceled") FleetMemberProvisioningState_STATUS_Failed = FleetMemberProvisioningState_STATUS("Failed") FleetMemberProvisioningState_STATUS_Joining = FleetMemberProvisioningState_STATUS("Joining") FleetMemberProvisioningState_STATUS_Leaving = FleetMemberProvisioningState_STATUS("Leaving") FleetMemberProvisioningState_STATUS_Succeeded = FleetMemberProvisioningState_STATUS("Succeeded") FleetMemberProvisioningState_STATUS_Updating = FleetMemberProvisioningState_STATUS("Updating") )
const ( ManagedClusterUpgradeType_Full = ManagedClusterUpgradeType("Full") ManagedClusterUpgradeType_NodeImageOnly = ManagedClusterUpgradeType("NodeImageOnly") )
const ( UpdateRunProvisioningState_STATUS_Canceled = UpdateRunProvisioningState_STATUS("Canceled") UpdateRunProvisioningState_STATUS_Failed = UpdateRunProvisioningState_STATUS("Failed") UpdateRunProvisioningState_STATUS_Succeeded = UpdateRunProvisioningState_STATUS("Succeeded") )
const ( ManagedClusterUpgradeType_STATUS_Full = ManagedClusterUpgradeType_STATUS("Full") ManagedClusterUpgradeType_STATUS_NodeImageOnly = ManagedClusterUpgradeType_STATUS("NodeImageOnly") )
const ( UpdateState_STATUS_Completed = UpdateState_STATUS("Completed") UpdateState_STATUS_Failed = UpdateState_STATUS("Failed") UpdateState_STATUS_NotStarted = UpdateState_STATUS("NotStarted") UpdateState_STATUS_Running = UpdateState_STATUS("Running") UpdateState_STATUS_Stopped = UpdateState_STATUS("Stopped") UpdateState_STATUS_Stopping = UpdateState_STATUS("Stopping") )
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type ErrorAdditionalInfo_STATUS ¶
type ErrorAdditionalInfo_STATUS struct {
// Info: The additional info.
Info map[string]v1.JSON `json:"info"`
// Type: The additional info type.
Type *string `json:"type,omitempty"`
}
The resource management error additional info.
type ErrorDetail_STATUS ¶
type ErrorDetail_STATUS struct {
// AdditionalInfo: The error additional info.
AdditionalInfo []ErrorAdditionalInfo_STATUS `json:"additionalInfo"`
// Code: The error code.
Code *string `json:"code,omitempty"`
// Details: The error details.
Details []ErrorDetail_STATUS_Unrolled `json:"details"`
// Message: The error message.
Message *string `json:"message,omitempty"`
// Target: The error target.
Target *string `json:"target,omitempty"`
}
The error detail.
type ErrorDetail_STATUS_Unrolled ¶
type ErrorDetail_STATUS_Unrolled struct {
// AdditionalInfo: The error additional info.
AdditionalInfo []ErrorAdditionalInfo_STATUS `json:"additionalInfo"`
// Code: The error code.
Code *string `json:"code,omitempty"`
// Message: The error message.
Message *string `json:"message,omitempty"`
// Target: The error target.
Target *string `json:"target,omitempty"`
}
type FleetHubProfile ¶
type FleetHubProfile struct {
// DnsPrefix: DNS prefix used to create the FQDN for the Fleet hub.
DnsPrefix *string `json:"dnsPrefix,omitempty"`
}
The FleetHubProfile configures the fleet hub.
type FleetHubProfile_STATUS ¶
type FleetHubProfile_STATUS struct {
// DnsPrefix: DNS prefix used to create the FQDN for the Fleet hub.
DnsPrefix *string `json:"dnsPrefix,omitempty"`
// Fqdn: The FQDN of the Fleet hub.
Fqdn *string `json:"fqdn,omitempty"`
// KubernetesVersion: The Kubernetes version of the Fleet hub.
KubernetesVersion *string `json:"kubernetesVersion,omitempty"`
}
The FleetHubProfile configures the fleet hub.
type FleetMemberProperties ¶
type FleetMemberProperties struct {
ClusterResourceId *string `json:"clusterResourceId,omitempty"`
// Group: The group this member belongs to for multi-cluster update management.
Group *string `json:"group,omitempty"`
}
A member of the Fleet. It contains a reference to an existing Kubernetes cluster on Azure.
type FleetMemberProperties_STATUS ¶
type FleetMemberProperties_STATUS struct {
// ClusterResourceId: The ARM resource id of the cluster that joins the Fleet. Must be a valid Azure resource id. e.g.:
// '/subscriptions/{subscriptionId}/resourceGroups/{resourceGroupName}/providers/Microsoft.ContainerService/managedClusters/{clusterName}'.
ClusterResourceId *string `json:"clusterResourceId,omitempty"`
// Group: The group this member belongs to for multi-cluster update management.
Group *string `json:"group,omitempty"`
// ProvisioningState: The status of the last operation.
ProvisioningState *FleetMemberProvisioningState_STATUS `json:"provisioningState,omitempty"`
}
A member of the Fleet. It contains a reference to an existing Kubernetes cluster on Azure.
type FleetMemberProvisioningState_STATUS ¶
type FleetMemberProvisioningState_STATUS string
The provisioning state of the last accepted operation.
type FleetProperties ¶
type FleetProperties struct {
// HubProfile: The FleetHubProfile configures the Fleet's hub.
HubProfile *FleetHubProfile `json:"hubProfile,omitempty"`
}
Fleet properties.
type FleetProperties_STATUS ¶
type FleetProperties_STATUS struct {
// HubProfile: The FleetHubProfile configures the Fleet's hub.
HubProfile *FleetHubProfile_STATUS `json:"hubProfile,omitempty"`
// ProvisioningState: The status of the last operation.
ProvisioningState *FleetProvisioningState_STATUS `json:"provisioningState,omitempty"`
}
Fleet properties.
type FleetProvisioningState_STATUS ¶
type FleetProvisioningState_STATUS string
The provisioning state of the last accepted operation.
type Fleet_STATUS ¶
type Fleet_STATUS struct {
// ETag: If eTag is provided in the response body, it may also be provided as a header per the normal etag convention.
// Entity tags are used for comparing two or more entities from the same requested resource. HTTP/1.1 uses entity tags in
// the etag (section 14.19), If-Match (section 14.24), If-None-Match (section 14.26), and If-Range (section 14.27) header
// fields.
ETag *string `json:"eTag,omitempty"`
// Id: Fully qualified resource ID for the resource. Ex -
// /subscriptions/{subscriptionId}/resourceGroups/{resourceGroupName}/providers/{resourceProviderNamespace}/{resourceType}/{resourceName}
Id *string `json:"id,omitempty"`
// Location: The geo-location where the resource lives
Location *string `json:"location,omitempty"`
// Name: The name of the resource
Name *string `json:"name,omitempty"`
// Properties: The resource-specific properties for this resource.
Properties *FleetProperties_STATUS `json:"properties,omitempty"`
// SystemData: Azure Resource Manager metadata containing createdBy and modifiedBy information.
SystemData *SystemData_STATUS `json:"systemData,omitempty"`
// Tags: Resource tags.
Tags map[string]string `json:"tags"`
// Type: The type of the resource. E.g. "Microsoft.Compute/virtualMachines" or "Microsoft.Storage/storageAccounts"
Type *string `json:"type,omitempty"`
}
The Fleet resource.
type Fleet_Spec ¶
type Fleet_Spec struct {
// Location: The geo-location where the resource lives
Location *string `json:"location,omitempty"`
Name string `json:"name,omitempty"`
// Properties: The resource-specific properties for this resource.
Properties *FleetProperties `json:"properties,omitempty"`
// Tags: Resource tags.
Tags map[string]string `json:"tags"`
}
func (Fleet_Spec) GetAPIVersion ¶
func (fleet Fleet_Spec) GetAPIVersion() string
GetAPIVersion returns the ARM API version of the resource. This is always "2023-03-15-preview"
func (*Fleet_Spec) GetName ¶
func (fleet *Fleet_Spec) GetName() string
GetName returns the Name of the resource
func (*Fleet_Spec) GetType ¶
func (fleet *Fleet_Spec) GetType() string
GetType returns the ARM Type of the resource. This is always "Microsoft.ContainerService/fleets"
type FleetsMember_STATUS ¶
type FleetsMember_STATUS struct {
// ETag: If eTag is provided in the response body, it may also be provided as a header per the normal etag convention.
// Entity tags are used for comparing two or more entities from the same requested resource. HTTP/1.1 uses entity tags in
// the etag (section 14.19), If-Match (section 14.24), If-None-Match (section 14.26), and If-Range (section 14.27) header
// fields.
ETag *string `json:"eTag,omitempty"`
// Id: Fully qualified resource ID for the resource. Ex -
// /subscriptions/{subscriptionId}/resourceGroups/{resourceGroupName}/providers/{resourceProviderNamespace}/{resourceType}/{resourceName}
Id *string `json:"id,omitempty"`
// Name: The name of the resource
Name *string `json:"name,omitempty"`
// Properties: The resource-specific properties for this resource.
Properties *FleetMemberProperties_STATUS `json:"properties,omitempty"`
// SystemData: Azure Resource Manager metadata containing createdBy and modifiedBy information.
SystemData *SystemData_STATUS `json:"systemData,omitempty"`
// Type: The type of the resource. E.g. "Microsoft.Compute/virtualMachines" or "Microsoft.Storage/storageAccounts"
Type *string `json:"type,omitempty"`
}
type FleetsMember_Spec ¶
type FleetsMember_Spec struct {
Name string `json:"name,omitempty"`
// Properties: The resource-specific properties for this resource.
Properties *FleetMemberProperties `json:"properties,omitempty"`
}
func (FleetsMember_Spec) GetAPIVersion ¶
func (member FleetsMember_Spec) GetAPIVersion() string
GetAPIVersion returns the ARM API version of the resource. This is always "2023-03-15-preview"
func (*FleetsMember_Spec) GetName ¶
func (member *FleetsMember_Spec) GetName() string
GetName returns the Name of the resource
func (*FleetsMember_Spec) GetType ¶
func (member *FleetsMember_Spec) GetType() string
GetType returns the ARM Type of the resource. This is always "Microsoft.ContainerService/fleets/members"
type FleetsUpdateRun_STATUS ¶
type FleetsUpdateRun_STATUS struct {
// ETag: If eTag is provided in the response body, it may also be provided as a header per the normal etag convention.
// Entity tags are used for comparing two or more entities from the same requested resource. HTTP/1.1 uses entity tags in
// the etag (section 14.19), If-Match (section 14.24), If-None-Match (section 14.26), and If-Range (section 14.27) header
// fields.
ETag *string `json:"eTag,omitempty"`
// Id: Fully qualified resource ID for the resource. Ex -
// /subscriptions/{subscriptionId}/resourceGroups/{resourceGroupName}/providers/{resourceProviderNamespace}/{resourceType}/{resourceName}
Id *string `json:"id,omitempty"`
// Name: The name of the resource
Name *string `json:"name,omitempty"`
// Properties: The resource-specific properties for this resource.
Properties *UpdateRunProperties_STATUS `json:"properties,omitempty"`
// SystemData: Azure Resource Manager metadata containing createdBy and modifiedBy information.
SystemData *SystemData_STATUS `json:"systemData,omitempty"`
// Type: The type of the resource. E.g. "Microsoft.Compute/virtualMachines" or "Microsoft.Storage/storageAccounts"
Type *string `json:"type,omitempty"`
}
type FleetsUpdateRun_Spec ¶
type FleetsUpdateRun_Spec struct {
Name string `json:"name,omitempty"`
// Properties: The resource-specific properties for this resource.
Properties *UpdateRunProperties `json:"properties,omitempty"`
}
func (FleetsUpdateRun_Spec) GetAPIVersion ¶
func (updateRun FleetsUpdateRun_Spec) GetAPIVersion() string
GetAPIVersion returns the ARM API version of the resource. This is always "2023-03-15-preview"
func (*FleetsUpdateRun_Spec) GetName ¶
func (updateRun *FleetsUpdateRun_Spec) GetName() string
GetName returns the Name of the resource
func (*FleetsUpdateRun_Spec) GetType ¶
func (updateRun *FleetsUpdateRun_Spec) GetType() string
GetType returns the ARM Type of the resource. This is always "Microsoft.ContainerService/fleets/updateRuns"
type ManagedClusterUpdate ¶
type ManagedClusterUpdate struct {
// Upgrade: The upgrade to apply to the ManagedClusters.
Upgrade *ManagedClusterUpgradeSpec `json:"upgrade,omitempty"`
}
The update to be applied to the ManagedClusters.
type ManagedClusterUpdate_STATUS ¶
type ManagedClusterUpdate_STATUS struct {
// Upgrade: The upgrade to apply to the ManagedClusters.
Upgrade *ManagedClusterUpgradeSpec_STATUS `json:"upgrade,omitempty"`
}
The update to be applied to the ManagedClusters.
type ManagedClusterUpgradeSpec ¶
type ManagedClusterUpgradeSpec struct {
// KubernetesVersion: The Kubernetes version to upgrade the member clusters to.
KubernetesVersion *string `json:"kubernetesVersion,omitempty"`
// Type: ManagedClusterUpgradeType is the type of upgrade to be applied.
Type *ManagedClusterUpgradeType `json:"type,omitempty"`
}
The upgrade to apply to a ManagedCluster.
type ManagedClusterUpgradeSpec_STATUS ¶
type ManagedClusterUpgradeSpec_STATUS struct {
// KubernetesVersion: The Kubernetes version to upgrade the member clusters to.
KubernetesVersion *string `json:"kubernetesVersion,omitempty"`
// Type: ManagedClusterUpgradeType is the type of upgrade to be applied.
Type *ManagedClusterUpgradeType_STATUS `json:"type,omitempty"`
}
The upgrade to apply to a ManagedCluster.
type ManagedClusterUpgradeType ¶
type ManagedClusterUpgradeType string
The type of upgrade to perform when targeting ManagedClusters. +kubebuilder:validation:Enum={"Full","NodeImageOnly"}
type ManagedClusterUpgradeType_STATUS ¶
type ManagedClusterUpgradeType_STATUS string
The type of upgrade to perform when targeting ManagedClusters.
type MemberUpdateStatus_STATUS ¶
type MemberUpdateStatus_STATUS struct {
// ClusterResourceId: The Azure resource id of the target Kubernetes cluster.
ClusterResourceId *string `json:"clusterResourceId,omitempty"`
// Name: The name of the FleetMember.
Name *string `json:"name,omitempty"`
// OperationId: The operation resource id of the latest attempt to perform the operation.
OperationId *string `json:"operationId,omitempty"`
// Status: The status of the MemberUpdate operation.
Status *UpdateStatus_STATUS `json:"status,omitempty"`
}
The status of a member update operation.
type SystemData_CreatedByType_STATUS ¶
type SystemData_CreatedByType_STATUS string
type SystemData_LastModifiedByType_STATUS ¶
type SystemData_LastModifiedByType_STATUS string
type SystemData_STATUS ¶
type SystemData_STATUS struct {
// CreatedAt: The timestamp of resource creation (UTC).
CreatedAt *string `json:"createdAt,omitempty"`
// CreatedBy: The identity that created the resource.
CreatedBy *string `json:"createdBy,omitempty"`
// CreatedByType: The type of identity that created the resource.
CreatedByType *SystemData_CreatedByType_STATUS `json:"createdByType,omitempty"`
// LastModifiedAt: The timestamp of resource last modification (UTC)
LastModifiedAt *string `json:"lastModifiedAt,omitempty"`
// LastModifiedBy: The identity that last modified the resource.
LastModifiedBy *string `json:"lastModifiedBy,omitempty"`
// LastModifiedByType: The type of identity that last modified the resource.
LastModifiedByType *SystemData_LastModifiedByType_STATUS `json:"lastModifiedByType,omitempty"`
}
Metadata pertaining to creation and last modification of the resource.
type UpdateGroup ¶
type UpdateGroup struct {
// Name: Name of the group.
// It must match a group name of an existing fleet member.
Name *string `json:"name,omitempty"`
}
A group to be updated.
type UpdateGroupStatus_STATUS ¶
type UpdateGroupStatus_STATUS struct {
// Members: The list of member this UpdateGroup updates.
Members []MemberUpdateStatus_STATUS `json:"members"`
// Name: The name of the UpdateGroup.
Name *string `json:"name,omitempty"`
// Status: The status of the UpdateGroup.
Status *UpdateStatus_STATUS `json:"status,omitempty"`
}
The status of a UpdateGroup.
type UpdateGroup_STATUS ¶
type UpdateGroup_STATUS struct {
// Name: Name of the group.
// It must match a group name of an existing fleet member.
Name *string `json:"name,omitempty"`
}
A group to be updated.
type UpdateRunProperties ¶
type UpdateRunProperties struct {
// ManagedClusterUpdate: The update to be applied to all clusters in the UpdateRun. The managedClusterUpdate can be
// modified until the run is started.
ManagedClusterUpdate *ManagedClusterUpdate `json:"managedClusterUpdate,omitempty"`
// Strategy: The strategy defines the order in which the clusters will be updated.
// If not set, all members will be updated sequentially. The UpdateRun status will show a single UpdateStage and a single
// UpdateGroup targeting all members.
// The strategy of the UpdateRun can be modified until the run is started.
Strategy *UpdateRunStrategy `json:"strategy,omitempty"`
}
The properties of the UpdateRun.
type UpdateRunProperties_STATUS ¶
type UpdateRunProperties_STATUS struct {
// ManagedClusterUpdate: The update to be applied to all clusters in the UpdateRun. The managedClusterUpdate can be
// modified until the run is started.
ManagedClusterUpdate *ManagedClusterUpdate_STATUS `json:"managedClusterUpdate,omitempty"`
// ProvisioningState: The provisioning state of the UpdateRun resource.
ProvisioningState *UpdateRunProvisioningState_STATUS `json:"provisioningState,omitempty"`
// Status: The status of the UpdateRun.
Status *UpdateRunStatus_STATUS `json:"status,omitempty"`
// Strategy: The strategy defines the order in which the clusters will be updated.
// If not set, all members will be updated sequentially. The UpdateRun status will show a single UpdateStage and a single
// UpdateGroup targeting all members.
// The strategy of the UpdateRun can be modified until the run is started.
Strategy *UpdateRunStrategy_STATUS `json:"strategy,omitempty"`
}
The properties of the UpdateRun.
type UpdateRunProvisioningState_STATUS ¶
type UpdateRunProvisioningState_STATUS string
The provisioning state of the UpdateRun resource.
type UpdateRunStatus_STATUS ¶
type UpdateRunStatus_STATUS struct {
// Stages: The stages composing an update run. Stages are run sequentially withing an UpdateRun.
Stages []UpdateStageStatus_STATUS `json:"stages"`
// Status: The status of the UpdateRun.
Status *UpdateStatus_STATUS `json:"status,omitempty"`
}
The status of a UpdateRun.
type UpdateRunStrategy ¶
type UpdateRunStrategy struct {
// Stages: The list of stages that compose this update run. Min size: 1.
Stages []UpdateStage `json:"stages"`
}
Defines the update sequence of the clusters via stages and groups. Stages within a run are executed sequentially one after another. Groups within a stage are executed in parallel. Member clusters within a group are updated sequentially one after another. A valid strategy contains no duplicate groups within or across stages.
type UpdateRunStrategy_STATUS ¶
type UpdateRunStrategy_STATUS struct {
// Stages: The list of stages that compose this update run. Min size: 1.
Stages []UpdateStage_STATUS `json:"stages"`
}
Defines the update sequence of the clusters via stages and groups. Stages within a run are executed sequentially one after another. Groups within a stage are executed in parallel. Member clusters within a group are updated sequentially one after another. A valid strategy contains no duplicate groups within or across stages.
type UpdateStage ¶
type UpdateStage struct {
// AfterStageWaitInSeconds: The time in seconds to wait at the end of this stage before starting the next one. Defaults to
// 0 seconds if unspecified.
AfterStageWaitInSeconds *int `json:"afterStageWaitInSeconds,omitempty"`
// Groups: Defines the groups to be executed in parallel in this stage. Duplicate groups are not allowed. Min size: 1.
Groups []UpdateGroup `json:"groups"`
// Name: The name of the stage. Must be unique within the UpdateRun.
Name *string `json:"name,omitempty"`
}
Defines a stage which contains the groups to update and the steps to take (e.g., wait for a time period) before starting the next stage.
type UpdateStageStatus_STATUS ¶
type UpdateStageStatus_STATUS struct {
// AfterStageWaitStatus: The status of the wait period configured on the UpdateStage.
AfterStageWaitStatus *WaitStatus_STATUS `json:"afterStageWaitStatus,omitempty"`
// Groups: The list of groups to be updated as part of this UpdateStage.
Groups []UpdateGroupStatus_STATUS `json:"groups"`
// Name: The name of the UpdateStage.
Name *string `json:"name,omitempty"`
// Status: The status of the UpdateStage.
Status *UpdateStatus_STATUS `json:"status,omitempty"`
}
The status of a UpdateStage.
type UpdateStage_STATUS ¶
type UpdateStage_STATUS struct {
// AfterStageWaitInSeconds: The time in seconds to wait at the end of this stage before starting the next one. Defaults to
// 0 seconds if unspecified.
AfterStageWaitInSeconds *int `json:"afterStageWaitInSeconds,omitempty"`
// Groups: Defines the groups to be executed in parallel in this stage. Duplicate groups are not allowed. Min size: 1.
Groups []UpdateGroup_STATUS `json:"groups"`
// Name: The name of the stage. Must be unique within the UpdateRun.
Name *string `json:"name,omitempty"`
}
Defines a stage which contains the groups to update and the steps to take (e.g., wait for a time period) before starting the next stage.
type UpdateState_STATUS ¶
type UpdateState_STATUS string
The state of the UpdateRun, UpdateStage, UpdateGroup, or MemberUpdate.
type UpdateStatus_STATUS ¶
type UpdateStatus_STATUS struct {
// CompletedTime: The time the operation or group was completed.
CompletedTime *string `json:"completedTime,omitempty"`
// Error: The error details when a failure is encountered.
Error *ErrorDetail_STATUS `json:"error,omitempty"`
// StartTime: The time the operation or group was started.
StartTime *string `json:"startTime,omitempty"`
// State: The State of the operation or group.
State *UpdateState_STATUS `json:"state,omitempty"`
}
The status for an operation or group of operations.
type WaitStatus_STATUS ¶
type WaitStatus_STATUS struct {
// Status: The status of the wait duration.
Status *UpdateStatus_STATUS `json:"status,omitempty"`
// WaitDurationInSeconds: The wait duration configured in seconds.
WaitDurationInSeconds *int `json:"waitDurationInSeconds,omitempty"`
}
The status of the wait duration.