Documentation
¶
Overview ¶
Code generated by azure-service-operator-codegen. DO NOT EDIT. Copyright (c) Microsoft Corporation. Licensed under the MIT license.
Code generated by azure-service-operator-codegen. DO NOT EDIT. Copyright (c) Microsoft Corporation. Licensed under the MIT license.
Index ¶
- Constants
- type CMKIdentityDefinition
- type CMKIdentityDefinition_STATUS
- type EncryptionConfiguration
- type EncryptionConfiguration_STATUS
- type FactoryGitHubConfiguration
- type FactoryGitHubConfiguration_STATUS
- type FactoryGitHubConfiguration_Type
- type FactoryGitHubConfiguration_Type_STATUS
- type FactoryIdentity
- type FactoryIdentity_STATUS
- type FactoryIdentity_Type
- type FactoryIdentity_Type_STATUS
- type FactoryProperties
- type FactoryProperties_PublicNetworkAccess
- type FactoryProperties_PublicNetworkAccess_STATUS
- type FactoryProperties_STATUS
- type FactoryRepoConfiguration
- type FactoryRepoConfiguration_STATUS
- type FactoryVSTSConfiguration
- type FactoryVSTSConfiguration_STATUS
- type FactoryVSTSConfiguration_Type
- type FactoryVSTSConfiguration_Type_STATUS
- type Factory_STATUS
- type Factory_Spec
- type GitHubClientSecret
- type GitHubClientSecret_STATUS
- type GlobalParameterSpecification
- type GlobalParameterSpecification_STATUS
- type GlobalParameterSpecification_Type
- type GlobalParameterSpecification_Type_STATUS
- type PurviewConfiguration
- type PurviewConfiguration_STATUS
- type UserAssignedIdentityDetails
Constants ¶
const ( FactoryIdentity_Type_SystemAssigned = FactoryIdentity_Type("SystemAssigned") FactoryIdentity_Type_SystemAssignedUserAssigned = FactoryIdentity_Type("SystemAssigned,UserAssigned") FactoryIdentity_Type_UserAssigned = FactoryIdentity_Type("UserAssigned") )
const ( FactoryProperties_PublicNetworkAccess_Disabled = FactoryProperties_PublicNetworkAccess("Disabled") FactoryProperties_PublicNetworkAccess_Enabled = FactoryProperties_PublicNetworkAccess("Enabled") )
const ( GlobalParameterSpecification_Type_Array = GlobalParameterSpecification_Type("Array") GlobalParameterSpecification_Type_Bool = GlobalParameterSpecification_Type("Bool") GlobalParameterSpecification_Type_Float = GlobalParameterSpecification_Type("Float") GlobalParameterSpecification_Type_Int = GlobalParameterSpecification_Type("Int") GlobalParameterSpecification_Type_Object = GlobalParameterSpecification_Type("Object") GlobalParameterSpecification_Type_String = GlobalParameterSpecification_Type("String") )
const ( FactoryIdentity_Type_STATUS_SystemAssigned = FactoryIdentity_Type_STATUS("SystemAssigned") FactoryIdentity_Type_STATUS_SystemAssignedUserAssigned = FactoryIdentity_Type_STATUS("SystemAssigned,UserAssigned") FactoryIdentity_Type_STATUS_UserAssigned = FactoryIdentity_Type_STATUS("UserAssigned") )
const ( FactoryProperties_PublicNetworkAccess_STATUS_Disabled = FactoryProperties_PublicNetworkAccess_STATUS("Disabled") FactoryProperties_PublicNetworkAccess_STATUS_Enabled = FactoryProperties_PublicNetworkAccess_STATUS("Enabled") )
const ( GlobalParameterSpecification_Type_STATUS_Array = GlobalParameterSpecification_Type_STATUS("Array") GlobalParameterSpecification_Type_STATUS_Bool = GlobalParameterSpecification_Type_STATUS("Bool") GlobalParameterSpecification_Type_STATUS_Float = GlobalParameterSpecification_Type_STATUS("Float") GlobalParameterSpecification_Type_STATUS_Int = GlobalParameterSpecification_Type_STATUS("Int") GlobalParameterSpecification_Type_STATUS_Object = GlobalParameterSpecification_Type_STATUS("Object") GlobalParameterSpecification_Type_STATUS_String = GlobalParameterSpecification_Type_STATUS("String") )
const FactoryGitHubConfiguration_Type_FactoryGitHubConfiguration = FactoryGitHubConfiguration_Type("FactoryGitHubConfiguration")
const FactoryGitHubConfiguration_Type_STATUS_FactoryGitHubConfiguration = FactoryGitHubConfiguration_Type_STATUS("FactoryGitHubConfiguration")
const FactoryVSTSConfiguration_Type_FactoryVSTSConfiguration = FactoryVSTSConfiguration_Type("FactoryVSTSConfiguration")
const FactoryVSTSConfiguration_Type_STATUS_FactoryVSTSConfiguration = FactoryVSTSConfiguration_Type_STATUS("FactoryVSTSConfiguration")
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type CMKIdentityDefinition ¶
type CMKIdentityDefinition struct {
UserAssignedIdentity *string `json:"userAssignedIdentity,omitempty"`
}
Managed Identity used for CMK.
type CMKIdentityDefinition_STATUS ¶
type CMKIdentityDefinition_STATUS struct {
// UserAssignedIdentity: The resource id of the user assigned identity to authenticate to customer's key vault.
UserAssignedIdentity *string `json:"userAssignedIdentity,omitempty"`
}
Managed Identity used for CMK.
type EncryptionConfiguration ¶
type EncryptionConfiguration struct {
// Identity: User assigned identity to use to authenticate to customer's key vault. If not provided Managed Service
// Identity will be used.
Identity *CMKIdentityDefinition `json:"identity,omitempty"`
// KeyName: The name of the key in Azure Key Vault to use as Customer Managed Key.
KeyName *string `json:"keyName,omitempty"`
// KeyVersion: The version of the key used for CMK. If not provided, latest version will be used.
KeyVersion *string `json:"keyVersion,omitempty"`
// VaultBaseUrl: The url of the Azure Key Vault used for CMK.
VaultBaseUrl *string `json:"vaultBaseUrl,omitempty"`
}
Definition of CMK for the factory.
type EncryptionConfiguration_STATUS ¶
type EncryptionConfiguration_STATUS struct {
// Identity: User assigned identity to use to authenticate to customer's key vault. If not provided Managed Service
// Identity will be used.
Identity *CMKIdentityDefinition_STATUS `json:"identity,omitempty"`
// KeyName: The name of the key in Azure Key Vault to use as Customer Managed Key.
KeyName *string `json:"keyName,omitempty"`
// KeyVersion: The version of the key used for CMK. If not provided, latest version will be used.
KeyVersion *string `json:"keyVersion,omitempty"`
// VaultBaseUrl: The url of the Azure Key Vault used for CMK.
VaultBaseUrl *string `json:"vaultBaseUrl,omitempty"`
}
Definition of CMK for the factory.
type FactoryGitHubConfiguration ¶
type FactoryGitHubConfiguration struct {
// AccountName: Account name.
AccountName *string `json:"accountName,omitempty"`
// ClientId: GitHub bring your own app client id.
ClientId *string `json:"clientId,omitempty"`
// ClientSecret: GitHub bring your own app client secret information.
ClientSecret *GitHubClientSecret `json:"clientSecret,omitempty"`
// CollaborationBranch: Collaboration branch.
CollaborationBranch *string `json:"collaborationBranch,omitempty"`
// DisablePublish: Disable manual publish operation in ADF studio to favor automated publish.
DisablePublish *bool `json:"disablePublish,omitempty"`
// HostName: GitHub Enterprise host name. For example: `https://github.mydomain.com`
HostName *string `json:"hostName,omitempty"`
// LastCommitId: Last commit id.
LastCommitId *string `json:"lastCommitId,omitempty"`
// RepositoryName: Repository name.
RepositoryName *string `json:"repositoryName,omitempty"`
// RootFolder: Root folder.
RootFolder *string `json:"rootFolder,omitempty"`
// Type: Type of repo configuration.
Type FactoryGitHubConfiguration_Type `json:"type,omitempty"`
}
type FactoryGitHubConfiguration_STATUS ¶
type FactoryGitHubConfiguration_STATUS struct {
// AccountName: Account name.
AccountName *string `json:"accountName,omitempty"`
// ClientId: GitHub bring your own app client id.
ClientId *string `json:"clientId,omitempty"`
// ClientSecret: GitHub bring your own app client secret information.
ClientSecret *GitHubClientSecret_STATUS `json:"clientSecret,omitempty"`
// CollaborationBranch: Collaboration branch.
CollaborationBranch *string `json:"collaborationBranch,omitempty"`
// DisablePublish: Disable manual publish operation in ADF studio to favor automated publish.
DisablePublish *bool `json:"disablePublish,omitempty"`
// HostName: GitHub Enterprise host name. For example: `https://github.mydomain.com`
HostName *string `json:"hostName,omitempty"`
// LastCommitId: Last commit id.
LastCommitId *string `json:"lastCommitId,omitempty"`
// RepositoryName: Repository name.
RepositoryName *string `json:"repositoryName,omitempty"`
// RootFolder: Root folder.
RootFolder *string `json:"rootFolder,omitempty"`
// Type: Type of repo configuration.
Type FactoryGitHubConfiguration_Type_STATUS `json:"type,omitempty"`
}
type FactoryGitHubConfiguration_Type ¶
type FactoryGitHubConfiguration_Type string
+kubebuilder:validation:Enum={"FactoryGitHubConfiguration"}
type FactoryGitHubConfiguration_Type_STATUS ¶
type FactoryGitHubConfiguration_Type_STATUS string
type FactoryIdentity ¶
type FactoryIdentity struct {
// Type: The identity type.
Type *FactoryIdentity_Type `json:"type,omitempty"`
UserAssignedIdentities map[string]UserAssignedIdentityDetails `json:"userAssignedIdentities,omitempty"`
}
Identity properties of the factory resource.
type FactoryIdentity_STATUS ¶
type FactoryIdentity_STATUS struct {
// PrincipalId: The principal id of the identity.
PrincipalId *string `json:"principalId,omitempty"`
// TenantId: The client tenant id of the identity.
TenantId *string `json:"tenantId,omitempty"`
// Type: The identity type.
Type *FactoryIdentity_Type_STATUS `json:"type,omitempty"`
// UserAssignedIdentities: List of user assigned identities for the factory.
UserAssignedIdentities map[string]v1.JSON `json:"userAssignedIdentities,omitempty"`
}
Identity properties of the factory resource.
type FactoryIdentity_Type ¶
type FactoryIdentity_Type string
+kubebuilder:validation:Enum={"SystemAssigned","SystemAssigned,UserAssigned","UserAssigned"}
type FactoryIdentity_Type_STATUS ¶
type FactoryIdentity_Type_STATUS string
type FactoryProperties ¶
type FactoryProperties struct {
// Encryption: Properties to enable Customer Managed Key for the factory.
Encryption *EncryptionConfiguration `json:"encryption,omitempty"`
// GlobalParameters: List of parameters for factory.
GlobalParameters map[string]GlobalParameterSpecification `json:"globalParameters,omitempty"`
// PublicNetworkAccess: Whether or not public network access is allowed for the data factory.
PublicNetworkAccess *FactoryProperties_PublicNetworkAccess `json:"publicNetworkAccess,omitempty"`
// PurviewConfiguration: Purview information of the factory.
PurviewConfiguration *PurviewConfiguration `json:"purviewConfiguration,omitempty"`
// RepoConfiguration: Git repo information of the factory.
RepoConfiguration *FactoryRepoConfiguration `json:"repoConfiguration,omitempty"`
}
Factory resource properties.
type FactoryProperties_PublicNetworkAccess ¶
type FactoryProperties_PublicNetworkAccess string
+kubebuilder:validation:Enum={"Disabled","Enabled"}
type FactoryProperties_PublicNetworkAccess_STATUS ¶
type FactoryProperties_PublicNetworkAccess_STATUS string
type FactoryProperties_STATUS ¶
type FactoryProperties_STATUS struct {
// CreateTime: Time the factory was created in ISO8601 format.
CreateTime *string `json:"createTime,omitempty"`
// Encryption: Properties to enable Customer Managed Key for the factory.
Encryption *EncryptionConfiguration_STATUS `json:"encryption,omitempty"`
// GlobalParameters: List of parameters for factory.
GlobalParameters map[string]GlobalParameterSpecification_STATUS `json:"globalParameters,omitempty"`
// ProvisioningState: Factory provisioning state, example Succeeded.
ProvisioningState *string `json:"provisioningState,omitempty"`
// PublicNetworkAccess: Whether or not public network access is allowed for the data factory.
PublicNetworkAccess *FactoryProperties_PublicNetworkAccess_STATUS `json:"publicNetworkAccess,omitempty"`
// PurviewConfiguration: Purview information of the factory.
PurviewConfiguration *PurviewConfiguration_STATUS `json:"purviewConfiguration,omitempty"`
// RepoConfiguration: Git repo information of the factory.
RepoConfiguration *FactoryRepoConfiguration_STATUS `json:"repoConfiguration,omitempty"`
// Version: Version of the factory.
Version *string `json:"version,omitempty"`
}
Factory resource properties.
type FactoryRepoConfiguration ¶
type FactoryRepoConfiguration struct {
// FactoryGitHub: Mutually exclusive with all other properties
FactoryGitHub *FactoryGitHubConfiguration `json:"factoryGitHubConfiguration,omitempty"`
// FactoryVSTS: Mutually exclusive with all other properties
FactoryVSTS *FactoryVSTSConfiguration `json:"factoryVSTSConfiguration,omitempty"`
}
func (FactoryRepoConfiguration) MarshalJSON ¶
func (configuration FactoryRepoConfiguration) MarshalJSON() ([]byte, error)
MarshalJSON defers JSON marshaling to the first non-nil property, because FactoryRepoConfiguration represents a discriminated union (JSON OneOf)
func (*FactoryRepoConfiguration) UnmarshalJSON ¶
func (configuration *FactoryRepoConfiguration) UnmarshalJSON(data []byte) error
UnmarshalJSON unmarshals the FactoryRepoConfiguration
type FactoryRepoConfiguration_STATUS ¶
type FactoryRepoConfiguration_STATUS struct {
// FactoryGitHub: Mutually exclusive with all other properties
FactoryGitHub *FactoryGitHubConfiguration_STATUS `json:"factoryGitHubConfiguration,omitempty"`
// FactoryVSTS: Mutually exclusive with all other properties
FactoryVSTS *FactoryVSTSConfiguration_STATUS `json:"factoryVSTSConfiguration,omitempty"`
}
func (FactoryRepoConfiguration_STATUS) MarshalJSON ¶
func (configuration FactoryRepoConfiguration_STATUS) MarshalJSON() ([]byte, error)
MarshalJSON defers JSON marshaling to the first non-nil property, because FactoryRepoConfiguration_STATUS represents a discriminated union (JSON OneOf)
func (*FactoryRepoConfiguration_STATUS) UnmarshalJSON ¶
func (configuration *FactoryRepoConfiguration_STATUS) UnmarshalJSON(data []byte) error
UnmarshalJSON unmarshals the FactoryRepoConfiguration_STATUS
type FactoryVSTSConfiguration ¶
type FactoryVSTSConfiguration struct {
// AccountName: Account name.
AccountName *string `json:"accountName,omitempty"`
// CollaborationBranch: Collaboration branch.
CollaborationBranch *string `json:"collaborationBranch,omitempty"`
// DisablePublish: Disable manual publish operation in ADF studio to favor automated publish.
DisablePublish *bool `json:"disablePublish,omitempty"`
// LastCommitId: Last commit id.
LastCommitId *string `json:"lastCommitId,omitempty"`
// ProjectName: VSTS project name.
ProjectName *string `json:"projectName,omitempty"`
// RepositoryName: Repository name.
RepositoryName *string `json:"repositoryName,omitempty"`
// RootFolder: Root folder.
RootFolder *string `json:"rootFolder,omitempty"`
// TenantId: VSTS tenant id.
TenantId *string `json:"tenantId,omitempty"`
// Type: Type of repo configuration.
Type FactoryVSTSConfiguration_Type `json:"type,omitempty"`
}
type FactoryVSTSConfiguration_STATUS ¶
type FactoryVSTSConfiguration_STATUS struct {
// AccountName: Account name.
AccountName *string `json:"accountName,omitempty"`
// CollaborationBranch: Collaboration branch.
CollaborationBranch *string `json:"collaborationBranch,omitempty"`
// DisablePublish: Disable manual publish operation in ADF studio to favor automated publish.
DisablePublish *bool `json:"disablePublish,omitempty"`
// LastCommitId: Last commit id.
LastCommitId *string `json:"lastCommitId,omitempty"`
// ProjectName: VSTS project name.
ProjectName *string `json:"projectName,omitempty"`
// RepositoryName: Repository name.
RepositoryName *string `json:"repositoryName,omitempty"`
// RootFolder: Root folder.
RootFolder *string `json:"rootFolder,omitempty"`
// TenantId: VSTS tenant id.
TenantId *string `json:"tenantId,omitempty"`
// Type: Type of repo configuration.
Type FactoryVSTSConfiguration_Type_STATUS `json:"type,omitempty"`
}
type FactoryVSTSConfiguration_Type ¶
type FactoryVSTSConfiguration_Type string
+kubebuilder:validation:Enum={"FactoryVSTSConfiguration"}
type FactoryVSTSConfiguration_Type_STATUS ¶
type FactoryVSTSConfiguration_Type_STATUS string
type Factory_STATUS ¶
type Factory_STATUS struct {
AdditionalProperties map[string]v1.JSON `json:"additionalProperties,omitempty"`
// ETag: Etag identifies change in the resource.
ETag *string `json:"eTag,omitempty"`
// Id: The resource identifier.
Id *string `json:"id,omitempty"`
// Identity: Managed service identity of the factory.
Identity *FactoryIdentity_STATUS `json:"identity,omitempty"`
// Location: The resource location.
Location *string `json:"location,omitempty"`
// Name: The resource name.
Name *string `json:"name,omitempty"`
// Properties: Properties of the factory.
Properties *FactoryProperties_STATUS `json:"properties,omitempty"`
// Tags: The resource tags.
Tags map[string]string `json:"tags,omitempty"`
// Type: The resource type.
Type *string `json:"type,omitempty"`
}
Factory resource type.
type Factory_Spec ¶
type Factory_Spec struct {
AdditionalProperties map[string]v1.JSON `json:"additionalProperties,omitempty"`
// Identity: Managed service identity of the factory.
Identity *FactoryIdentity `json:"identity,omitempty"`
// Location: The resource location.
Location *string `json:"location,omitempty"`
Name string `json:"name,omitempty"`
// Properties: Properties of the factory.
Properties *FactoryProperties `json:"properties,omitempty"`
// Tags: The resource tags.
Tags map[string]string `json:"tags,omitempty"`
}
func (Factory_Spec) GetAPIVersion ¶
func (factory Factory_Spec) GetAPIVersion() string
GetAPIVersion returns the ARM API version of the resource. This is always "2018-06-01"
func (*Factory_Spec) GetName ¶
func (factory *Factory_Spec) GetName() string
GetName returns the Name of the resource
func (*Factory_Spec) GetType ¶
func (factory *Factory_Spec) GetType() string
GetType returns the ARM Type of the resource. This is always "Microsoft.DataFactory/factories"
type GitHubClientSecret ¶
type GitHubClientSecret struct {
// ByoaSecretAkvUrl: Bring your own app client secret AKV URL.
ByoaSecretAkvUrl *string `json:"byoaSecretAkvUrl,omitempty"`
// ByoaSecretName: Bring your own app client secret name in AKV.
ByoaSecretName *string `json:"byoaSecretName,omitempty"`
}
Client secret information for factory's bring your own app repository configuration.
type GitHubClientSecret_STATUS ¶
type GitHubClientSecret_STATUS struct {
// ByoaSecretAkvUrl: Bring your own app client secret AKV URL.
ByoaSecretAkvUrl *string `json:"byoaSecretAkvUrl,omitempty"`
// ByoaSecretName: Bring your own app client secret name in AKV.
ByoaSecretName *string `json:"byoaSecretName,omitempty"`
}
Client secret information for factory's bring your own app repository configuration.
type GlobalParameterSpecification ¶
type GlobalParameterSpecification struct {
// Type: Global Parameter type.
Type *GlobalParameterSpecification_Type `json:"type,omitempty"`
// Value: Value of parameter.
Value map[string]v1.JSON `json:"value,omitempty"`
}
Definition of a single parameter for an entity.
type GlobalParameterSpecification_STATUS ¶
type GlobalParameterSpecification_STATUS struct {
// Type: Global Parameter type.
Type *GlobalParameterSpecification_Type_STATUS `json:"type,omitempty"`
// Value: Value of parameter.
Value map[string]v1.JSON `json:"value,omitempty"`
}
Definition of a single parameter for an entity.
type GlobalParameterSpecification_Type ¶
type GlobalParameterSpecification_Type string
+kubebuilder:validation:Enum={"Array","Bool","Float","Int","Object","String"}
type GlobalParameterSpecification_Type_STATUS ¶
type GlobalParameterSpecification_Type_STATUS string
type PurviewConfiguration ¶
type PurviewConfiguration struct {
PurviewResourceId *string `json:"purviewResourceId,omitempty"`
}
Purview configuration.
type PurviewConfiguration_STATUS ¶
type PurviewConfiguration_STATUS struct {
// PurviewResourceId: Purview resource id.
PurviewResourceId *string `json:"purviewResourceId,omitempty"`
}
Purview configuration.
type UserAssignedIdentityDetails ¶
type UserAssignedIdentityDetails struct {
}
Information about the user assigned identity for the resource