Documentation
¶
Overview ¶
Code generated by azure-service-operator-codegen. DO NOT EDIT. Copyright (c) Microsoft Corporation. Licensed under the MIT license.
Code generated by azure-service-operator-codegen. DO NOT EDIT. Copyright (c) Microsoft Corporation. Licensed under the MIT license.
Code generated by azure-service-operator-codegen. DO NOT EDIT. Copyright (c) Microsoft Corporation. Licensed under the MIT license.
Code generated by azure-service-operator-codegen. DO NOT EDIT. Copyright (c) Microsoft Corporation. Licensed under the MIT license.
Code generated by azure-service-operator-codegen. DO NOT EDIT. Copyright (c) Microsoft Corporation. Licensed under the MIT license.
Code generated by azure-service-operator-codegen. DO NOT EDIT. Copyright (c) Microsoft Corporation. Licensed under the MIT license.
Code generated by azure-service-operator-codegen. DO NOT EDIT. Copyright (c) Microsoft Corporation. Licensed under the MIT license.
Code generated by azure-service-operator-codegen. DO NOT EDIT. Copyright (c) Microsoft Corporation. Licensed under the MIT license.
Code generated by azure-service-operator-codegen. DO NOT EDIT. Copyright (c) Microsoft Corporation. Licensed under the MIT license.
Code generated by azure-service-operator-codegen. DO NOT EDIT. Copyright (c) Microsoft Corporation. Licensed under the MIT license.
Index ¶
- Constants
- type CaptureDescription
- type CaptureDescription_Encoding
- type CaptureDescription_Encoding_STATUS
- type CaptureDescription_STATUS
- type Destination
- type Destination_Properties
- type Destination_Properties_STATUS
- type Destination_STATUS
- type Encryption
- type Encryption_KeySource
- type Encryption_KeySource_STATUS
- type Encryption_STATUS
- type Identity
- type Identity_STATUS
- type Identity_Type
- type Identity_Type_STATUS
- type KeyVaultProperties
- type KeyVaultProperties_STATUS
- type Namespace_Properties_STATUS
- type Namespace_Properties_Spec
- type Namespace_STATUS
- type Namespace_Spec
- type NamespacesAuthorizationRule_STATUS
- type NamespacesAuthorizationRule_Spec
- type NamespacesEventhub_STATUS
- type NamespacesEventhub_Spec
- type NamespacesEventhubsAuthorizationRule_STATUS
- type NamespacesEventhubsAuthorizationRule_Spec
- type NamespacesEventhubsConsumerGroup_STATUS
- type NamespacesEventhubsConsumerGroup_Spec
- type Namespaces_AuthorizationRule_Properties_Rights_STATUS
- type Namespaces_AuthorizationRule_Properties_Rights_Spec
- type Namespaces_AuthorizationRule_Properties_STATUS
- type Namespaces_AuthorizationRule_Properties_Spec
- type Namespaces_Eventhub_Properties_STATUS
- type Namespaces_Eventhub_Properties_Spec
- type Namespaces_Eventhub_Properties_Status_STATUS
- type Namespaces_Eventhubs_AuthorizationRule_Properties_Rights_STATUS
- type Namespaces_Eventhubs_AuthorizationRule_Properties_Rights_Spec
- type Namespaces_Eventhubs_AuthorizationRule_Properties_STATUS
- type Namespaces_Eventhubs_AuthorizationRule_Properties_Spec
- type Namespaces_Eventhubs_Consumergroup_Properties_STATUS
- type Namespaces_Eventhubs_Consumergroup_Properties_Spec
- type PrivateEndpointConnection_STATUS
- type Sku
- type Sku_Name
- type Sku_Name_STATUS
- type Sku_STATUS
- type Sku_Tier
- type Sku_Tier_STATUS
- type SystemData_CreatedByType_STATUS
- type SystemData_LastModifiedByType_STATUS
- type SystemData_STATUS
- type UserAssignedIdentityDetails
- type UserAssignedIdentityProperties
- type UserAssignedIdentityProperties_STATUS
- type UserAssignedIdentity_STATUS
Constants ¶
const ( Identity_Type_None = Identity_Type("None") Identity_Type_SystemAssigned = Identity_Type("SystemAssigned") Identity_Type_SystemAssignedUserAssigned = Identity_Type("SystemAssigned, UserAssigned") Identity_Type_UserAssigned = Identity_Type("UserAssigned") )
const ( Sku_Name_Basic = Sku_Name("Basic") Sku_Name_Premium = Sku_Name("Premium") Sku_Name_Standard = Sku_Name("Standard") )
const ( Sku_Tier_Basic = Sku_Tier("Basic") Sku_Tier_Premium = Sku_Tier("Premium") Sku_Tier_Standard = Sku_Tier("Standard") )
const ( Identity_Type_STATUS_None = Identity_Type_STATUS("None") Identity_Type_STATUS_SystemAssigned = Identity_Type_STATUS("SystemAssigned") Identity_Type_STATUS_SystemAssignedUserAssigned = Identity_Type_STATUS("SystemAssigned, UserAssigned") Identity_Type_STATUS_UserAssigned = Identity_Type_STATUS("UserAssigned") )
const ( Sku_Name_STATUS_Basic = Sku_Name_STATUS("Basic") Sku_Name_STATUS_Premium = Sku_Name_STATUS("Premium") Sku_Name_STATUS_Standard = Sku_Name_STATUS("Standard") )
const ( Sku_Tier_STATUS_Basic = Sku_Tier_STATUS("Basic") Sku_Tier_STATUS_Premium = Sku_Tier_STATUS("Premium") Sku_Tier_STATUS_Standard = Sku_Tier_STATUS("Standard") )
const ( SystemData_CreatedByType_STATUS_Application = SystemData_CreatedByType_STATUS("Application") SystemData_CreatedByType_STATUS_Key = SystemData_CreatedByType_STATUS("Key") SystemData_CreatedByType_STATUS_ManagedIdentity = SystemData_CreatedByType_STATUS("ManagedIdentity") SystemData_CreatedByType_STATUS_User = SystemData_CreatedByType_STATUS("User") )
const ( SystemData_LastModifiedByType_STATUS_Application = SystemData_LastModifiedByType_STATUS("Application") SystemData_LastModifiedByType_STATUS_Key = SystemData_LastModifiedByType_STATUS("Key") SystemData_LastModifiedByType_STATUS_ManagedIdentity = SystemData_LastModifiedByType_STATUS("ManagedIdentity") SystemData_LastModifiedByType_STATUS_User = SystemData_LastModifiedByType_STATUS("User") )
const ( Namespaces_AuthorizationRule_Properties_Rights_Spec_Listen = Namespaces_AuthorizationRule_Properties_Rights_Spec("Listen") Namespaces_AuthorizationRule_Properties_Rights_Spec_Manage = Namespaces_AuthorizationRule_Properties_Rights_Spec("Manage") Namespaces_AuthorizationRule_Properties_Rights_Spec_Send = Namespaces_AuthorizationRule_Properties_Rights_Spec("Send") )
const ( Namespaces_AuthorizationRule_Properties_Rights_STATUS_Listen = Namespaces_AuthorizationRule_Properties_Rights_STATUS("Listen") Namespaces_AuthorizationRule_Properties_Rights_STATUS_Manage = Namespaces_AuthorizationRule_Properties_Rights_STATUS("Manage") Namespaces_AuthorizationRule_Properties_Rights_STATUS_Send = Namespaces_AuthorizationRule_Properties_Rights_STATUS("Send") )
const ( CaptureDescription_Encoding_Avro = CaptureDescription_Encoding("Avro") CaptureDescription_Encoding_AvroDeflate = CaptureDescription_Encoding("AvroDeflate") )
const ( Namespaces_Eventhub_Properties_Status_STATUS_Active = Namespaces_Eventhub_Properties_Status_STATUS("Active") Namespaces_Eventhub_Properties_Status_STATUS_Creating = Namespaces_Eventhub_Properties_Status_STATUS("Creating") Namespaces_Eventhub_Properties_Status_STATUS_Deleting = Namespaces_Eventhub_Properties_Status_STATUS("Deleting") Namespaces_Eventhub_Properties_Status_STATUS_Disabled = Namespaces_Eventhub_Properties_Status_STATUS("Disabled") Namespaces_Eventhub_Properties_Status_STATUS_ReceiveDisabled = Namespaces_Eventhub_Properties_Status_STATUS("ReceiveDisabled") Namespaces_Eventhub_Properties_Status_STATUS_Renaming = Namespaces_Eventhub_Properties_Status_STATUS("Renaming") Namespaces_Eventhub_Properties_Status_STATUS_Restoring = Namespaces_Eventhub_Properties_Status_STATUS("Restoring") Namespaces_Eventhub_Properties_Status_STATUS_SendDisabled = Namespaces_Eventhub_Properties_Status_STATUS("SendDisabled") Namespaces_Eventhub_Properties_Status_STATUS_Unknown = Namespaces_Eventhub_Properties_Status_STATUS("Unknown") )
const ( CaptureDescription_Encoding_STATUS_Avro = CaptureDescription_Encoding_STATUS("Avro") CaptureDescription_Encoding_STATUS_AvroDeflate = CaptureDescription_Encoding_STATUS("AvroDeflate") )
const ( Namespaces_Eventhubs_AuthorizationRule_Properties_Rights_Spec_Listen = Namespaces_Eventhubs_AuthorizationRule_Properties_Rights_Spec("Listen") Namespaces_Eventhubs_AuthorizationRule_Properties_Rights_Spec_Manage = Namespaces_Eventhubs_AuthorizationRule_Properties_Rights_Spec("Manage") Namespaces_Eventhubs_AuthorizationRule_Properties_Rights_Spec_Send = Namespaces_Eventhubs_AuthorizationRule_Properties_Rights_Spec("Send") )
const ( Namespaces_Eventhubs_AuthorizationRule_Properties_Rights_STATUS_Listen = Namespaces_Eventhubs_AuthorizationRule_Properties_Rights_STATUS("Listen") Namespaces_Eventhubs_AuthorizationRule_Properties_Rights_STATUS_Manage = Namespaces_Eventhubs_AuthorizationRule_Properties_Rights_STATUS("Manage") Namespaces_Eventhubs_AuthorizationRule_Properties_Rights_STATUS_Send = Namespaces_Eventhubs_AuthorizationRule_Properties_Rights_STATUS("Send") )
const Encryption_KeySource_MicrosoftKeyVault = Encryption_KeySource("Microsoft.KeyVault")
const Encryption_KeySource_STATUS_MicrosoftKeyVault = Encryption_KeySource_STATUS("Microsoft.KeyVault")
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type CaptureDescription ¶
type CaptureDescription struct {
// Destination: Properties of Destination where capture will be stored. (Storage Account, Blob Names)
Destination *Destination `json:"destination,omitempty"`
// Enabled: A value that indicates whether capture description is enabled.
Enabled *bool `json:"enabled,omitempty"`
// Encoding: Enumerates the possible values for the encoding format of capture description. Note: 'AvroDeflate' will be
// deprecated in New API Version
Encoding *CaptureDescription_Encoding `json:"encoding,omitempty"`
// IntervalInSeconds: The time window allows you to set the frequency with which the capture to Azure Blobs will happen,
// value should between 60 to 900 seconds
IntervalInSeconds *int `json:"intervalInSeconds,omitempty"`
// SizeLimitInBytes: The size window defines the amount of data built up in your Event Hub before an capture operation,
// value should be between 10485760 to 524288000 bytes
SizeLimitInBytes *int `json:"sizeLimitInBytes,omitempty"`
// SkipEmptyArchives: A value that indicates whether to Skip Empty Archives
SkipEmptyArchives *bool `json:"skipEmptyArchives,omitempty"`
}
Properties to configure capture description for eventhub
type CaptureDescription_Encoding ¶
type CaptureDescription_Encoding string
+kubebuilder:validation:Enum={"Avro","AvroDeflate"}
type CaptureDescription_Encoding_STATUS ¶
type CaptureDescription_Encoding_STATUS string
type CaptureDescription_STATUS ¶
type CaptureDescription_STATUS struct {
// Destination: Properties of Destination where capture will be stored. (Storage Account, Blob Names)
Destination *Destination_STATUS `json:"destination,omitempty"`
// Enabled: A value that indicates whether capture description is enabled.
Enabled *bool `json:"enabled,omitempty"`
// Encoding: Enumerates the possible values for the encoding format of capture description. Note: 'AvroDeflate' will be
// deprecated in New API Version
Encoding *CaptureDescription_Encoding_STATUS `json:"encoding,omitempty"`
// IntervalInSeconds: The time window allows you to set the frequency with which the capture to Azure Blobs will happen,
// value should between 60 to 900 seconds
IntervalInSeconds *int `json:"intervalInSeconds,omitempty"`
// SizeLimitInBytes: The size window defines the amount of data built up in your Event Hub before an capture operation,
// value should be between 10485760 to 524288000 bytes
SizeLimitInBytes *int `json:"sizeLimitInBytes,omitempty"`
// SkipEmptyArchives: A value that indicates whether to Skip Empty Archives
SkipEmptyArchives *bool `json:"skipEmptyArchives,omitempty"`
}
Properties to configure capture description for eventhub
type Destination ¶
type Destination struct {
// Name: Name for capture destination
Name *string `json:"name,omitempty"`
// Properties: Properties describing the storage account, blob container and archive name format for capture destination
Properties *Destination_Properties `json:"properties,omitempty"`
}
Capture storage details for capture description
type Destination_Properties ¶
type Destination_Properties struct {
// ArchiveNameFormat: Blob naming convention for archive, e.g.
// {Namespace}/{EventHub}/{PartitionId}/{Year}/{Month}/{Day}/{Hour}/{Minute}/{Second}. Here all the parameters
// (Namespace,EventHub .. etc) are mandatory irrespective of order
ArchiveNameFormat *string `json:"archiveNameFormat,omitempty"`
// BlobContainer: Blob container Name
BlobContainer *string `json:"blobContainer,omitempty"`
// DataLakeAccountName: The Azure Data Lake Store name for the captured events
DataLakeAccountName *string `json:"dataLakeAccountName,omitempty"`
// DataLakeFolderPath: The destination folder path for the captured events
DataLakeFolderPath *string `json:"dataLakeFolderPath,omitempty"`
// DataLakeSubscriptionId: Subscription Id of Azure Data Lake Store
DataLakeSubscriptionId *string `json:"dataLakeSubscriptionId,omitempty"`
StorageAccountResourceId *string `json:"storageAccountResourceId,omitempty"`
}
type Destination_Properties_STATUS ¶
type Destination_Properties_STATUS struct {
// ArchiveNameFormat: Blob naming convention for archive, e.g.
// {Namespace}/{EventHub}/{PartitionId}/{Year}/{Month}/{Day}/{Hour}/{Minute}/{Second}. Here all the parameters
// (Namespace,EventHub .. etc) are mandatory irrespective of order
ArchiveNameFormat *string `json:"archiveNameFormat,omitempty"`
// BlobContainer: Blob container Name
BlobContainer *string `json:"blobContainer,omitempty"`
// DataLakeAccountName: The Azure Data Lake Store name for the captured events
DataLakeAccountName *string `json:"dataLakeAccountName,omitempty"`
// DataLakeFolderPath: The destination folder path for the captured events
DataLakeFolderPath *string `json:"dataLakeFolderPath,omitempty"`
// DataLakeSubscriptionId: Subscription Id of Azure Data Lake Store
DataLakeSubscriptionId *string `json:"dataLakeSubscriptionId,omitempty"`
// StorageAccountResourceId: Resource id of the storage account to be used to create the blobs
StorageAccountResourceId *string `json:"storageAccountResourceId,omitempty"`
}
type Destination_STATUS ¶
type Destination_STATUS struct {
// Name: Name for capture destination
Name *string `json:"name,omitempty"`
// Properties: Properties describing the storage account, blob container and archive name format for capture destination
Properties *Destination_Properties_STATUS `json:"properties,omitempty"`
}
Capture storage details for capture description
type Encryption ¶
type Encryption struct {
// KeySource: Enumerates the possible value of keySource for Encryption
KeySource *Encryption_KeySource `json:"keySource,omitempty"`
// KeyVaultProperties: Properties of KeyVault
KeyVaultProperties []KeyVaultProperties `json:"keyVaultProperties,omitempty"`
// RequireInfrastructureEncryption: Enable Infrastructure Encryption (Double Encryption)
RequireInfrastructureEncryption *bool `json:"requireInfrastructureEncryption,omitempty"`
}
Properties to configure Encryption
type Encryption_KeySource ¶
type Encryption_KeySource string
+kubebuilder:validation:Enum={"Microsoft.KeyVault"}
type Encryption_KeySource_STATUS ¶
type Encryption_KeySource_STATUS string
type Encryption_STATUS ¶
type Encryption_STATUS struct {
// KeySource: Enumerates the possible value of keySource for Encryption
KeySource *Encryption_KeySource_STATUS `json:"keySource,omitempty"`
// KeyVaultProperties: Properties of KeyVault
KeyVaultProperties []KeyVaultProperties_STATUS `json:"keyVaultProperties,omitempty"`
// RequireInfrastructureEncryption: Enable Infrastructure Encryption (Double Encryption)
RequireInfrastructureEncryption *bool `json:"requireInfrastructureEncryption,omitempty"`
}
Properties to configure Encryption
type Identity ¶
type Identity struct {
// Type: Type of managed service identity.
Type *Identity_Type `json:"type,omitempty"`
UserAssignedIdentities map[string]UserAssignedIdentityDetails `json:"userAssignedIdentities,omitempty"`
}
Properties to configure Identity for Bring your Own Keys
type Identity_STATUS ¶
type Identity_STATUS struct {
// PrincipalId: ObjectId from the KeyVault
PrincipalId *string `json:"principalId,omitempty"`
// TenantId: TenantId from the KeyVault
TenantId *string `json:"tenantId,omitempty"`
// Type: Type of managed service identity.
Type *Identity_Type_STATUS `json:"type,omitempty"`
// UserAssignedIdentities: Properties for User Assigned Identities
UserAssignedIdentities map[string]UserAssignedIdentity_STATUS `json:"userAssignedIdentities,omitempty"`
}
Properties to configure Identity for Bring your Own Keys
type Identity_Type ¶
type Identity_Type string
+kubebuilder:validation:Enum={"None","SystemAssigned","SystemAssigned, UserAssigned","UserAssigned"}
type Identity_Type_STATUS ¶
type Identity_Type_STATUS string
type KeyVaultProperties ¶
type KeyVaultProperties struct {
Identity *UserAssignedIdentityProperties `json:"identity,omitempty"`
// KeyName: Name of the Key from KeyVault
KeyName *string `json:"keyName,omitempty"`
// KeyVaultUri: Uri of KeyVault
KeyVaultUri *string `json:"keyVaultUri,omitempty"`
// KeyVersion: Key Version
KeyVersion *string `json:"keyVersion,omitempty"`
}
Properties to configure keyVault Properties
type KeyVaultProperties_STATUS ¶
type KeyVaultProperties_STATUS struct {
Identity *UserAssignedIdentityProperties_STATUS `json:"identity,omitempty"`
// KeyName: Name of the Key from KeyVault
KeyName *string `json:"keyName,omitempty"`
// KeyVaultUri: Uri of KeyVault
KeyVaultUri *string `json:"keyVaultUri,omitempty"`
// KeyVersion: Key Version
KeyVersion *string `json:"keyVersion,omitempty"`
}
Properties to configure keyVault Properties
type Namespace_Properties_STATUS ¶
type Namespace_Properties_STATUS struct {
// AlternateName: Alternate name specified when alias and namespace names are same.
AlternateName *string `json:"alternateName,omitempty"`
// ClusterArmId: Cluster ARM ID of the Namespace.
ClusterArmId *string `json:"clusterArmId,omitempty"`
// CreatedAt: The time the Namespace was created.
CreatedAt *string `json:"createdAt,omitempty"`
// DisableLocalAuth: This property disables SAS authentication for the Event Hubs namespace.
DisableLocalAuth *bool `json:"disableLocalAuth,omitempty"`
// Encryption: Properties of BYOK Encryption description
Encryption *Encryption_STATUS `json:"encryption,omitempty"`
// IsAutoInflateEnabled: Value that indicates whether AutoInflate is enabled for eventhub namespace.
IsAutoInflateEnabled *bool `json:"isAutoInflateEnabled,omitempty"`
// KafkaEnabled: Value that indicates whether Kafka is enabled for eventhub namespace.
KafkaEnabled *bool `json:"kafkaEnabled,omitempty"`
// MaximumThroughputUnits: Upper limit of throughput units when AutoInflate is enabled, value should be within 0 to 20
// throughput units. ( '0' if AutoInflateEnabled = true)
MaximumThroughputUnits *int `json:"maximumThroughputUnits,omitempty"`
// MetricId: Identifier for Azure Insights metrics.
MetricId *string `json:"metricId,omitempty"`
// PrivateEndpointConnections: List of private endpoint connections.
PrivateEndpointConnections []PrivateEndpointConnection_STATUS `json:"privateEndpointConnections,omitempty"`
// ProvisioningState: Provisioning state of the Namespace.
ProvisioningState *string `json:"provisioningState,omitempty"`
// ServiceBusEndpoint: Endpoint you can use to perform Service Bus operations.
ServiceBusEndpoint *string `json:"serviceBusEndpoint,omitempty"`
// Status: Status of the Namespace.
Status *string `json:"status,omitempty"`
// UpdatedAt: The time the Namespace was updated.
UpdatedAt *string `json:"updatedAt,omitempty"`
// ZoneRedundant: Enabling this property creates a Standard Event Hubs Namespace in regions supported availability zones.
ZoneRedundant *bool `json:"zoneRedundant,omitempty"`
}
type Namespace_Properties_Spec ¶
type Namespace_Properties_Spec struct {
// AlternateName: Alternate name specified when alias and namespace names are same.
AlternateName *string `json:"alternateName,omitempty"`
ClusterArmId *string `json:"clusterArmId,omitempty"`
// DisableLocalAuth: This property disables SAS authentication for the Event Hubs namespace.
DisableLocalAuth *bool `json:"disableLocalAuth,omitempty"`
// Encryption: Properties of BYOK Encryption description
Encryption *Encryption `json:"encryption,omitempty"`
// IsAutoInflateEnabled: Value that indicates whether AutoInflate is enabled for eventhub namespace.
IsAutoInflateEnabled *bool `json:"isAutoInflateEnabled,omitempty"`
// KafkaEnabled: Value that indicates whether Kafka is enabled for eventhub namespace.
KafkaEnabled *bool `json:"kafkaEnabled,omitempty"`
// MaximumThroughputUnits: Upper limit of throughput units when AutoInflate is enabled, value should be within 0 to 20
// throughput units. ( '0' if AutoInflateEnabled = true)
MaximumThroughputUnits *int `json:"maximumThroughputUnits,omitempty"`
// ZoneRedundant: Enabling this property creates a Standard Event Hubs Namespace in regions supported availability zones.
ZoneRedundant *bool `json:"zoneRedundant,omitempty"`
}
type Namespace_STATUS ¶
type Namespace_STATUS struct {
// Id: Fully qualified resource ID for the resource. Ex -
// /subscriptions/{subscriptionId}/resourceGroups/{resourceGroupName}/providers/{resourceProviderNamespace}/{resourceType}/{resourceName}
Id *string `json:"id,omitempty"`
// Identity: Properties of BYOK Identity description
Identity *Identity_STATUS `json:"identity,omitempty"`
// Location: Resource location.
Location *string `json:"location,omitempty"`
// Name: The name of the resource
Name *string `json:"name,omitempty"`
// Properties: Namespace properties supplied for create namespace operation.
Properties *Namespace_Properties_STATUS `json:"properties,omitempty"`
// Sku: Properties of sku resource
Sku *Sku_STATUS `json:"sku,omitempty"`
// SystemData: The system meta data relating to this resource.
SystemData *SystemData_STATUS `json:"systemData,omitempty"`
// Tags: Resource tags.
Tags map[string]string `json:"tags,omitempty"`
// Type: The type of the resource. E.g. "Microsoft.Compute/virtualMachines" or "Microsoft.Storage/storageAccounts"
Type *string `json:"type,omitempty"`
}
type Namespace_Spec ¶
type Namespace_Spec struct {
// Identity: Properties of BYOK Identity description
Identity *Identity `json:"identity,omitempty"`
// Location: Resource location.
Location *string `json:"location,omitempty"`
Name string `json:"name,omitempty"`
// Properties: Namespace properties supplied for create namespace operation.
Properties *Namespace_Properties_Spec `json:"properties,omitempty"`
// Sku: Properties of sku resource
Sku *Sku `json:"sku,omitempty"`
// Tags: Resource tags.
Tags map[string]string `json:"tags,omitempty"`
}
func (Namespace_Spec) GetAPIVersion ¶
func (namespace Namespace_Spec) GetAPIVersion() string
GetAPIVersion returns the ARM API version of the resource. This is always "2021-11-01"
func (*Namespace_Spec) GetName ¶
func (namespace *Namespace_Spec) GetName() string
GetName returns the Name of the resource
func (*Namespace_Spec) GetType ¶
func (namespace *Namespace_Spec) GetType() string
GetType returns the ARM Type of the resource. This is always "Microsoft.EventHub/namespaces"
type NamespacesAuthorizationRule_STATUS ¶
type NamespacesAuthorizationRule_STATUS struct {
// Id: Fully qualified resource ID for the resource. Ex -
// /subscriptions/{subscriptionId}/resourceGroups/{resourceGroupName}/providers/{resourceProviderNamespace}/{resourceType}/{resourceName}
Id *string `json:"id,omitempty"`
// Location: The geo-location where the resource lives
Location *string `json:"location,omitempty"`
// Name: The name of the resource
Name *string `json:"name,omitempty"`
// Properties: Properties supplied to create or update AuthorizationRule
Properties *Namespaces_AuthorizationRule_Properties_STATUS `json:"properties,omitempty"`
// SystemData: The system meta data relating to this resource.
SystemData *SystemData_STATUS `json:"systemData,omitempty"`
// Type: The type of the resource. E.g. "Microsoft.EventHub/Namespaces" or "Microsoft.EventHub/Namespaces/EventHubs"
Type *string `json:"type,omitempty"`
}
type NamespacesAuthorizationRule_Spec ¶
type NamespacesAuthorizationRule_Spec struct {
Name string `json:"name,omitempty"`
// Properties: Properties supplied to create or update AuthorizationRule
Properties *Namespaces_AuthorizationRule_Properties_Spec `json:"properties,omitempty"`
}
func (NamespacesAuthorizationRule_Spec) GetAPIVersion ¶
func (rule NamespacesAuthorizationRule_Spec) GetAPIVersion() string
GetAPIVersion returns the ARM API version of the resource. This is always "2021-11-01"
func (*NamespacesAuthorizationRule_Spec) GetName ¶
func (rule *NamespacesAuthorizationRule_Spec) GetName() string
GetName returns the Name of the resource
func (*NamespacesAuthorizationRule_Spec) GetType ¶
func (rule *NamespacesAuthorizationRule_Spec) GetType() string
GetType returns the ARM Type of the resource. This is always "Microsoft.EventHub/namespaces/authorizationRules"
type NamespacesEventhub_STATUS ¶
type NamespacesEventhub_STATUS struct {
// Id: Fully qualified resource ID for the resource. Ex -
// /subscriptions/{subscriptionId}/resourceGroups/{resourceGroupName}/providers/{resourceProviderNamespace}/{resourceType}/{resourceName}
Id *string `json:"id,omitempty"`
// Location: The geo-location where the resource lives
Location *string `json:"location,omitempty"`
// Name: The name of the resource
Name *string `json:"name,omitempty"`
// Properties: Properties supplied to the Create Or Update Event Hub operation.
Properties *Namespaces_Eventhub_Properties_STATUS `json:"properties,omitempty"`
// SystemData: The system meta data relating to this resource.
SystemData *SystemData_STATUS `json:"systemData,omitempty"`
// Type: The type of the resource. E.g. "Microsoft.EventHub/Namespaces" or "Microsoft.EventHub/Namespaces/EventHubs"
Type *string `json:"type,omitempty"`
}
type NamespacesEventhub_Spec ¶
type NamespacesEventhub_Spec struct {
Name string `json:"name,omitempty"`
// Properties: Properties supplied to the Create Or Update Event Hub operation.
Properties *Namespaces_Eventhub_Properties_Spec `json:"properties,omitempty"`
}
func (NamespacesEventhub_Spec) GetAPIVersion ¶
func (eventhub NamespacesEventhub_Spec) GetAPIVersion() string
GetAPIVersion returns the ARM API version of the resource. This is always "2021-11-01"
func (*NamespacesEventhub_Spec) GetName ¶
func (eventhub *NamespacesEventhub_Spec) GetName() string
GetName returns the Name of the resource
func (*NamespacesEventhub_Spec) GetType ¶
func (eventhub *NamespacesEventhub_Spec) GetType() string
GetType returns the ARM Type of the resource. This is always "Microsoft.EventHub/namespaces/eventhubs"
type NamespacesEventhubsAuthorizationRule_STATUS ¶
type NamespacesEventhubsAuthorizationRule_STATUS struct {
// Id: Fully qualified resource ID for the resource. Ex -
// /subscriptions/{subscriptionId}/resourceGroups/{resourceGroupName}/providers/{resourceProviderNamespace}/{resourceType}/{resourceName}
Id *string `json:"id,omitempty"`
// Location: The geo-location where the resource lives
Location *string `json:"location,omitempty"`
// Name: The name of the resource
Name *string `json:"name,omitempty"`
// Properties: Properties supplied to create or update AuthorizationRule
Properties *Namespaces_Eventhubs_AuthorizationRule_Properties_STATUS `json:"properties,omitempty"`
// SystemData: The system meta data relating to this resource.
SystemData *SystemData_STATUS `json:"systemData,omitempty"`
// Type: The type of the resource. E.g. "Microsoft.EventHub/Namespaces" or "Microsoft.EventHub/Namespaces/EventHubs"
Type *string `json:"type,omitempty"`
}
type NamespacesEventhubsAuthorizationRule_Spec ¶
type NamespacesEventhubsAuthorizationRule_Spec struct {
Name string `json:"name,omitempty"`
// Properties: Properties supplied to create or update AuthorizationRule
Properties *Namespaces_Eventhubs_AuthorizationRule_Properties_Spec `json:"properties,omitempty"`
}
func (NamespacesEventhubsAuthorizationRule_Spec) GetAPIVersion ¶
func (rule NamespacesEventhubsAuthorizationRule_Spec) GetAPIVersion() string
GetAPIVersion returns the ARM API version of the resource. This is always "2021-11-01"
func (*NamespacesEventhubsAuthorizationRule_Spec) GetName ¶
func (rule *NamespacesEventhubsAuthorizationRule_Spec) GetName() string
GetName returns the Name of the resource
func (*NamespacesEventhubsAuthorizationRule_Spec) GetType ¶
func (rule *NamespacesEventhubsAuthorizationRule_Spec) GetType() string
GetType returns the ARM Type of the resource. This is always "Microsoft.EventHub/namespaces/eventhubs/authorizationRules"
type NamespacesEventhubsConsumerGroup_STATUS ¶
type NamespacesEventhubsConsumerGroup_STATUS struct {
// Id: Fully qualified resource ID for the resource. Ex -
// /subscriptions/{subscriptionId}/resourceGroups/{resourceGroupName}/providers/{resourceProviderNamespace}/{resourceType}/{resourceName}
Id *string `json:"id,omitempty"`
// Location: The geo-location where the resource lives
Location *string `json:"location,omitempty"`
// Name: The name of the resource
Name *string `json:"name,omitempty"`
// Properties: Single item in List or Get Consumer group operation
Properties *Namespaces_Eventhubs_Consumergroup_Properties_STATUS `json:"properties,omitempty"`
// SystemData: The system meta data relating to this resource.
SystemData *SystemData_STATUS `json:"systemData,omitempty"`
// Type: The type of the resource. E.g. "Microsoft.EventHub/Namespaces" or "Microsoft.EventHub/Namespaces/EventHubs"
Type *string `json:"type,omitempty"`
}
type NamespacesEventhubsConsumerGroup_Spec ¶
type NamespacesEventhubsConsumerGroup_Spec struct {
Name string `json:"name,omitempty"`
// Properties: Single item in List or Get Consumer group operation
Properties *Namespaces_Eventhubs_Consumergroup_Properties_Spec `json:"properties,omitempty"`
}
func (NamespacesEventhubsConsumerGroup_Spec) GetAPIVersion ¶
func (group NamespacesEventhubsConsumerGroup_Spec) GetAPIVersion() string
GetAPIVersion returns the ARM API version of the resource. This is always "2021-11-01"
func (*NamespacesEventhubsConsumerGroup_Spec) GetName ¶
func (group *NamespacesEventhubsConsumerGroup_Spec) GetName() string
GetName returns the Name of the resource
func (*NamespacesEventhubsConsumerGroup_Spec) GetType ¶
func (group *NamespacesEventhubsConsumerGroup_Spec) GetType() string
GetType returns the ARM Type of the resource. This is always "Microsoft.EventHub/namespaces/eventhubs/consumergroups"
type Namespaces_AuthorizationRule_Properties_Rights_STATUS ¶
type Namespaces_AuthorizationRule_Properties_Rights_STATUS string
type Namespaces_AuthorizationRule_Properties_Rights_Spec ¶
type Namespaces_AuthorizationRule_Properties_Rights_Spec string
+kubebuilder:validation:Enum={"Listen","Manage","Send"}
type Namespaces_AuthorizationRule_Properties_STATUS ¶
type Namespaces_AuthorizationRule_Properties_STATUS struct {
// Rights: The rights associated with the rule.
Rights []Namespaces_AuthorizationRule_Properties_Rights_STATUS `json:"rights,omitempty"`
}
type Namespaces_AuthorizationRule_Properties_Spec ¶
type Namespaces_AuthorizationRule_Properties_Spec struct {
// Rights: The rights associated with the rule.
Rights []Namespaces_AuthorizationRule_Properties_Rights_Spec `json:"rights,omitempty"`
}
type Namespaces_Eventhub_Properties_STATUS ¶
type Namespaces_Eventhub_Properties_STATUS struct {
// CaptureDescription: Properties of capture description
CaptureDescription *CaptureDescription_STATUS `json:"captureDescription,omitempty"`
// CreatedAt: Exact time the Event Hub was created.
CreatedAt *string `json:"createdAt,omitempty"`
// MessageRetentionInDays: Number of days to retain the events for this Event Hub, value should be 1 to 7 days
MessageRetentionInDays *int `json:"messageRetentionInDays,omitempty"`
// PartitionCount: Number of partitions created for the Event Hub, allowed values are from 1 to 32 partitions.
PartitionCount *int `json:"partitionCount,omitempty"`
// PartitionIds: Current number of shards on the Event Hub.
PartitionIds []string `json:"partitionIds,omitempty"`
// Status: Enumerates the possible values for the status of the Event Hub.
Status *Namespaces_Eventhub_Properties_Status_STATUS `json:"status,omitempty"`
// UpdatedAt: The exact time the message was updated.
UpdatedAt *string `json:"updatedAt,omitempty"`
}
type Namespaces_Eventhub_Properties_Spec ¶
type Namespaces_Eventhub_Properties_Spec struct {
// CaptureDescription: Properties of capture description
CaptureDescription *CaptureDescription `json:"captureDescription,omitempty"`
// MessageRetentionInDays: Number of days to retain the events for this Event Hub, value should be 1 to 7 days
MessageRetentionInDays *int `json:"messageRetentionInDays,omitempty"`
// PartitionCount: Number of partitions created for the Event Hub, allowed values are from 1 to 32 partitions.
PartitionCount *int `json:"partitionCount,omitempty"`
}
type Namespaces_Eventhub_Properties_Status_STATUS ¶
type Namespaces_Eventhub_Properties_Status_STATUS string
type Namespaces_Eventhubs_AuthorizationRule_Properties_Rights_STATUS ¶
type Namespaces_Eventhubs_AuthorizationRule_Properties_Rights_STATUS string
type Namespaces_Eventhubs_AuthorizationRule_Properties_Rights_Spec ¶
type Namespaces_Eventhubs_AuthorizationRule_Properties_Rights_Spec string
+kubebuilder:validation:Enum={"Listen","Manage","Send"}
type Namespaces_Eventhubs_AuthorizationRule_Properties_STATUS ¶
type Namespaces_Eventhubs_AuthorizationRule_Properties_STATUS struct {
// Rights: The rights associated with the rule.
Rights []Namespaces_Eventhubs_AuthorizationRule_Properties_Rights_STATUS `json:"rights,omitempty"`
}
type Namespaces_Eventhubs_AuthorizationRule_Properties_Spec ¶
type Namespaces_Eventhubs_AuthorizationRule_Properties_Spec struct {
// Rights: The rights associated with the rule.
Rights []Namespaces_Eventhubs_AuthorizationRule_Properties_Rights_Spec `json:"rights,omitempty"`
}
type Namespaces_Eventhubs_Consumergroup_Properties_STATUS ¶
type Namespaces_Eventhubs_Consumergroup_Properties_STATUS struct {
// CreatedAt: Exact time the message was created.
CreatedAt *string `json:"createdAt,omitempty"`
// UpdatedAt: The exact time the message was updated.
UpdatedAt *string `json:"updatedAt,omitempty"`
// UserMetadata: User Metadata is a placeholder to store user-defined string data with maximum length 1024. e.g. it can be
// used to store descriptive data, such as list of teams and their contact information also user-defined configuration
// settings can be stored.
UserMetadata *string `json:"userMetadata,omitempty"`
}
type Namespaces_Eventhubs_Consumergroup_Properties_Spec ¶
type Namespaces_Eventhubs_Consumergroup_Properties_Spec struct {
// UserMetadata: User Metadata is a placeholder to store user-defined string data with maximum length 1024. e.g. it can be
// used to store descriptive data, such as list of teams and their contact information also user-defined configuration
// settings can be stored.
UserMetadata *string `json:"userMetadata,omitempty"`
}
type PrivateEndpointConnection_STATUS ¶
type PrivateEndpointConnection_STATUS struct {
// Id: Fully qualified resource ID for the resource. Ex -
// /subscriptions/{subscriptionId}/resourceGroups/{resourceGroupName}/providers/{resourceProviderNamespace}/{resourceType}/{resourceName}
Id *string `json:"id,omitempty"`
}
Properties of the PrivateEndpointConnection.
type Sku ¶
type Sku struct {
// Capacity: The Event Hubs throughput units for Basic or Standard tiers, where value should be 0 to 20 throughput units.
// The Event Hubs premium units for Premium tier, where value should be 0 to 10 premium units.
Capacity *int `json:"capacity,omitempty"`
// Name: Name of this SKU.
Name *Sku_Name `json:"name,omitempty"`
// Tier: The billing tier of this particular SKU.
Tier *Sku_Tier `json:"tier,omitempty"`
}
SKU parameters supplied to the create namespace operation
type Sku_Name_STATUS ¶
type Sku_Name_STATUS string
type Sku_STATUS ¶
type Sku_STATUS struct {
// Capacity: The Event Hubs throughput units for Basic or Standard tiers, where value should be 0 to 20 throughput units.
// The Event Hubs premium units for Premium tier, where value should be 0 to 10 premium units.
Capacity *int `json:"capacity,omitempty"`
// Name: Name of this SKU.
Name *Sku_Name_STATUS `json:"name,omitempty"`
// Tier: The billing tier of this particular SKU.
Tier *Sku_Tier_STATUS `json:"tier,omitempty"`
}
SKU parameters supplied to the create namespace operation
type Sku_Tier_STATUS ¶
type Sku_Tier_STATUS string
type SystemData_CreatedByType_STATUS ¶
type SystemData_CreatedByType_STATUS string
type SystemData_LastModifiedByType_STATUS ¶
type SystemData_LastModifiedByType_STATUS string
type SystemData_STATUS ¶
type SystemData_STATUS struct {
// CreatedAt: The timestamp of resource creation (UTC).
CreatedAt *string `json:"createdAt,omitempty"`
// CreatedBy: The identity that created the resource.
CreatedBy *string `json:"createdBy,omitempty"`
// CreatedByType: The type of identity that created the resource.
CreatedByType *SystemData_CreatedByType_STATUS `json:"createdByType,omitempty"`
// LastModifiedAt: The type of identity that last modified the resource.
LastModifiedAt *string `json:"lastModifiedAt,omitempty"`
// LastModifiedBy: The identity that last modified the resource.
LastModifiedBy *string `json:"lastModifiedBy,omitempty"`
// LastModifiedByType: The type of identity that last modified the resource.
LastModifiedByType *SystemData_LastModifiedByType_STATUS `json:"lastModifiedByType,omitempty"`
}
Metadata pertaining to creation and last modification of the resource.
type UserAssignedIdentityDetails ¶
type UserAssignedIdentityDetails struct {
}
Information about the user assigned identity for the resource
type UserAssignedIdentityProperties ¶
type UserAssignedIdentityProperties struct {
UserAssignedIdentity *string `json:"userAssignedIdentity,omitempty"`
}
type UserAssignedIdentityProperties_STATUS ¶
type UserAssignedIdentityProperties_STATUS struct {
// UserAssignedIdentity: ARM ID of user Identity selected for encryption
UserAssignedIdentity *string `json:"userAssignedIdentity,omitempty"`
}
type UserAssignedIdentity_STATUS ¶
type UserAssignedIdentity_STATUS struct {
// ClientId: Client Id of user assigned identity
ClientId *string `json:"clientId,omitempty"`
// PrincipalId: Principal Id of user assigned identity
PrincipalId *string `json:"principalId,omitempty"`
}
Recognized Dictionary value.
Source Files
¶
- namespace_spec_types_gen.go
- namespace_status_types_gen.go
- namespaces_authorization_rule_spec_types_gen.go
- namespaces_authorization_rule_status_types_gen.go
- namespaces_eventhub_spec_types_gen.go
- namespaces_eventhub_status_types_gen.go
- namespaces_eventhubs_authorization_rule_spec_types_gen.go
- namespaces_eventhubs_authorization_rule_status_types_gen.go
- namespaces_eventhubs_consumer_group_spec_types_gen.go
- namespaces_eventhubs_consumer_group_status_types_gen.go