Documentation
¶
Overview ¶
Code generated by azure-service-operator-codegen. DO NOT EDIT. Copyright (c) Microsoft Corporation. Licensed under the MIT license.
Code generated by azure-service-operator-codegen. DO NOT EDIT. Copyright (c) Microsoft Corporation. Licensed under the MIT license.
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type FederatedIdentityCredentialProperties ¶
type FederatedIdentityCredentialProperties struct {
// Audiences: The list of audiences that can appear in the issued token.
Audiences []string `json:"audiences,omitempty"`
// Issuer: The URL of the issuer to be trusted.
Issuer *string `json:"issuer,omitempty" optionalConfigMapPair:"Issuer"`
// Subject: The identifier of the external identity.
Subject *string `json:"subject,omitempty" optionalConfigMapPair:"Subject"`
}
The properties associated with a federated identity credential.
type FederatedIdentityCredentialProperties_STATUS ¶
type FederatedIdentityCredentialProperties_STATUS struct {
// Audiences: The list of audiences that can appear in the issued token.
Audiences []string `json:"audiences,omitempty"`
// Issuer: The URL of the issuer to be trusted.
Issuer *string `json:"issuer,omitempty"`
// Subject: The identifier of the external identity.
Subject *string `json:"subject,omitempty"`
}
The properties associated with a federated identity credential.
type FederatedIdentityCredential_STATUS ¶
type FederatedIdentityCredential_STATUS struct {
// Id: Fully qualified resource ID for the resource. Ex -
// /subscriptions/{subscriptionId}/resourceGroups/{resourceGroupName}/providers/{resourceProviderNamespace}/{resourceType}/{resourceName}
Id *string `json:"id,omitempty"`
// Name: The name of the resource
Name *string `json:"name,omitempty"`
// Properties: The properties associated with the federated identity credential.
Properties *FederatedIdentityCredentialProperties_STATUS `json:"properties,omitempty"`
// Type: The type of the resource. E.g. "Microsoft.Compute/virtualMachines" or "Microsoft.Storage/storageAccounts"
Type *string `json:"type,omitempty"`
}
type FederatedIdentityCredential_Spec ¶
type FederatedIdentityCredential_Spec struct {
Name string `json:"name,omitempty"`
// Properties: The properties associated with the federated identity credential.
Properties *FederatedIdentityCredentialProperties `json:"properties,omitempty"`
}
func (FederatedIdentityCredential_Spec) GetAPIVersion ¶
func (credential FederatedIdentityCredential_Spec) GetAPIVersion() string
GetAPIVersion returns the ARM API version of the resource. This is always "2022-01-31-preview"
func (*FederatedIdentityCredential_Spec) GetName ¶
func (credential *FederatedIdentityCredential_Spec) GetName() string
GetName returns the Name of the resource
func (*FederatedIdentityCredential_Spec) GetType ¶
func (credential *FederatedIdentityCredential_Spec) GetType() string
GetType returns the ARM Type of the resource. This is always "Microsoft.ManagedIdentity/userAssignedIdentities/federatedIdentityCredentials"