Documentation
¶
Overview ¶
Code generated by azure-service-operator-codegen. DO NOT EDIT. Copyright (c) Microsoft Corporation. Licensed under the MIT license.
Code generated by azure-service-operator-codegen. DO NOT EDIT. Copyright (c) Microsoft Corporation. Licensed under the MIT license.
Code generated by azure-service-operator-codegen. DO NOT EDIT. Copyright (c) Microsoft Corporation. Licensed under the MIT license.
Code generated by azure-service-operator-codegen. DO NOT EDIT. Copyright (c) Microsoft Corporation. Licensed under the MIT license.
Code generated by azure-service-operator-codegen. DO NOT EDIT. Copyright (c) Microsoft Corporation. Licensed under the MIT license.
Code generated by azure-service-operator-codegen. DO NOT EDIT. Copyright (c) Microsoft Corporation. Licensed under the MIT license.
Code generated by azure-service-operator-codegen. DO NOT EDIT. Copyright (c) Microsoft Corporation. Licensed under the MIT license.
Code generated by azure-service-operator-codegen. DO NOT EDIT. Copyright (c) Microsoft Corporation. Licensed under the MIT license.
Index ¶
- Constants
- type AllowedEndpointRecordType
- type AllowedEndpointRecordType_STATUS
- type DnsConfig
- type DnsConfig_STATUS
- type EndpointProperties
- type EndpointProperties_AlwaysServe
- type EndpointProperties_AlwaysServe_STATUS
- type EndpointProperties_CustomHeaders
- type EndpointProperties_CustomHeaders_STATUS
- type EndpointProperties_EndpointMonitorStatus
- type EndpointProperties_EndpointMonitorStatus_STATUS
- type EndpointProperties_EndpointStatus
- type EndpointProperties_EndpointStatus_STATUS
- type EndpointProperties_STATUS
- type EndpointProperties_Subnets
- type EndpointProperties_Subnets_STATUS
- type Endpoint_STATUS
- type MonitorConfig
- type MonitorConfig_CustomHeaders
- type MonitorConfig_CustomHeaders_STATUS
- type MonitorConfig_ExpectedStatusCodeRanges
- type MonitorConfig_ExpectedStatusCodeRanges_STATUS
- type MonitorConfig_ProfileMonitorStatus
- type MonitorConfig_ProfileMonitorStatus_STATUS
- type MonitorConfig_Protocol
- type MonitorConfig_Protocol_STATUS
- type MonitorConfig_STATUS
- type ProfileProperties
- type ProfileProperties_ProfileStatus
- type ProfileProperties_ProfileStatus_STATUS
- type ProfileProperties_STATUS
- type ProfileProperties_TrafficRoutingMethod
- type ProfileProperties_TrafficRoutingMethod_STATUS
- type ProfileProperties_TrafficViewEnrollmentStatus
- type ProfileProperties_TrafficViewEnrollmentStatus_STATUS
- type TrafficManagerProfile_STATUS
- type TrafficManagerProfile_Spec
- type TrafficManagerProfilesAzureEndpoint_STATUS
- type TrafficManagerProfilesAzureEndpoint_Spec
- type TrafficManagerProfilesExternalEndpoint_STATUS
- type TrafficManagerProfilesExternalEndpoint_Spec
- type TrafficManagerProfilesNestedEndpoint_STATUS
- type TrafficManagerProfilesNestedEndpoint_Spec
Constants ¶
const ( AllowedEndpointRecordType_Any = AllowedEndpointRecordType("Any") AllowedEndpointRecordType_DomainName = AllowedEndpointRecordType("DomainName") AllowedEndpointRecordType_IPv4Address = AllowedEndpointRecordType("IPv4Address") AllowedEndpointRecordType_IPv6Address = AllowedEndpointRecordType("IPv6Address") )
const ( ProfileProperties_ProfileStatus_Disabled = ProfileProperties_ProfileStatus("Disabled") ProfileProperties_ProfileStatus_Enabled = ProfileProperties_ProfileStatus("Enabled") )
const ( ProfileProperties_TrafficRoutingMethod_Geographic = ProfileProperties_TrafficRoutingMethod("Geographic") ProfileProperties_TrafficRoutingMethod_MultiValue = ProfileProperties_TrafficRoutingMethod("MultiValue") ProfileProperties_TrafficRoutingMethod_Performance = ProfileProperties_TrafficRoutingMethod("Performance") ProfileProperties_TrafficRoutingMethod_Priority = ProfileProperties_TrafficRoutingMethod("Priority") ProfileProperties_TrafficRoutingMethod_Subnet = ProfileProperties_TrafficRoutingMethod("Subnet") ProfileProperties_TrafficRoutingMethod_Weighted = ProfileProperties_TrafficRoutingMethod("Weighted") )
const ( ProfileProperties_TrafficViewEnrollmentStatus_Disabled = ProfileProperties_TrafficViewEnrollmentStatus("Disabled") ProfileProperties_TrafficViewEnrollmentStatus_Enabled = ProfileProperties_TrafficViewEnrollmentStatus("Enabled") )
const ( MonitorConfig_ProfileMonitorStatus_CheckingEndpoints = MonitorConfig_ProfileMonitorStatus("CheckingEndpoints") MonitorConfig_ProfileMonitorStatus_Degraded = MonitorConfig_ProfileMonitorStatus("Degraded") MonitorConfig_ProfileMonitorStatus_Disabled = MonitorConfig_ProfileMonitorStatus("Disabled") MonitorConfig_ProfileMonitorStatus_Inactive = MonitorConfig_ProfileMonitorStatus("Inactive") MonitorConfig_ProfileMonitorStatus_Online = MonitorConfig_ProfileMonitorStatus("Online") )
const ( MonitorConfig_Protocol_HTTP = MonitorConfig_Protocol("HTTP") MonitorConfig_Protocol_HTTPS = MonitorConfig_Protocol("HTTPS") MonitorConfig_Protocol_TCP = MonitorConfig_Protocol("TCP") )
const ( AllowedEndpointRecordType_STATUS_Any = AllowedEndpointRecordType_STATUS("Any") AllowedEndpointRecordType_STATUS_DomainName = AllowedEndpointRecordType_STATUS("DomainName") AllowedEndpointRecordType_STATUS_IPv4Address = AllowedEndpointRecordType_STATUS("IPv4Address") AllowedEndpointRecordType_STATUS_IPv6Address = AllowedEndpointRecordType_STATUS("IPv6Address") )
const ( ProfileProperties_ProfileStatus_STATUS_Disabled = ProfileProperties_ProfileStatus_STATUS("Disabled") ProfileProperties_ProfileStatus_STATUS_Enabled = ProfileProperties_ProfileStatus_STATUS("Enabled") )
const ( ProfileProperties_TrafficRoutingMethod_STATUS_Geographic = ProfileProperties_TrafficRoutingMethod_STATUS("Geographic") ProfileProperties_TrafficRoutingMethod_STATUS_MultiValue = ProfileProperties_TrafficRoutingMethod_STATUS("MultiValue") ProfileProperties_TrafficRoutingMethod_STATUS_Performance = ProfileProperties_TrafficRoutingMethod_STATUS("Performance") ProfileProperties_TrafficRoutingMethod_STATUS_Priority = ProfileProperties_TrafficRoutingMethod_STATUS("Priority") ProfileProperties_TrafficRoutingMethod_STATUS_Subnet = ProfileProperties_TrafficRoutingMethod_STATUS("Subnet") ProfileProperties_TrafficRoutingMethod_STATUS_Weighted = ProfileProperties_TrafficRoutingMethod_STATUS("Weighted") )
const ( ProfileProperties_TrafficViewEnrollmentStatus_STATUS_Disabled = ProfileProperties_TrafficViewEnrollmentStatus_STATUS("Disabled") ProfileProperties_TrafficViewEnrollmentStatus_STATUS_Enabled = ProfileProperties_TrafficViewEnrollmentStatus_STATUS("Enabled") )
const ( MonitorConfig_ProfileMonitorStatus_STATUS_CheckingEndpoints = MonitorConfig_ProfileMonitorStatus_STATUS("CheckingEndpoints") MonitorConfig_ProfileMonitorStatus_STATUS_Degraded = MonitorConfig_ProfileMonitorStatus_STATUS("Degraded") MonitorConfig_ProfileMonitorStatus_STATUS_Disabled = MonitorConfig_ProfileMonitorStatus_STATUS("Disabled") MonitorConfig_ProfileMonitorStatus_STATUS_Inactive = MonitorConfig_ProfileMonitorStatus_STATUS("Inactive") MonitorConfig_ProfileMonitorStatus_STATUS_Online = MonitorConfig_ProfileMonitorStatus_STATUS("Online") )
const ( MonitorConfig_Protocol_STATUS_HTTP = MonitorConfig_Protocol_STATUS("HTTP") MonitorConfig_Protocol_STATUS_HTTPS = MonitorConfig_Protocol_STATUS("HTTPS") MonitorConfig_Protocol_STATUS_TCP = MonitorConfig_Protocol_STATUS("TCP") )
const ( EndpointProperties_AlwaysServe_Disabled = EndpointProperties_AlwaysServe("Disabled") EndpointProperties_AlwaysServe_Enabled = EndpointProperties_AlwaysServe("Enabled") )
const ( EndpointProperties_EndpointMonitorStatus_CheckingEndpoint = EndpointProperties_EndpointMonitorStatus("CheckingEndpoint") EndpointProperties_EndpointMonitorStatus_Degraded = EndpointProperties_EndpointMonitorStatus("Degraded") EndpointProperties_EndpointMonitorStatus_Disabled = EndpointProperties_EndpointMonitorStatus("Disabled") EndpointProperties_EndpointMonitorStatus_Inactive = EndpointProperties_EndpointMonitorStatus("Inactive") EndpointProperties_EndpointMonitorStatus_Online = EndpointProperties_EndpointMonitorStatus("Online") EndpointProperties_EndpointMonitorStatus_Stopped = EndpointProperties_EndpointMonitorStatus("Stopped") EndpointProperties_EndpointMonitorStatus_Unmonitored = EndpointProperties_EndpointMonitorStatus("Unmonitored") )
const ( EndpointProperties_EndpointStatus_Disabled = EndpointProperties_EndpointStatus("Disabled") EndpointProperties_EndpointStatus_Enabled = EndpointProperties_EndpointStatus("Enabled") )
const ( EndpointProperties_AlwaysServe_STATUS_Disabled = EndpointProperties_AlwaysServe_STATUS("Disabled") EndpointProperties_AlwaysServe_STATUS_Enabled = EndpointProperties_AlwaysServe_STATUS("Enabled") )
const ( EndpointProperties_EndpointMonitorStatus_STATUS_CheckingEndpoint = EndpointProperties_EndpointMonitorStatus_STATUS("CheckingEndpoint") EndpointProperties_EndpointMonitorStatus_STATUS_Degraded = EndpointProperties_EndpointMonitorStatus_STATUS("Degraded") EndpointProperties_EndpointMonitorStatus_STATUS_Disabled = EndpointProperties_EndpointMonitorStatus_STATUS("Disabled") EndpointProperties_EndpointMonitorStatus_STATUS_Inactive = EndpointProperties_EndpointMonitorStatus_STATUS("Inactive") EndpointProperties_EndpointMonitorStatus_STATUS_Online = EndpointProperties_EndpointMonitorStatus_STATUS("Online") EndpointProperties_EndpointMonitorStatus_STATUS_Stopped = EndpointProperties_EndpointMonitorStatus_STATUS("Stopped") EndpointProperties_EndpointMonitorStatus_STATUS_Unmonitored = EndpointProperties_EndpointMonitorStatus_STATUS("Unmonitored") )
const ( EndpointProperties_EndpointStatus_STATUS_Disabled = EndpointProperties_EndpointStatus_STATUS("Disabled") EndpointProperties_EndpointStatus_STATUS_Enabled = EndpointProperties_EndpointStatus_STATUS("Enabled") )
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type AllowedEndpointRecordType ¶
type AllowedEndpointRecordType string
The allowed type DNS record types for this profile. +kubebuilder:validation:Enum={"Any","DomainName","IPv4Address","IPv6Address"}
type AllowedEndpointRecordType_STATUS ¶
type AllowedEndpointRecordType_STATUS string
The allowed type DNS record types for this profile.
type DnsConfig ¶
type DnsConfig struct {
// RelativeName: The relative DNS name provided by this Traffic Manager profile. This value is combined with the DNS domain
// name used by Azure Traffic Manager to form the fully-qualified domain name (FQDN) of the profile.
RelativeName *string `json:"relativeName,omitempty"`
// Ttl: The DNS Time-To-Live (TTL), in seconds. This informs the local DNS resolvers and DNS clients how long to cache DNS
// responses provided by this Traffic Manager profile.
Ttl *int `json:"ttl,omitempty"`
}
Class containing DNS settings in a Traffic Manager profile.
type DnsConfig_STATUS ¶
type DnsConfig_STATUS struct {
// Fqdn: The fully-qualified domain name (FQDN) of the Traffic Manager profile. This is formed from the concatenation of
// the RelativeName with the DNS domain used by Azure Traffic Manager.
Fqdn *string `json:"fqdn,omitempty"`
// RelativeName: The relative DNS name provided by this Traffic Manager profile. This value is combined with the DNS domain
// name used by Azure Traffic Manager to form the fully-qualified domain name (FQDN) of the profile.
RelativeName *string `json:"relativeName,omitempty"`
// Ttl: The DNS Time-To-Live (TTL), in seconds. This informs the local DNS resolvers and DNS clients how long to cache DNS
// responses provided by this Traffic Manager profile.
Ttl *int `json:"ttl,omitempty"`
}
Class containing DNS settings in a Traffic Manager profile.
type EndpointProperties ¶
type EndpointProperties struct {
// AlwaysServe: If Always Serve is enabled, probing for endpoint health will be disabled and endpoints will be included in
// the traffic routing method.
AlwaysServe *EndpointProperties_AlwaysServe `json:"alwaysServe,omitempty"`
// CustomHeaders: List of custom headers.
CustomHeaders []EndpointProperties_CustomHeaders `json:"customHeaders,omitempty"`
// EndpointLocation: Specifies the location of the external or nested endpoints when using the 'Performance' traffic
// routing method.
EndpointLocation *string `json:"endpointLocation,omitempty"`
// EndpointMonitorStatus: The monitoring status of the endpoint.
EndpointMonitorStatus *EndpointProperties_EndpointMonitorStatus `json:"endpointMonitorStatus,omitempty"`
// EndpointStatus: The status of the endpoint. If the endpoint is Enabled, it is probed for endpoint health and is included
// in the traffic routing method.
EndpointStatus *EndpointProperties_EndpointStatus `json:"endpointStatus,omitempty"`
// GeoMapping: The list of countries/regions mapped to this endpoint when using the 'Geographic' traffic routing method.
// Please consult Traffic Manager Geographic documentation for a full list of accepted values.
GeoMapping []string `json:"geoMapping,omitempty"`
// MinChildEndpoints: The minimum number of endpoints that must be available in the child profile in order for the parent
// profile to be considered available. Only applicable to endpoint of type 'NestedEndpoints'.
MinChildEndpoints *int `json:"minChildEndpoints,omitempty"`
// MinChildEndpointsIPv4: The minimum number of IPv4 (DNS record type A) endpoints that must be available in the child
// profile in order for the parent profile to be considered available. Only applicable to endpoint of type
// 'NestedEndpoints'.
MinChildEndpointsIPv4 *int `json:"minChildEndpointsIPv4,omitempty"`
// MinChildEndpointsIPv6: The minimum number of IPv6 (DNS record type AAAA) endpoints that must be available in the child
// profile in order for the parent profile to be considered available. Only applicable to endpoint of type
// 'NestedEndpoints'.
MinChildEndpointsIPv6 *int `json:"minChildEndpointsIPv6,omitempty"`
// Priority: The priority of this endpoint when using the 'Priority' traffic routing method. Possible values are from 1 to
// 1000, lower values represent higher priority. This is an optional parameter. If specified, it must be specified on all
// endpoints, and no two endpoints can share the same priority value.
Priority *int `json:"priority,omitempty"`
// Subnets: The list of subnets, IP addresses, and/or address ranges mapped to this endpoint when using the 'Subnet'
// traffic routing method. An empty list will match all ranges not covered by other endpoints.
Subnets []EndpointProperties_Subnets `json:"subnets,omitempty"`
// Target: The fully-qualified DNS name or IP address of the endpoint. Traffic Manager returns this value in DNS responses
// to direct traffic to this endpoint.
Target *string `json:"target,omitempty"`
TargetResourceId *string `json:"targetResourceId,omitempty"`
// Weight: The weight of this endpoint when using the 'Weighted' traffic routing method. Possible values are from 1 to 1000.
Weight *int `json:"weight,omitempty"`
}
Class representing a Traffic Manager endpoint properties.
type EndpointProperties_AlwaysServe ¶
type EndpointProperties_AlwaysServe string
+kubebuilder:validation:Enum={"Disabled","Enabled"}
type EndpointProperties_AlwaysServe_STATUS ¶
type EndpointProperties_AlwaysServe_STATUS string
type EndpointProperties_EndpointMonitorStatus ¶
type EndpointProperties_EndpointMonitorStatus string
+kubebuilder:validation:Enum={"CheckingEndpoint","Degraded","Disabled","Inactive","Online","Stopped","Unmonitored"}
type EndpointProperties_EndpointMonitorStatus_STATUS ¶
type EndpointProperties_EndpointMonitorStatus_STATUS string
type EndpointProperties_EndpointStatus ¶
type EndpointProperties_EndpointStatus string
+kubebuilder:validation:Enum={"Disabled","Enabled"}
type EndpointProperties_EndpointStatus_STATUS ¶
type EndpointProperties_EndpointStatus_STATUS string
type EndpointProperties_STATUS ¶
type EndpointProperties_STATUS struct {
// AlwaysServe: If Always Serve is enabled, probing for endpoint health will be disabled and endpoints will be included in
// the traffic routing method.
AlwaysServe *EndpointProperties_AlwaysServe_STATUS `json:"alwaysServe,omitempty"`
// CustomHeaders: List of custom headers.
CustomHeaders []EndpointProperties_CustomHeaders_STATUS `json:"customHeaders,omitempty"`
// EndpointLocation: Specifies the location of the external or nested endpoints when using the 'Performance' traffic
// routing method.
EndpointLocation *string `json:"endpointLocation,omitempty"`
// EndpointMonitorStatus: The monitoring status of the endpoint.
EndpointMonitorStatus *EndpointProperties_EndpointMonitorStatus_STATUS `json:"endpointMonitorStatus,omitempty"`
// EndpointStatus: The status of the endpoint. If the endpoint is Enabled, it is probed for endpoint health and is included
// in the traffic routing method.
EndpointStatus *EndpointProperties_EndpointStatus_STATUS `json:"endpointStatus,omitempty"`
// GeoMapping: The list of countries/regions mapped to this endpoint when using the 'Geographic' traffic routing method.
// Please consult Traffic Manager Geographic documentation for a full list of accepted values.
GeoMapping []string `json:"geoMapping,omitempty"`
// MinChildEndpoints: The minimum number of endpoints that must be available in the child profile in order for the parent
// profile to be considered available. Only applicable to endpoint of type 'NestedEndpoints'.
MinChildEndpoints *int `json:"minChildEndpoints,omitempty"`
// MinChildEndpointsIPv4: The minimum number of IPv4 (DNS record type A) endpoints that must be available in the child
// profile in order for the parent profile to be considered available. Only applicable to endpoint of type
// 'NestedEndpoints'.
MinChildEndpointsIPv4 *int `json:"minChildEndpointsIPv4,omitempty"`
// MinChildEndpointsIPv6: The minimum number of IPv6 (DNS record type AAAA) endpoints that must be available in the child
// profile in order for the parent profile to be considered available. Only applicable to endpoint of type
// 'NestedEndpoints'.
MinChildEndpointsIPv6 *int `json:"minChildEndpointsIPv6,omitempty"`
// Priority: The priority of this endpoint when using the 'Priority' traffic routing method. Possible values are from 1 to
// 1000, lower values represent higher priority. This is an optional parameter. If specified, it must be specified on all
// endpoints, and no two endpoints can share the same priority value.
Priority *int `json:"priority,omitempty"`
// Subnets: The list of subnets, IP addresses, and/or address ranges mapped to this endpoint when using the 'Subnet'
// traffic routing method. An empty list will match all ranges not covered by other endpoints.
Subnets []EndpointProperties_Subnets_STATUS `json:"subnets,omitempty"`
// Target: The fully-qualified DNS name or IP address of the endpoint. Traffic Manager returns this value in DNS responses
// to direct traffic to this endpoint.
Target *string `json:"target,omitempty"`
// TargetResourceId: The Azure Resource URI of the of the endpoint. Not applicable to endpoints of type 'ExternalEndpoints'.
TargetResourceId *string `json:"targetResourceId,omitempty"`
// Weight: The weight of this endpoint when using the 'Weighted' traffic routing method. Possible values are from 1 to 1000.
Weight *int `json:"weight,omitempty"`
}
Class representing a Traffic Manager endpoint properties.
type EndpointProperties_Subnets_STATUS ¶
type EndpointProperties_Subnets_STATUS struct {
// First: First address in the subnet.
First *string `json:"first,omitempty"`
// Last: Last address in the subnet.
Last *string `json:"last,omitempty"`
// Scope: Block size (number of leading bits in the subnet mask).
Scope *int `json:"scope,omitempty"`
}
type Endpoint_STATUS ¶
type Endpoint_STATUS struct {
// Id: Fully qualified resource Id for the resource. Ex -
// /subscriptions/{subscriptionId}/resourceGroups/{resourceGroupName}/providers/Microsoft.Network/trafficManagerProfiles/{resourceName}
Id *string `json:"id,omitempty"`
}
Class representing a Traffic Manager endpoint.
type MonitorConfig ¶
type MonitorConfig struct {
// CustomHeaders: List of custom headers.
CustomHeaders []MonitorConfig_CustomHeaders `json:"customHeaders,omitempty"`
// ExpectedStatusCodeRanges: List of expected status code ranges.
ExpectedStatusCodeRanges []MonitorConfig_ExpectedStatusCodeRanges `json:"expectedStatusCodeRanges,omitempty"`
// IntervalInSeconds: The monitor interval for endpoints in this profile. This is the interval at which Traffic Manager
// will check the health of each endpoint in this profile.
IntervalInSeconds *int `json:"intervalInSeconds,omitempty"`
// Path: The path relative to the endpoint domain name used to probe for endpoint health.
Path *string `json:"path,omitempty"`
// Port: The TCP port used to probe for endpoint health.
Port *int `json:"port,omitempty"`
// ProfileMonitorStatus: The profile-level monitoring status of the Traffic Manager profile.
ProfileMonitorStatus *MonitorConfig_ProfileMonitorStatus `json:"profileMonitorStatus,omitempty"`
// Protocol: The protocol (HTTP, HTTPS or TCP) used to probe for endpoint health.
Protocol *MonitorConfig_Protocol `json:"protocol,omitempty"`
// TimeoutInSeconds: The monitor timeout for endpoints in this profile. This is the time that Traffic Manager allows
// endpoints in this profile to response to the health check.
TimeoutInSeconds *int `json:"timeoutInSeconds,omitempty"`
// ToleratedNumberOfFailures: The number of consecutive failed health check that Traffic Manager tolerates before declaring
// an endpoint in this profile Degraded after the next failed health check.
ToleratedNumberOfFailures *int `json:"toleratedNumberOfFailures,omitempty"`
}
Class containing endpoint monitoring settings in a Traffic Manager profile.
type MonitorConfig_ProfileMonitorStatus ¶
type MonitorConfig_ProfileMonitorStatus string
+kubebuilder:validation:Enum={"CheckingEndpoints","Degraded","Disabled","Inactive","Online"}
type MonitorConfig_ProfileMonitorStatus_STATUS ¶
type MonitorConfig_ProfileMonitorStatus_STATUS string
type MonitorConfig_Protocol ¶
type MonitorConfig_Protocol string
+kubebuilder:validation:Enum={"HTTP","HTTPS","TCP"}
type MonitorConfig_Protocol_STATUS ¶
type MonitorConfig_Protocol_STATUS string
type MonitorConfig_STATUS ¶
type MonitorConfig_STATUS struct {
// CustomHeaders: List of custom headers.
CustomHeaders []MonitorConfig_CustomHeaders_STATUS `json:"customHeaders,omitempty"`
// ExpectedStatusCodeRanges: List of expected status code ranges.
ExpectedStatusCodeRanges []MonitorConfig_ExpectedStatusCodeRanges_STATUS `json:"expectedStatusCodeRanges,omitempty"`
// IntervalInSeconds: The monitor interval for endpoints in this profile. This is the interval at which Traffic Manager
// will check the health of each endpoint in this profile.
IntervalInSeconds *int `json:"intervalInSeconds,omitempty"`
// Path: The path relative to the endpoint domain name used to probe for endpoint health.
Path *string `json:"path,omitempty"`
// Port: The TCP port used to probe for endpoint health.
Port *int `json:"port,omitempty"`
// ProfileMonitorStatus: The profile-level monitoring status of the Traffic Manager profile.
ProfileMonitorStatus *MonitorConfig_ProfileMonitorStatus_STATUS `json:"profileMonitorStatus,omitempty"`
// Protocol: The protocol (HTTP, HTTPS or TCP) used to probe for endpoint health.
Protocol *MonitorConfig_Protocol_STATUS `json:"protocol,omitempty"`
// TimeoutInSeconds: The monitor timeout for endpoints in this profile. This is the time that Traffic Manager allows
// endpoints in this profile to response to the health check.
TimeoutInSeconds *int `json:"timeoutInSeconds,omitempty"`
// ToleratedNumberOfFailures: The number of consecutive failed health check that Traffic Manager tolerates before declaring
// an endpoint in this profile Degraded after the next failed health check.
ToleratedNumberOfFailures *int `json:"toleratedNumberOfFailures,omitempty"`
}
Class containing endpoint monitoring settings in a Traffic Manager profile.
type ProfileProperties ¶
type ProfileProperties struct {
// AllowedEndpointRecordTypes: The list of allowed endpoint record types.
AllowedEndpointRecordTypes []AllowedEndpointRecordType `json:"allowedEndpointRecordTypes,omitempty"`
// DnsConfig: The DNS settings of the Traffic Manager profile.
DnsConfig *DnsConfig `json:"dnsConfig,omitempty"`
// MaxReturn: Maximum number of endpoints to be returned for MultiValue routing type.
MaxReturn *int `json:"maxReturn,omitempty"`
// MonitorConfig: The endpoint monitoring settings of the Traffic Manager profile.
MonitorConfig *MonitorConfig `json:"monitorConfig,omitempty"`
// ProfileStatus: The status of the Traffic Manager profile.
ProfileStatus *ProfileProperties_ProfileStatus `json:"profileStatus,omitempty"`
// TrafficRoutingMethod: The traffic routing method of the Traffic Manager profile.
TrafficRoutingMethod *ProfileProperties_TrafficRoutingMethod `json:"trafficRoutingMethod,omitempty"`
// TrafficViewEnrollmentStatus: Indicates whether Traffic View is 'Enabled' or 'Disabled' for the Traffic Manager profile.
// Null, indicates 'Disabled'. Enabling this feature will increase the cost of the Traffic Manage profile.
TrafficViewEnrollmentStatus *ProfileProperties_TrafficViewEnrollmentStatus `json:"trafficViewEnrollmentStatus,omitempty"`
}
Class representing the Traffic Manager profile properties.
type ProfileProperties_ProfileStatus ¶
type ProfileProperties_ProfileStatus string
+kubebuilder:validation:Enum={"Disabled","Enabled"}
type ProfileProperties_ProfileStatus_STATUS ¶
type ProfileProperties_ProfileStatus_STATUS string
type ProfileProperties_STATUS ¶
type ProfileProperties_STATUS struct {
// AllowedEndpointRecordTypes: The list of allowed endpoint record types.
AllowedEndpointRecordTypes []AllowedEndpointRecordType_STATUS `json:"allowedEndpointRecordTypes,omitempty"`
// DnsConfig: The DNS settings of the Traffic Manager profile.
DnsConfig *DnsConfig_STATUS `json:"dnsConfig,omitempty"`
// Endpoints: The list of endpoints in the Traffic Manager profile.
Endpoints []Endpoint_STATUS `json:"endpoints,omitempty"`
// MaxReturn: Maximum number of endpoints to be returned for MultiValue routing type.
MaxReturn *int `json:"maxReturn,omitempty"`
// MonitorConfig: The endpoint monitoring settings of the Traffic Manager profile.
MonitorConfig *MonitorConfig_STATUS `json:"monitorConfig,omitempty"`
// ProfileStatus: The status of the Traffic Manager profile.
ProfileStatus *ProfileProperties_ProfileStatus_STATUS `json:"profileStatus,omitempty"`
// TrafficRoutingMethod: The traffic routing method of the Traffic Manager profile.
TrafficRoutingMethod *ProfileProperties_TrafficRoutingMethod_STATUS `json:"trafficRoutingMethod,omitempty"`
// TrafficViewEnrollmentStatus: Indicates whether Traffic View is 'Enabled' or 'Disabled' for the Traffic Manager profile.
// Null, indicates 'Disabled'. Enabling this feature will increase the cost of the Traffic Manage profile.
TrafficViewEnrollmentStatus *ProfileProperties_TrafficViewEnrollmentStatus_STATUS `json:"trafficViewEnrollmentStatus,omitempty"`
}
Class representing the Traffic Manager profile properties.
type ProfileProperties_TrafficRoutingMethod ¶
type ProfileProperties_TrafficRoutingMethod string
+kubebuilder:validation:Enum={"Geographic","MultiValue","Performance","Priority","Subnet","Weighted"}
type ProfileProperties_TrafficRoutingMethod_STATUS ¶
type ProfileProperties_TrafficRoutingMethod_STATUS string
type ProfileProperties_TrafficViewEnrollmentStatus ¶
type ProfileProperties_TrafficViewEnrollmentStatus string
+kubebuilder:validation:Enum={"Disabled","Enabled"}
type ProfileProperties_TrafficViewEnrollmentStatus_STATUS ¶
type ProfileProperties_TrafficViewEnrollmentStatus_STATUS string
type TrafficManagerProfile_STATUS ¶
type TrafficManagerProfile_STATUS struct {
// Id: Fully qualified resource Id for the resource. Ex -
// /subscriptions/{subscriptionId}/resourceGroups/{resourceGroupName}/providers/Microsoft.Network/trafficManagerProfiles/{resourceName}
Id *string `json:"id,omitempty"`
// Location: The Azure Region where the resource lives
Location *string `json:"location,omitempty"`
// Name: The name of the resource
Name *string `json:"name,omitempty"`
// Properties: The properties of the Traffic Manager profile.
Properties *ProfileProperties_STATUS `json:"properties,omitempty"`
// Tags: Resource tags.
Tags map[string]string `json:"tags,omitempty"`
// Type: The type of the resource. Ex- Microsoft.Network/trafficManagerProfiles.
Type *string `json:"type,omitempty"`
}
type TrafficManagerProfile_Spec ¶
type TrafficManagerProfile_Spec struct {
// Location: The Azure Region where the resource lives
Location *string `json:"location,omitempty"`
// Name: The name of the resource
Name string `json:"name,omitempty"`
// Properties: The properties of the Traffic Manager profile.
Properties *ProfileProperties `json:"properties,omitempty"`
// Tags: Resource tags.
Tags map[string]string `json:"tags,omitempty"`
// Type: The type of the resource. Ex- Microsoft.Network/trafficManagerProfiles.
Type *string `json:"type,omitempty"`
}
func (TrafficManagerProfile_Spec) GetAPIVersion ¶
func (profile TrafficManagerProfile_Spec) GetAPIVersion() string
GetAPIVersion returns the ARM API version of the resource. This is always "2022-04-01"
func (*TrafficManagerProfile_Spec) GetName ¶
func (profile *TrafficManagerProfile_Spec) GetName() string
GetName returns the Name of the resource
func (*TrafficManagerProfile_Spec) GetType ¶
func (profile *TrafficManagerProfile_Spec) GetType() string
GetType returns the ARM Type of the resource. This is always "Microsoft.Network/trafficmanagerprofiles"
type TrafficManagerProfilesAzureEndpoint_STATUS ¶
type TrafficManagerProfilesAzureEndpoint_STATUS struct {
// Id: Fully qualified resource Id for the resource. Ex -
// /subscriptions/{subscriptionId}/resourceGroups/{resourceGroupName}/providers/Microsoft.Network/trafficManagerProfiles/{resourceName}
Id *string `json:"id,omitempty"`
// Name: The name of the resource
Name *string `json:"name,omitempty"`
// Properties: The properties of the Traffic Manager endpoint.
Properties *EndpointProperties_STATUS `json:"properties,omitempty"`
// Type: The type of the resource. Ex- Microsoft.Network/trafficManagerProfiles.
Type *string `json:"type,omitempty"`
}
type TrafficManagerProfilesAzureEndpoint_Spec ¶
type TrafficManagerProfilesAzureEndpoint_Spec struct {
// Name: The name of the resource
Name string `json:"name,omitempty"`
// Properties: The properties of the Traffic Manager endpoint.
Properties *EndpointProperties `json:"properties,omitempty"`
// Type: The type of the resource. Ex- Microsoft.Network/trafficManagerProfiles.
Type *string `json:"type,omitempty"`
}
func (TrafficManagerProfilesAzureEndpoint_Spec) GetAPIVersion ¶
func (endpoint TrafficManagerProfilesAzureEndpoint_Spec) GetAPIVersion() string
GetAPIVersion returns the ARM API version of the resource. This is always "2022-04-01"
func (*TrafficManagerProfilesAzureEndpoint_Spec) GetName ¶
func (endpoint *TrafficManagerProfilesAzureEndpoint_Spec) GetName() string
GetName returns the Name of the resource
func (*TrafficManagerProfilesAzureEndpoint_Spec) GetType ¶
func (endpoint *TrafficManagerProfilesAzureEndpoint_Spec) GetType() string
GetType returns the ARM Type of the resource. This is always "Microsoft.Network/trafficmanagerprofiles/AzureEndpoints"
type TrafficManagerProfilesExternalEndpoint_STATUS ¶
type TrafficManagerProfilesExternalEndpoint_STATUS struct {
// Id: Fully qualified resource Id for the resource. Ex -
// /subscriptions/{subscriptionId}/resourceGroups/{resourceGroupName}/providers/Microsoft.Network/trafficManagerProfiles/{resourceName}
Id *string `json:"id,omitempty"`
// Name: The name of the resource
Name *string `json:"name,omitempty"`
// Properties: The properties of the Traffic Manager endpoint.
Properties *EndpointProperties_STATUS `json:"properties,omitempty"`
// Type: The type of the resource. Ex- Microsoft.Network/trafficManagerProfiles.
Type *string `json:"type,omitempty"`
}
type TrafficManagerProfilesExternalEndpoint_Spec ¶
type TrafficManagerProfilesExternalEndpoint_Spec struct {
// Name: The name of the resource
Name string `json:"name,omitempty"`
// Properties: The properties of the Traffic Manager endpoint.
Properties *EndpointProperties `json:"properties,omitempty"`
// Type: The type of the resource. Ex- Microsoft.Network/trafficManagerProfiles.
Type *string `json:"type,omitempty"`
}
func (TrafficManagerProfilesExternalEndpoint_Spec) GetAPIVersion ¶
func (endpoint TrafficManagerProfilesExternalEndpoint_Spec) GetAPIVersion() string
GetAPIVersion returns the ARM API version of the resource. This is always "2022-04-01"
func (*TrafficManagerProfilesExternalEndpoint_Spec) GetName ¶
func (endpoint *TrafficManagerProfilesExternalEndpoint_Spec) GetName() string
GetName returns the Name of the resource
func (*TrafficManagerProfilesExternalEndpoint_Spec) GetType ¶
func (endpoint *TrafficManagerProfilesExternalEndpoint_Spec) GetType() string
GetType returns the ARM Type of the resource. This is always "Microsoft.Network/trafficmanagerprofiles/ExternalEndpoints"
type TrafficManagerProfilesNestedEndpoint_STATUS ¶
type TrafficManagerProfilesNestedEndpoint_STATUS struct {
// Id: Fully qualified resource Id for the resource. Ex -
// /subscriptions/{subscriptionId}/resourceGroups/{resourceGroupName}/providers/Microsoft.Network/trafficManagerProfiles/{resourceName}
Id *string `json:"id,omitempty"`
// Name: The name of the resource
Name *string `json:"name,omitempty"`
// Properties: The properties of the Traffic Manager endpoint.
Properties *EndpointProperties_STATUS `json:"properties,omitempty"`
// Type: The type of the resource. Ex- Microsoft.Network/trafficManagerProfiles.
Type *string `json:"type,omitempty"`
}
type TrafficManagerProfilesNestedEndpoint_Spec ¶
type TrafficManagerProfilesNestedEndpoint_Spec struct {
// Name: The name of the resource
Name string `json:"name,omitempty"`
// Properties: The properties of the Traffic Manager endpoint.
Properties *EndpointProperties `json:"properties,omitempty"`
// Type: The type of the resource. Ex- Microsoft.Network/trafficManagerProfiles.
Type *string `json:"type,omitempty"`
}
func (TrafficManagerProfilesNestedEndpoint_Spec) GetAPIVersion ¶
func (endpoint TrafficManagerProfilesNestedEndpoint_Spec) GetAPIVersion() string
GetAPIVersion returns the ARM API version of the resource. This is always "2022-04-01"
func (*TrafficManagerProfilesNestedEndpoint_Spec) GetName ¶
func (endpoint *TrafficManagerProfilesNestedEndpoint_Spec) GetName() string
GetName returns the Name of the resource
func (*TrafficManagerProfilesNestedEndpoint_Spec) GetType ¶
func (endpoint *TrafficManagerProfilesNestedEndpoint_Spec) GetType() string
GetType returns the ARM Type of the resource. This is always "Microsoft.Network/trafficmanagerprofiles/NestedEndpoints"
Source Files
¶
- traffic_manager_profile_spec_types_gen.go
- traffic_manager_profile_status_types_gen.go
- traffic_manager_profiles_azure_endpoint_spec_types_gen.go
- traffic_manager_profiles_azure_endpoint_status_types_gen.go
- traffic_manager_profiles_external_endpoint_spec_types_gen.go
- traffic_manager_profiles_external_endpoint_status_types_gen.go
- traffic_manager_profiles_nested_endpoint_spec_types_gen.go
- traffic_manager_profiles_nested_endpoint_status_types_gen.go