Documentation
¶
Overview ¶
Code generated by azure-service-operator-codegen. DO NOT EDIT. Copyright (c) Microsoft Corporation. Licensed under the MIT license.
Code generated by azure-service-operator-codegen. DO NOT EDIT. Copyright (c) Microsoft Corporation. Licensed under the MIT license.
Code generated by azure-service-operator-codegen. DO NOT EDIT. Copyright (c) Microsoft Corporation. Licensed under the MIT license.
Code generated by azure-service-operator-codegen. DO NOT EDIT. Copyright (c) Microsoft Corporation. Licensed under the MIT license.
Code generated by azure-service-operator-codegen. DO NOT EDIT. Copyright (c) Microsoft Corporation. Licensed under the MIT license.
Code generated by azure-service-operator-codegen. DO NOT EDIT. Copyright (c) Microsoft Corporation. Licensed under the MIT license.
Code generated by azure-service-operator-codegen. DO NOT EDIT. Copyright (c) Microsoft Corporation. Licensed under the MIT license.
Code generated by azure-service-operator-codegen. DO NOT EDIT. Copyright (c) Microsoft Corporation. Licensed under the MIT license.
Code generated by azure-service-operator-codegen. DO NOT EDIT. Copyright (c) Microsoft Corporation. Licensed under the MIT license.
Code generated by azure-service-operator-codegen. DO NOT EDIT. Copyright (c) Microsoft Corporation. Licensed under the MIT license.
Code generated by azure-service-operator-codegen. DO NOT EDIT. Copyright (c) Microsoft Corporation. Licensed under the MIT license.
Code generated by azure-service-operator-codegen. DO NOT EDIT. Copyright (c) Microsoft Corporation. Licensed under the MIT license.
Code generated by azure-service-operator-codegen. DO NOT EDIT. Copyright (c) Microsoft Corporation. Licensed under the MIT license.
Code generated by azure-service-operator-codegen. DO NOT EDIT. Copyright (c) Microsoft Corporation. Licensed under the MIT license.
Code generated by azure-service-operator-codegen. DO NOT EDIT. Copyright (c) Microsoft Corporation. Licensed under the MIT license.
Code generated by azure-service-operator-codegen. DO NOT EDIT. Copyright (c) Microsoft Corporation. Licensed under the MIT license.
Code generated by azure-service-operator-codegen. DO NOT EDIT. Copyright (c) Microsoft Corporation. Licensed under the MIT license.
Code generated by azure-service-operator-codegen. DO NOT EDIT. Copyright (c) Microsoft Corporation. Licensed under the MIT license.
Index ¶
- Constants
- type ARecord
- type ARecord_STATUS
- type AaaaRecord
- type AaaaRecord_STATUS
- type CnameRecord
- type CnameRecord_STATUS
- type MxRecord
- type MxRecord_STATUS
- type PrivateDnsZone_STATUS
- type PrivateDnsZone_Spec
- type PrivateDnsZonesAAAARecord_STATUS
- type PrivateDnsZonesAAAARecord_Spec
- type PrivateDnsZonesARecord_STATUS
- type PrivateDnsZonesARecord_Spec
- type PrivateDnsZonesCNAMERecord_STATUS
- type PrivateDnsZonesCNAMERecord_Spec
- type PrivateDnsZonesMXRecord_STATUS
- type PrivateDnsZonesMXRecord_Spec
- type PrivateDnsZonesPTRRecord_STATUS
- type PrivateDnsZonesPTRRecord_Spec
- type PrivateDnsZonesSRVRecord_STATUS
- type PrivateDnsZonesSRVRecord_Spec
- type PrivateDnsZonesTXTRecord_STATUS
- type PrivateDnsZonesTXTRecord_Spec
- type PrivateDnsZonesVirtualNetworkLink_STATUS
- type PrivateDnsZonesVirtualNetworkLink_Spec
- type PrivateZoneProperties_ProvisioningState_STATUS
- type PrivateZoneProperties_STATUS
- type PtrRecord
- type PtrRecord_STATUS
- type RecordSetProperties
- type RecordSetProperties_STATUS
- type SoaRecord
- type SoaRecord_STATUS
- type SrvRecord
- type SrvRecord_STATUS
- type SubResource
- type SubResource_STATUS
- type TxtRecord
- type TxtRecord_STATUS
- type VirtualNetworkLinkProperties
- type VirtualNetworkLinkProperties_ProvisioningState_STATUS
- type VirtualNetworkLinkProperties_ResolutionPolicy
- type VirtualNetworkLinkProperties_ResolutionPolicy_STATUS
- type VirtualNetworkLinkProperties_STATUS
- type VirtualNetworkLinkProperties_VirtualNetworkLinkState_STATUS
Constants ¶
const ( PrivateZoneProperties_ProvisioningState_STATUS_Canceled = PrivateZoneProperties_ProvisioningState_STATUS("Canceled") PrivateZoneProperties_ProvisioningState_STATUS_Creating = PrivateZoneProperties_ProvisioningState_STATUS("Creating") PrivateZoneProperties_ProvisioningState_STATUS_Deleting = PrivateZoneProperties_ProvisioningState_STATUS("Deleting") PrivateZoneProperties_ProvisioningState_STATUS_Failed = PrivateZoneProperties_ProvisioningState_STATUS("Failed") PrivateZoneProperties_ProvisioningState_STATUS_Succeeded = PrivateZoneProperties_ProvisioningState_STATUS("Succeeded") PrivateZoneProperties_ProvisioningState_STATUS_Updating = PrivateZoneProperties_ProvisioningState_STATUS("Updating") )
const ( VirtualNetworkLinkProperties_ResolutionPolicy_Default = VirtualNetworkLinkProperties_ResolutionPolicy("Default") VirtualNetworkLinkProperties_ResolutionPolicy_NxDomainRedirect = VirtualNetworkLinkProperties_ResolutionPolicy("NxDomainRedirect") )
const ( VirtualNetworkLinkProperties_ProvisioningState_STATUS_Canceled = VirtualNetworkLinkProperties_ProvisioningState_STATUS("Canceled") VirtualNetworkLinkProperties_ProvisioningState_STATUS_Creating = VirtualNetworkLinkProperties_ProvisioningState_STATUS("Creating") VirtualNetworkLinkProperties_ProvisioningState_STATUS_Deleting = VirtualNetworkLinkProperties_ProvisioningState_STATUS("Deleting") VirtualNetworkLinkProperties_ProvisioningState_STATUS_Failed = VirtualNetworkLinkProperties_ProvisioningState_STATUS("Failed") VirtualNetworkLinkProperties_ProvisioningState_STATUS_Succeeded = VirtualNetworkLinkProperties_ProvisioningState_STATUS("Succeeded") VirtualNetworkLinkProperties_ProvisioningState_STATUS_Updating = VirtualNetworkLinkProperties_ProvisioningState_STATUS("Updating") )
const ( VirtualNetworkLinkProperties_ResolutionPolicy_STATUS_Default = VirtualNetworkLinkProperties_ResolutionPolicy_STATUS("Default") VirtualNetworkLinkProperties_ResolutionPolicy_STATUS_NxDomainRedirect = VirtualNetworkLinkProperties_ResolutionPolicy_STATUS("NxDomainRedirect") )
const ( VirtualNetworkLinkProperties_VirtualNetworkLinkState_STATUS_Completed = VirtualNetworkLinkProperties_VirtualNetworkLinkState_STATUS("Completed") VirtualNetworkLinkProperties_VirtualNetworkLinkState_STATUS_InProgress = VirtualNetworkLinkProperties_VirtualNetworkLinkState_STATUS("InProgress") )
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type ARecord ¶
type ARecord struct {
// Ipv4Address: The IPv4 address of this A record.
Ipv4Address *string `json:"ipv4Address,omitempty"`
}
An A record.
type ARecord_STATUS ¶
type ARecord_STATUS struct {
// Ipv4Address: The IPv4 address of this A record.
Ipv4Address *string `json:"ipv4Address,omitempty"`
}
An A record.
type AaaaRecord ¶
type AaaaRecord struct {
// Ipv6Address: The IPv6 address of this AAAA record.
Ipv6Address *string `json:"ipv6Address,omitempty"`
}
An AAAA record.
type AaaaRecord_STATUS ¶
type AaaaRecord_STATUS struct {
// Ipv6Address: The IPv6 address of this AAAA record.
Ipv6Address *string `json:"ipv6Address,omitempty"`
}
An AAAA record.
type CnameRecord ¶
type CnameRecord struct {
// Cname: The canonical name for this CNAME record.
Cname *string `json:"cname,omitempty"`
}
A CNAME record.
type CnameRecord_STATUS ¶
type CnameRecord_STATUS struct {
// Cname: The canonical name for this CNAME record.
Cname *string `json:"cname,omitempty"`
}
A CNAME record.
type MxRecord ¶
type MxRecord struct {
// Exchange: The domain name of the mail host for this MX record.
Exchange *string `json:"exchange,omitempty"`
// Preference: The preference value for this MX record.
Preference *int `json:"preference,omitempty"`
}
An MX record.
type MxRecord_STATUS ¶
type MxRecord_STATUS struct {
// Exchange: The domain name of the mail host for this MX record.
Exchange *string `json:"exchange,omitempty"`
// Preference: The preference value for this MX record.
Preference *int `json:"preference,omitempty"`
}
An MX record.
type PrivateDnsZone_STATUS ¶
type PrivateDnsZone_STATUS struct {
// Etag: The ETag of the zone.
Etag *string `json:"etag,omitempty"`
// Id: Fully qualified resource Id for the resource. Example -
// '/subscriptions/{subscriptionId}/resourceGroups/{resourceGroupName}/providers/Microsoft.Network/privateDnsZones/{privateDnsZoneName}'.
Id *string `json:"id,omitempty"`
// Location: The Azure Region where the resource lives
Location *string `json:"location,omitempty"`
// Name: The name of the resource
Name *string `json:"name,omitempty"`
// Properties: Properties of the Private DNS zone.
Properties *PrivateZoneProperties_STATUS `json:"properties,omitempty"`
// Tags: Resource tags.
Tags map[string]string `json:"tags,omitempty"`
// Type: The type of the resource. Example - 'Microsoft.Network/privateDnsZones'.
Type *string `json:"type,omitempty"`
}
type PrivateDnsZone_Spec ¶
type PrivateDnsZone_Spec struct {
// Etag: The ETag of the zone.
Etag *string `json:"etag,omitempty"`
// Location: The Azure Region where the resource lives
Location *string `json:"location,omitempty"`
Name string `json:"name,omitempty"`
// Tags: Resource tags.
Tags map[string]string `json:"tags,omitempty"`
}
func (PrivateDnsZone_Spec) GetAPIVersion ¶
func (zone PrivateDnsZone_Spec) GetAPIVersion() string
GetAPIVersion returns the ARM API version of the resource. This is always "2024-06-01"
func (*PrivateDnsZone_Spec) GetName ¶
func (zone *PrivateDnsZone_Spec) GetName() string
GetName returns the Name of the resource
func (*PrivateDnsZone_Spec) GetType ¶
func (zone *PrivateDnsZone_Spec) GetType() string
GetType returns the ARM Type of the resource. This is always "Microsoft.Network/privateDnsZones"
type PrivateDnsZonesAAAARecord_STATUS ¶
type PrivateDnsZonesAAAARecord_STATUS struct {
// Etag: The ETag of the record set.
Etag *string `json:"etag,omitempty"`
// Id: Fully qualified resource Id for the resource. Example -
// '/subscriptions/{subscriptionId}/resourceGroups/{resourceGroupName}/providers/Microsoft.Network/privateDnsZones/{privateDnsZoneName}'.
Id *string `json:"id,omitempty"`
// Name: The name of the record set.
Name *string `json:"name,omitempty"`
// Properties: The properties of the record set.
Properties *RecordSetProperties_STATUS `json:"properties,omitempty"`
// Type: The type of the resource. Example - 'Microsoft.Network/privateDnsZones'.
Type *string `json:"type,omitempty"`
}
type PrivateDnsZonesAAAARecord_Spec ¶
type PrivateDnsZonesAAAARecord_Spec struct {
// Etag: The ETag of the record set.
Etag *string `json:"etag,omitempty"`
Name string `json:"name,omitempty"`
// Properties: The properties of the record set.
Properties *RecordSetProperties `json:"properties,omitempty"`
}
func (PrivateDnsZonesAAAARecord_Spec) GetAPIVersion ¶
func (record PrivateDnsZonesAAAARecord_Spec) GetAPIVersion() string
GetAPIVersion returns the ARM API version of the resource. This is always "2024-06-01"
func (*PrivateDnsZonesAAAARecord_Spec) GetName ¶
func (record *PrivateDnsZonesAAAARecord_Spec) GetName() string
GetName returns the Name of the resource
func (*PrivateDnsZonesAAAARecord_Spec) GetType ¶
func (record *PrivateDnsZonesAAAARecord_Spec) GetType() string
GetType returns the ARM Type of the resource. This is always "Microsoft.Network/privateDnsZones/AAAA"
type PrivateDnsZonesARecord_STATUS ¶
type PrivateDnsZonesARecord_STATUS struct {
// Etag: The ETag of the record set.
Etag *string `json:"etag,omitempty"`
// Id: Fully qualified resource Id for the resource. Example -
// '/subscriptions/{subscriptionId}/resourceGroups/{resourceGroupName}/providers/Microsoft.Network/privateDnsZones/{privateDnsZoneName}'.
Id *string `json:"id,omitempty"`
// Name: The name of the record set.
Name *string `json:"name,omitempty"`
// Properties: The properties of the record set.
Properties *RecordSetProperties_STATUS `json:"properties,omitempty"`
// Type: The type of the resource. Example - 'Microsoft.Network/privateDnsZones'.
Type *string `json:"type,omitempty"`
}
type PrivateDnsZonesARecord_Spec ¶
type PrivateDnsZonesARecord_Spec struct {
// Etag: The ETag of the record set.
Etag *string `json:"etag,omitempty"`
Name string `json:"name,omitempty"`
// Properties: The properties of the record set.
Properties *RecordSetProperties `json:"properties,omitempty"`
}
func (PrivateDnsZonesARecord_Spec) GetAPIVersion ¶
func (record PrivateDnsZonesARecord_Spec) GetAPIVersion() string
GetAPIVersion returns the ARM API version of the resource. This is always "2024-06-01"
func (*PrivateDnsZonesARecord_Spec) GetName ¶
func (record *PrivateDnsZonesARecord_Spec) GetName() string
GetName returns the Name of the resource
func (*PrivateDnsZonesARecord_Spec) GetType ¶
func (record *PrivateDnsZonesARecord_Spec) GetType() string
GetType returns the ARM Type of the resource. This is always "Microsoft.Network/privateDnsZones/A"
type PrivateDnsZonesCNAMERecord_STATUS ¶
type PrivateDnsZonesCNAMERecord_STATUS struct {
// Etag: The ETag of the record set.
Etag *string `json:"etag,omitempty"`
// Id: Fully qualified resource Id for the resource. Example -
// '/subscriptions/{subscriptionId}/resourceGroups/{resourceGroupName}/providers/Microsoft.Network/privateDnsZones/{privateDnsZoneName}'.
Id *string `json:"id,omitempty"`
// Name: The name of the record set.
Name *string `json:"name,omitempty"`
// Properties: The properties of the record set.
Properties *RecordSetProperties_STATUS `json:"properties,omitempty"`
// Type: The type of the resource. Example - 'Microsoft.Network/privateDnsZones'.
Type *string `json:"type,omitempty"`
}
type PrivateDnsZonesCNAMERecord_Spec ¶
type PrivateDnsZonesCNAMERecord_Spec struct {
// Etag: The ETag of the record set.
Etag *string `json:"etag,omitempty"`
Name string `json:"name,omitempty"`
// Properties: The properties of the record set.
Properties *RecordSetProperties `json:"properties,omitempty"`
}
func (PrivateDnsZonesCNAMERecord_Spec) GetAPIVersion ¶
func (record PrivateDnsZonesCNAMERecord_Spec) GetAPIVersion() string
GetAPIVersion returns the ARM API version of the resource. This is always "2024-06-01"
func (*PrivateDnsZonesCNAMERecord_Spec) GetName ¶
func (record *PrivateDnsZonesCNAMERecord_Spec) GetName() string
GetName returns the Name of the resource
func (*PrivateDnsZonesCNAMERecord_Spec) GetType ¶
func (record *PrivateDnsZonesCNAMERecord_Spec) GetType() string
GetType returns the ARM Type of the resource. This is always "Microsoft.Network/privateDnsZones/CNAME"
type PrivateDnsZonesMXRecord_STATUS ¶
type PrivateDnsZonesMXRecord_STATUS struct {
// Etag: The ETag of the record set.
Etag *string `json:"etag,omitempty"`
// Id: Fully qualified resource Id for the resource. Example -
// '/subscriptions/{subscriptionId}/resourceGroups/{resourceGroupName}/providers/Microsoft.Network/privateDnsZones/{privateDnsZoneName}'.
Id *string `json:"id,omitempty"`
// Name: The name of the record set.
Name *string `json:"name,omitempty"`
// Properties: The properties of the record set.
Properties *RecordSetProperties_STATUS `json:"properties,omitempty"`
// Type: The type of the resource. Example - 'Microsoft.Network/privateDnsZones'.
Type *string `json:"type,omitempty"`
}
type PrivateDnsZonesMXRecord_Spec ¶
type PrivateDnsZonesMXRecord_Spec struct {
// Etag: The ETag of the record set.
Etag *string `json:"etag,omitempty"`
Name string `json:"name,omitempty"`
// Properties: The properties of the record set.
Properties *RecordSetProperties `json:"properties,omitempty"`
}
func (PrivateDnsZonesMXRecord_Spec) GetAPIVersion ¶
func (record PrivateDnsZonesMXRecord_Spec) GetAPIVersion() string
GetAPIVersion returns the ARM API version of the resource. This is always "2024-06-01"
func (*PrivateDnsZonesMXRecord_Spec) GetName ¶
func (record *PrivateDnsZonesMXRecord_Spec) GetName() string
GetName returns the Name of the resource
func (*PrivateDnsZonesMXRecord_Spec) GetType ¶
func (record *PrivateDnsZonesMXRecord_Spec) GetType() string
GetType returns the ARM Type of the resource. This is always "Microsoft.Network/privateDnsZones/MX"
type PrivateDnsZonesPTRRecord_STATUS ¶
type PrivateDnsZonesPTRRecord_STATUS struct {
// Etag: The ETag of the record set.
Etag *string `json:"etag,omitempty"`
// Id: Fully qualified resource Id for the resource. Example -
// '/subscriptions/{subscriptionId}/resourceGroups/{resourceGroupName}/providers/Microsoft.Network/privateDnsZones/{privateDnsZoneName}'.
Id *string `json:"id,omitempty"`
// Name: The name of the record set.
Name *string `json:"name,omitempty"`
// Properties: The properties of the record set.
Properties *RecordSetProperties_STATUS `json:"properties,omitempty"`
// Type: The type of the resource. Example - 'Microsoft.Network/privateDnsZones'.
Type *string `json:"type,omitempty"`
}
type PrivateDnsZonesPTRRecord_Spec ¶
type PrivateDnsZonesPTRRecord_Spec struct {
// Etag: The ETag of the record set.
Etag *string `json:"etag,omitempty"`
Name string `json:"name,omitempty"`
// Properties: The properties of the record set.
Properties *RecordSetProperties `json:"properties,omitempty"`
}
func (PrivateDnsZonesPTRRecord_Spec) GetAPIVersion ¶
func (record PrivateDnsZonesPTRRecord_Spec) GetAPIVersion() string
GetAPIVersion returns the ARM API version of the resource. This is always "2024-06-01"
func (*PrivateDnsZonesPTRRecord_Spec) GetName ¶
func (record *PrivateDnsZonesPTRRecord_Spec) GetName() string
GetName returns the Name of the resource
func (*PrivateDnsZonesPTRRecord_Spec) GetType ¶
func (record *PrivateDnsZonesPTRRecord_Spec) GetType() string
GetType returns the ARM Type of the resource. This is always "Microsoft.Network/privateDnsZones/PTR"
type PrivateDnsZonesSRVRecord_STATUS ¶
type PrivateDnsZonesSRVRecord_STATUS struct {
// Etag: The ETag of the record set.
Etag *string `json:"etag,omitempty"`
// Id: Fully qualified resource Id for the resource. Example -
// '/subscriptions/{subscriptionId}/resourceGroups/{resourceGroupName}/providers/Microsoft.Network/privateDnsZones/{privateDnsZoneName}'.
Id *string `json:"id,omitempty"`
// Name: The name of the record set.
Name *string `json:"name,omitempty"`
// Properties: The properties of the record set.
Properties *RecordSetProperties_STATUS `json:"properties,omitempty"`
// Type: The type of the resource. Example - 'Microsoft.Network/privateDnsZones'.
Type *string `json:"type,omitempty"`
}
type PrivateDnsZonesSRVRecord_Spec ¶
type PrivateDnsZonesSRVRecord_Spec struct {
// Etag: The ETag of the record set.
Etag *string `json:"etag,omitempty"`
Name string `json:"name,omitempty"`
// Properties: The properties of the record set.
Properties *RecordSetProperties `json:"properties,omitempty"`
}
func (PrivateDnsZonesSRVRecord_Spec) GetAPIVersion ¶
func (record PrivateDnsZonesSRVRecord_Spec) GetAPIVersion() string
GetAPIVersion returns the ARM API version of the resource. This is always "2024-06-01"
func (*PrivateDnsZonesSRVRecord_Spec) GetName ¶
func (record *PrivateDnsZonesSRVRecord_Spec) GetName() string
GetName returns the Name of the resource
func (*PrivateDnsZonesSRVRecord_Spec) GetType ¶
func (record *PrivateDnsZonesSRVRecord_Spec) GetType() string
GetType returns the ARM Type of the resource. This is always "Microsoft.Network/privateDnsZones/SRV"
type PrivateDnsZonesTXTRecord_STATUS ¶
type PrivateDnsZonesTXTRecord_STATUS struct {
// Etag: The ETag of the record set.
Etag *string `json:"etag,omitempty"`
// Id: Fully qualified resource Id for the resource. Example -
// '/subscriptions/{subscriptionId}/resourceGroups/{resourceGroupName}/providers/Microsoft.Network/privateDnsZones/{privateDnsZoneName}'.
Id *string `json:"id,omitempty"`
// Name: The name of the record set.
Name *string `json:"name,omitempty"`
// Properties: The properties of the record set.
Properties *RecordSetProperties_STATUS `json:"properties,omitempty"`
// Type: The type of the resource. Example - 'Microsoft.Network/privateDnsZones'.
Type *string `json:"type,omitempty"`
}
type PrivateDnsZonesTXTRecord_Spec ¶
type PrivateDnsZonesTXTRecord_Spec struct {
// Etag: The ETag of the record set.
Etag *string `json:"etag,omitempty"`
Name string `json:"name,omitempty"`
// Properties: The properties of the record set.
Properties *RecordSetProperties `json:"properties,omitempty"`
}
func (PrivateDnsZonesTXTRecord_Spec) GetAPIVersion ¶
func (record PrivateDnsZonesTXTRecord_Spec) GetAPIVersion() string
GetAPIVersion returns the ARM API version of the resource. This is always "2024-06-01"
func (*PrivateDnsZonesTXTRecord_Spec) GetName ¶
func (record *PrivateDnsZonesTXTRecord_Spec) GetName() string
GetName returns the Name of the resource
func (*PrivateDnsZonesTXTRecord_Spec) GetType ¶
func (record *PrivateDnsZonesTXTRecord_Spec) GetType() string
GetType returns the ARM Type of the resource. This is always "Microsoft.Network/privateDnsZones/TXT"
type PrivateDnsZonesVirtualNetworkLink_STATUS ¶
type PrivateDnsZonesVirtualNetworkLink_STATUS struct {
// Etag: The ETag of the virtual network link.
Etag *string `json:"etag,omitempty"`
// Id: Fully qualified resource Id for the resource. Example -
// '/subscriptions/{subscriptionId}/resourceGroups/{resourceGroupName}/providers/Microsoft.Network/privateDnsZones/{privateDnsZoneName}'.
Id *string `json:"id,omitempty"`
// Location: The Azure Region where the resource lives
Location *string `json:"location,omitempty"`
// Name: The name of the resource
Name *string `json:"name,omitempty"`
// Properties: Properties of the virtual network link to the Private DNS zone.
Properties *VirtualNetworkLinkProperties_STATUS `json:"properties,omitempty"`
// Tags: Resource tags.
Tags map[string]string `json:"tags,omitempty"`
// Type: The type of the resource. Example - 'Microsoft.Network/privateDnsZones'.
Type *string `json:"type,omitempty"`
}
type PrivateDnsZonesVirtualNetworkLink_Spec ¶
type PrivateDnsZonesVirtualNetworkLink_Spec struct {
// Etag: The ETag of the virtual network link.
Etag *string `json:"etag,omitempty"`
// Location: The Azure Region where the resource lives
Location *string `json:"location,omitempty"`
Name string `json:"name,omitempty"`
// Properties: Properties of the virtual network link to the Private DNS zone.
Properties *VirtualNetworkLinkProperties `json:"properties,omitempty"`
// Tags: Resource tags.
Tags map[string]string `json:"tags,omitempty"`
}
func (PrivateDnsZonesVirtualNetworkLink_Spec) GetAPIVersion ¶
func (link PrivateDnsZonesVirtualNetworkLink_Spec) GetAPIVersion() string
GetAPIVersion returns the ARM API version of the resource. This is always "2024-06-01"
func (*PrivateDnsZonesVirtualNetworkLink_Spec) GetName ¶
func (link *PrivateDnsZonesVirtualNetworkLink_Spec) GetName() string
GetName returns the Name of the resource
func (*PrivateDnsZonesVirtualNetworkLink_Spec) GetType ¶
func (link *PrivateDnsZonesVirtualNetworkLink_Spec) GetType() string
GetType returns the ARM Type of the resource. This is always "Microsoft.Network/privateDnsZones/virtualNetworkLinks"
type PrivateZoneProperties_ProvisioningState_STATUS ¶
type PrivateZoneProperties_ProvisioningState_STATUS string
type PrivateZoneProperties_STATUS ¶
type PrivateZoneProperties_STATUS struct {
// InternalId: Private zone internal Id
InternalId *string `json:"internalId,omitempty"`
// MaxNumberOfRecordSets: The maximum number of record sets that can be created in this Private DNS zone. This is a
// read-only property and any attempt to set this value will be ignored.
MaxNumberOfRecordSets *int `json:"maxNumberOfRecordSets,omitempty"`
// MaxNumberOfVirtualNetworkLinks: The maximum number of virtual networks that can be linked to this Private DNS zone. This
// is a read-only property and any attempt to set this value will be ignored.
MaxNumberOfVirtualNetworkLinks *int `json:"maxNumberOfVirtualNetworkLinks,omitempty"`
// MaxNumberOfVirtualNetworkLinksWithRegistration: The maximum number of virtual networks that can be linked to this
// Private DNS zone with registration enabled. This is a read-only property and any attempt to set this value will be
// ignored.
MaxNumberOfVirtualNetworkLinksWithRegistration *int `json:"maxNumberOfVirtualNetworkLinksWithRegistration,omitempty"`
// NumberOfRecordSets: The current number of record sets in this Private DNS zone. This is a read-only property and any
// attempt to set this value will be ignored.
NumberOfRecordSets *int `json:"numberOfRecordSets,omitempty"`
// NumberOfVirtualNetworkLinks: The current number of virtual networks that are linked to this Private DNS zone. This is a
// read-only property and any attempt to set this value will be ignored.
NumberOfVirtualNetworkLinks *int `json:"numberOfVirtualNetworkLinks,omitempty"`
// NumberOfVirtualNetworkLinksWithRegistration: The current number of virtual networks that are linked to this Private DNS
// zone with registration enabled. This is a read-only property and any attempt to set this value will be ignored.
NumberOfVirtualNetworkLinksWithRegistration *int `json:"numberOfVirtualNetworkLinksWithRegistration,omitempty"`
// ProvisioningState: The provisioning state of the resource. This is a read-only property and any attempt to set this
// value will be ignored.
ProvisioningState *PrivateZoneProperties_ProvisioningState_STATUS `json:"provisioningState,omitempty"`
}
Represents the properties of the Private DNS zone.
type PtrRecord ¶
type PtrRecord struct {
// Ptrdname: The PTR target domain name for this PTR record.
Ptrdname *string `json:"ptrdname,omitempty"`
}
A PTR record.
type PtrRecord_STATUS ¶
type PtrRecord_STATUS struct {
// Ptrdname: The PTR target domain name for this PTR record.
Ptrdname *string `json:"ptrdname,omitempty"`
}
A PTR record.
type RecordSetProperties ¶
type RecordSetProperties struct {
// ARecords: The list of A records in the record set.
ARecords []ARecord `json:"aRecords,omitempty"`
// AaaaRecords: The list of AAAA records in the record set.
AaaaRecords []AaaaRecord `json:"aaaaRecords,omitempty"`
// CnameRecord: The CNAME record in the record set.
CnameRecord *CnameRecord `json:"cnameRecord,omitempty"`
// Metadata: The metadata attached to the record set.
Metadata map[string]string `json:"metadata,omitempty"`
// MxRecords: The list of MX records in the record set.
MxRecords []MxRecord `json:"mxRecords,omitempty"`
// PtrRecords: The list of PTR records in the record set.
PtrRecords []PtrRecord `json:"ptrRecords,omitempty"`
// SoaRecord: The SOA record in the record set.
SoaRecord *SoaRecord `json:"soaRecord,omitempty"`
// SrvRecords: The list of SRV records in the record set.
SrvRecords []SrvRecord `json:"srvRecords,omitempty"`
// Ttl: The TTL (time-to-live) of the records in the record set.
Ttl *int `json:"ttl,omitempty"`
// TxtRecords: The list of TXT records in the record set.
TxtRecords []TxtRecord `json:"txtRecords,omitempty"`
}
Represents the properties of the records in the record set.
type RecordSetProperties_STATUS ¶
type RecordSetProperties_STATUS struct {
// ARecords: The list of A records in the record set.
ARecords []ARecord_STATUS `json:"aRecords,omitempty"`
// AaaaRecords: The list of AAAA records in the record set.
AaaaRecords []AaaaRecord_STATUS `json:"aaaaRecords,omitempty"`
// CnameRecord: The CNAME record in the record set.
CnameRecord *CnameRecord_STATUS `json:"cnameRecord,omitempty"`
// Fqdn: Fully qualified domain name of the record set.
Fqdn *string `json:"fqdn,omitempty"`
// IsAutoRegistered: Is the record set auto-registered in the Private DNS zone through a virtual network link?
IsAutoRegistered *bool `json:"isAutoRegistered,omitempty"`
// Metadata: The metadata attached to the record set.
Metadata map[string]string `json:"metadata,omitempty"`
// MxRecords: The list of MX records in the record set.
MxRecords []MxRecord_STATUS `json:"mxRecords,omitempty"`
// PtrRecords: The list of PTR records in the record set.
PtrRecords []PtrRecord_STATUS `json:"ptrRecords,omitempty"`
// SoaRecord: The SOA record in the record set.
SoaRecord *SoaRecord_STATUS `json:"soaRecord,omitempty"`
// SrvRecords: The list of SRV records in the record set.
SrvRecords []SrvRecord_STATUS `json:"srvRecords,omitempty"`
// Ttl: The TTL (time-to-live) of the records in the record set.
Ttl *int `json:"ttl,omitempty"`
// TxtRecords: The list of TXT records in the record set.
TxtRecords []TxtRecord_STATUS `json:"txtRecords,omitempty"`
}
Represents the properties of the records in the record set.
type SoaRecord ¶
type SoaRecord struct {
// Email: The email contact for this SOA record.
Email *string `json:"email,omitempty"`
// ExpireTime: The expire time for this SOA record.
ExpireTime *int `json:"expireTime,omitempty"`
// Host: The domain name of the authoritative name server for this SOA record.
Host *string `json:"host,omitempty"`
// MinimumTtl: The minimum value for this SOA record. By convention this is used to determine the negative caching duration.
MinimumTtl *int `json:"minimumTtl,omitempty"`
// RefreshTime: The refresh value for this SOA record.
RefreshTime *int `json:"refreshTime,omitempty"`
// RetryTime: The retry time for this SOA record.
RetryTime *int `json:"retryTime,omitempty"`
// SerialNumber: The serial number for this SOA record.
SerialNumber *int `json:"serialNumber,omitempty"`
}
An SOA record.
type SoaRecord_STATUS ¶
type SoaRecord_STATUS struct {
// Email: The email contact for this SOA record.
Email *string `json:"email,omitempty"`
// ExpireTime: The expire time for this SOA record.
ExpireTime *int `json:"expireTime,omitempty"`
// Host: The domain name of the authoritative name server for this SOA record.
Host *string `json:"host,omitempty"`
// MinimumTtl: The minimum value for this SOA record. By convention this is used to determine the negative caching duration.
MinimumTtl *int `json:"minimumTtl,omitempty"`
// RefreshTime: The refresh value for this SOA record.
RefreshTime *int `json:"refreshTime,omitempty"`
// RetryTime: The retry time for this SOA record.
RetryTime *int `json:"retryTime,omitempty"`
// SerialNumber: The serial number for this SOA record.
SerialNumber *int `json:"serialNumber,omitempty"`
}
An SOA record.
type SrvRecord ¶
type SrvRecord struct {
// Port: The port value for this SRV record.
Port *int `json:"port,omitempty"`
// Priority: The priority value for this SRV record.
Priority *int `json:"priority,omitempty"`
// Target: The target domain name for this SRV record.
Target *string `json:"target,omitempty"`
// Weight: The weight value for this SRV record.
Weight *int `json:"weight,omitempty"`
}
An SRV record.
type SrvRecord_STATUS ¶
type SrvRecord_STATUS struct {
// Port: The port value for this SRV record.
Port *int `json:"port,omitempty"`
// Priority: The priority value for this SRV record.
Priority *int `json:"priority,omitempty"`
// Target: The target domain name for this SRV record.
Target *string `json:"target,omitempty"`
// Weight: The weight value for this SRV record.
Weight *int `json:"weight,omitempty"`
}
An SRV record.
type SubResource ¶
type SubResource struct {
Id *string `json:"id,omitempty"`
}
Reference to another subresource.
type SubResource_STATUS ¶
type SubResource_STATUS struct {
// Id: Resource ID.
Id *string `json:"id,omitempty"`
}
Reference to another subresource.
type TxtRecord ¶
type TxtRecord struct {
// Value: The text value of this TXT record.
Value []string `json:"value,omitempty"`
}
A TXT record.
type TxtRecord_STATUS ¶
type TxtRecord_STATUS struct {
// Value: The text value of this TXT record.
Value []string `json:"value,omitempty"`
}
A TXT record.
type VirtualNetworkLinkProperties ¶
type VirtualNetworkLinkProperties struct {
// RegistrationEnabled: Is auto-registration of virtual machine records in the virtual network in the Private DNS zone
// enabled?
RegistrationEnabled *bool `json:"registrationEnabled,omitempty"`
// ResolutionPolicy: The resolution policy on the virtual network link. Only applicable for virtual network links to
// privatelink zones, and for A,AAAA,CNAME queries. When set to 'NxDomainRedirect', Azure DNS resolver falls back to public
// resolution if private dns query resolution results in non-existent domain response.
ResolutionPolicy *VirtualNetworkLinkProperties_ResolutionPolicy `json:"resolutionPolicy,omitempty"`
// VirtualNetwork: The reference of the virtual network.
VirtualNetwork *SubResource `json:"virtualNetwork,omitempty"`
}
Represents the properties of the Private DNS zone.
type VirtualNetworkLinkProperties_ProvisioningState_STATUS ¶
type VirtualNetworkLinkProperties_ProvisioningState_STATUS string
type VirtualNetworkLinkProperties_ResolutionPolicy ¶
type VirtualNetworkLinkProperties_ResolutionPolicy string
+kubebuilder:validation:Enum={"Default","NxDomainRedirect"}
type VirtualNetworkLinkProperties_ResolutionPolicy_STATUS ¶
type VirtualNetworkLinkProperties_ResolutionPolicy_STATUS string
type VirtualNetworkLinkProperties_STATUS ¶
type VirtualNetworkLinkProperties_STATUS struct {
// ProvisioningState: The provisioning state of the resource. This is a read-only property and any attempt to set this
// value will be ignored.
ProvisioningState *VirtualNetworkLinkProperties_ProvisioningState_STATUS `json:"provisioningState,omitempty"`
// RegistrationEnabled: Is auto-registration of virtual machine records in the virtual network in the Private DNS zone
// enabled?
RegistrationEnabled *bool `json:"registrationEnabled,omitempty"`
// ResolutionPolicy: The resolution policy on the virtual network link. Only applicable for virtual network links to
// privatelink zones, and for A,AAAA,CNAME queries. When set to 'NxDomainRedirect', Azure DNS resolver falls back to public
// resolution if private dns query resolution results in non-existent domain response.
ResolutionPolicy *VirtualNetworkLinkProperties_ResolutionPolicy_STATUS `json:"resolutionPolicy,omitempty"`
// VirtualNetwork: The reference of the virtual network.
VirtualNetwork *SubResource_STATUS `json:"virtualNetwork,omitempty"`
// VirtualNetworkLinkState: The status of the virtual network link to the Private DNS zone. Possible values are
// 'InProgress' and 'Done'. This is a read-only property and any attempt to set this value will be ignored.
VirtualNetworkLinkState *VirtualNetworkLinkProperties_VirtualNetworkLinkState_STATUS `json:"virtualNetworkLinkState,omitempty"`
}
Represents the properties of the Private DNS zone.
type VirtualNetworkLinkProperties_VirtualNetworkLinkState_STATUS ¶
type VirtualNetworkLinkProperties_VirtualNetworkLinkState_STATUS string
Source Files
¶
- private_dns_zone_spec_types_gen.go
- private_dns_zone_status_types_gen.go
- private_dns_zones_a_record_spec_types_gen.go
- private_dns_zones_a_record_status_types_gen.go
- private_dns_zones_aaaa_record_spec_types_gen.go
- private_dns_zones_aaaa_record_status_types_gen.go
- private_dns_zones_cname_record_spec_types_gen.go
- private_dns_zones_cname_record_status_types_gen.go
- private_dns_zones_mx_record_spec_types_gen.go
- private_dns_zones_mx_record_status_types_gen.go
- private_dns_zones_ptr_record_spec_types_gen.go
- private_dns_zones_ptr_record_status_types_gen.go
- private_dns_zones_srv_record_spec_types_gen.go
- private_dns_zones_srv_record_status_types_gen.go
- private_dns_zones_txt_record_spec_types_gen.go
- private_dns_zones_txt_record_status_types_gen.go
- private_dns_zones_virtual_network_link_spec_types_gen.go
- private_dns_zones_virtual_network_link_status_types_gen.go