Documentation
¶
Overview ¶
Code generated by azure-service-operator-codegen. DO NOT EDIT. Copyright (c) Microsoft Corporation. Licensed under the MIT license.
Code generated by azure-service-operator-codegen. DO NOT EDIT. Copyright (c) Microsoft Corporation. Licensed under the MIT license.
Code generated by azure-service-operator-codegen. DO NOT EDIT. Copyright (c) Microsoft Corporation. Licensed under the MIT license.
Code generated by azure-service-operator-codegen. DO NOT EDIT. Copyright (c) Microsoft Corporation. Licensed under the MIT license.
Code generated by azure-service-operator-codegen. DO NOT EDIT. Copyright (c) Microsoft Corporation. Licensed under the MIT license.
Code generated by azure-service-operator-codegen. DO NOT EDIT. Copyright (c) Microsoft Corporation. Licensed under the MIT license.
Code generated by azure-service-operator-codegen. DO NOT EDIT. Copyright (c) Microsoft Corporation. Licensed under the MIT license.
Code generated by azure-service-operator-codegen. DO NOT EDIT. Copyright (c) Microsoft Corporation. Licensed under the MIT license.
Code generated by azure-service-operator-codegen. DO NOT EDIT. Copyright (c) Microsoft Corporation. Licensed under the MIT license.
Code generated by azure-service-operator-codegen. DO NOT EDIT. Copyright (c) Microsoft Corporation. Licensed under the MIT license.
Code generated by azure-service-operator-codegen. DO NOT EDIT. Copyright (c) Microsoft Corporation. Licensed under the MIT license.
Code generated by azure-service-operator-codegen. DO NOT EDIT. Copyright (c) Microsoft Corporation. Licensed under the MIT license.
Index ¶
- Constants
- type Action
- type Action_STATUS
- type CorrelationFilter
- type CorrelationFilter_STATUS
- type Encryption
- type Encryption_KeySource
- type Encryption_KeySource_STATUS
- type Encryption_STATUS
- type EntityStatus_STATUS
- type FilterType
- type FilterType_STATUS
- type Identity
- type Identity_STATUS
- type Identity_Type
- type Identity_Type_STATUS
- type KeyVaultProperties
- type KeyVaultProperties_STATUS
- type MessageCountDetails_STATUS
- type Namespace_STATUS
- type Namespace_Spec
- type NamespacesAuthorizationRule_STATUS
- type NamespacesAuthorizationRule_Spec
- type NamespacesQueue_STATUS
- type NamespacesQueue_Spec
- type NamespacesTopic_STATUS
- type NamespacesTopic_Spec
- type NamespacesTopicsSubscription_STATUS
- type NamespacesTopicsSubscription_Spec
- type NamespacesTopicsSubscriptionsRule_STATUS
- type NamespacesTopicsSubscriptionsRule_Spec
- type Namespaces_AuthorizationRule_Properties_Rights_STATUS
- type Namespaces_AuthorizationRule_Properties_Rights_Spec
- type Namespaces_AuthorizationRule_Properties_STATUS
- type Namespaces_AuthorizationRule_Properties_Spec
- type PrivateEndpointConnection_STATUS
- type Ruleproperties
- type Ruleproperties_STATUS
- type SBClientAffineProperties
- type SBClientAffineProperties_STATUS
- type SBNamespaceProperties
- type SBNamespaceProperties_STATUS
- type SBQueueProperties
- type SBQueueProperties_STATUS
- type SBSku
- type SBSku_Name
- type SBSku_Name_STATUS
- type SBSku_STATUS
- type SBSku_Tier
- type SBSku_Tier_STATUS
- type SBSubscriptionProperties
- type SBSubscriptionProperties_STATUS
- type SBTopicProperties
- type SBTopicProperties_STATUS
- type SqlFilter
- type SqlFilter_STATUS
- type SystemData_CreatedByType_STATUS
- type SystemData_LastModifiedByType_STATUS
- type SystemData_STATUS
- type UserAssignedIdentityDetails
- type UserAssignedIdentityProperties
- type UserAssignedIdentityProperties_STATUS
- type UserAssignedIdentity_STATUS
Constants ¶
const ( Identity_Type_None = Identity_Type("None") Identity_Type_SystemAssigned = Identity_Type("SystemAssigned") Identity_Type_SystemAssignedUserAssigned = Identity_Type("SystemAssigned, UserAssigned") Identity_Type_UserAssigned = Identity_Type("UserAssigned") )
const ( SBSku_Name_Basic = SBSku_Name("Basic") SBSku_Name_Premium = SBSku_Name("Premium") SBSku_Name_Standard = SBSku_Name("Standard") )
const ( SBSku_Tier_Basic = SBSku_Tier("Basic") SBSku_Tier_Premium = SBSku_Tier("Premium") SBSku_Tier_Standard = SBSku_Tier("Standard") )
const ( Identity_Type_STATUS_None = Identity_Type_STATUS("None") Identity_Type_STATUS_SystemAssigned = Identity_Type_STATUS("SystemAssigned") Identity_Type_STATUS_SystemAssignedUserAssigned = Identity_Type_STATUS("SystemAssigned, UserAssigned") Identity_Type_STATUS_UserAssigned = Identity_Type_STATUS("UserAssigned") )
const ( SBSku_Name_STATUS_Basic = SBSku_Name_STATUS("Basic") SBSku_Name_STATUS_Premium = SBSku_Name_STATUS("Premium") SBSku_Name_STATUS_Standard = SBSku_Name_STATUS("Standard") )
const ( SBSku_Tier_STATUS_Basic = SBSku_Tier_STATUS("Basic") SBSku_Tier_STATUS_Premium = SBSku_Tier_STATUS("Premium") SBSku_Tier_STATUS_Standard = SBSku_Tier_STATUS("Standard") )
const ( SystemData_CreatedByType_STATUS_Application = SystemData_CreatedByType_STATUS("Application") SystemData_CreatedByType_STATUS_Key = SystemData_CreatedByType_STATUS("Key") SystemData_CreatedByType_STATUS_ManagedIdentity = SystemData_CreatedByType_STATUS("ManagedIdentity") SystemData_CreatedByType_STATUS_User = SystemData_CreatedByType_STATUS("User") )
const ( SystemData_LastModifiedByType_STATUS_Application = SystemData_LastModifiedByType_STATUS("Application") SystemData_LastModifiedByType_STATUS_Key = SystemData_LastModifiedByType_STATUS("Key") SystemData_LastModifiedByType_STATUS_ManagedIdentity = SystemData_LastModifiedByType_STATUS("ManagedIdentity") SystemData_LastModifiedByType_STATUS_User = SystemData_LastModifiedByType_STATUS("User") )
const ( Namespaces_AuthorizationRule_Properties_Rights_Spec_Listen = Namespaces_AuthorizationRule_Properties_Rights_Spec("Listen") Namespaces_AuthorizationRule_Properties_Rights_Spec_Manage = Namespaces_AuthorizationRule_Properties_Rights_Spec("Manage") Namespaces_AuthorizationRule_Properties_Rights_Spec_Send = Namespaces_AuthorizationRule_Properties_Rights_Spec("Send") )
const ( Namespaces_AuthorizationRule_Properties_Rights_STATUS_Listen = Namespaces_AuthorizationRule_Properties_Rights_STATUS("Listen") Namespaces_AuthorizationRule_Properties_Rights_STATUS_Manage = Namespaces_AuthorizationRule_Properties_Rights_STATUS("Manage") Namespaces_AuthorizationRule_Properties_Rights_STATUS_Send = Namespaces_AuthorizationRule_Properties_Rights_STATUS("Send") )
const ( EntityStatus_STATUS_Active = EntityStatus_STATUS("Active") EntityStatus_STATUS_Creating = EntityStatus_STATUS("Creating") EntityStatus_STATUS_Deleting = EntityStatus_STATUS("Deleting") EntityStatus_STATUS_Disabled = EntityStatus_STATUS("Disabled") EntityStatus_STATUS_ReceiveDisabled = EntityStatus_STATUS("ReceiveDisabled") EntityStatus_STATUS_Renaming = EntityStatus_STATUS("Renaming") EntityStatus_STATUS_Restoring = EntityStatus_STATUS("Restoring") EntityStatus_STATUS_SendDisabled = EntityStatus_STATUS("SendDisabled") EntityStatus_STATUS_Unknown = EntityStatus_STATUS("Unknown") )
const ( FilterType_CorrelationFilter = FilterType("CorrelationFilter") FilterType_SqlFilter = FilterType("SqlFilter") )
const ( FilterType_STATUS_CorrelationFilter = FilterType_STATUS("CorrelationFilter") FilterType_STATUS_SqlFilter = FilterType_STATUS("SqlFilter") )
const Encryption_KeySource_MicrosoftKeyVault = Encryption_KeySource("Microsoft.KeyVault")
const Encryption_KeySource_STATUS_MicrosoftKeyVault = Encryption_KeySource_STATUS("Microsoft.KeyVault")
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type Action ¶
type Action struct {
// CompatibilityLevel: This property is reserved for future use. An integer value showing the compatibility level,
// currently hard-coded to 20.
CompatibilityLevel *int `json:"compatibilityLevel,omitempty"`
// RequiresPreprocessing: Value that indicates whether the rule action requires preprocessing.
RequiresPreprocessing *bool `json:"requiresPreprocessing,omitempty"`
// SqlExpression: SQL expression. e.g. MyProperty='ABC'
SqlExpression *string `json:"sqlExpression,omitempty"`
}
Represents the filter actions which are allowed for the transformation of a message that have been matched by a filter expression.
type Action_STATUS ¶
type Action_STATUS struct {
// CompatibilityLevel: This property is reserved for future use. An integer value showing the compatibility level,
// currently hard-coded to 20.
CompatibilityLevel *int `json:"compatibilityLevel,omitempty"`
// RequiresPreprocessing: Value that indicates whether the rule action requires preprocessing.
RequiresPreprocessing *bool `json:"requiresPreprocessing,omitempty"`
// SqlExpression: SQL expression. e.g. MyProperty='ABC'
SqlExpression *string `json:"sqlExpression,omitempty"`
}
Represents the filter actions which are allowed for the transformation of a message that have been matched by a filter expression.
type CorrelationFilter ¶
type CorrelationFilter struct {
// ContentType: Content type of the message.
ContentType *string `json:"contentType,omitempty"`
// CorrelationId: Identifier of the correlation.
CorrelationId *string `json:"correlationId,omitempty"`
// Label: Application specific label.
Label *string `json:"label,omitempty"`
// MessageId: Identifier of the message.
MessageId *string `json:"messageId,omitempty"`
// Properties: dictionary object for custom filters
Properties map[string]string `json:"properties,omitempty"`
// ReplyTo: Address of the queue to reply to.
ReplyTo *string `json:"replyTo,omitempty"`
// ReplyToSessionId: Session identifier to reply to.
ReplyToSessionId *string `json:"replyToSessionId,omitempty"`
// RequiresPreprocessing: Value that indicates whether the rule action requires preprocessing.
RequiresPreprocessing *bool `json:"requiresPreprocessing,omitempty"`
// SessionId: Session identifier.
SessionId *string `json:"sessionId,omitempty"`
// To: Address to send to.
To *string `json:"to,omitempty"`
}
Represents the correlation filter expression.
type CorrelationFilter_STATUS ¶
type CorrelationFilter_STATUS struct {
// ContentType: Content type of the message.
ContentType *string `json:"contentType,omitempty"`
// CorrelationId: Identifier of the correlation.
CorrelationId *string `json:"correlationId,omitempty"`
// Label: Application specific label.
Label *string `json:"label,omitempty"`
// MessageId: Identifier of the message.
MessageId *string `json:"messageId,omitempty"`
// Properties: dictionary object for custom filters
Properties map[string]string `json:"properties,omitempty"`
// ReplyTo: Address of the queue to reply to.
ReplyTo *string `json:"replyTo,omitempty"`
// ReplyToSessionId: Session identifier to reply to.
ReplyToSessionId *string `json:"replyToSessionId,omitempty"`
// RequiresPreprocessing: Value that indicates whether the rule action requires preprocessing.
RequiresPreprocessing *bool `json:"requiresPreprocessing,omitempty"`
// SessionId: Session identifier.
SessionId *string `json:"sessionId,omitempty"`
// To: Address to send to.
To *string `json:"to,omitempty"`
}
Represents the correlation filter expression.
type Encryption ¶
type Encryption struct {
// KeySource: Enumerates the possible value of keySource for Encryption
KeySource *Encryption_KeySource `json:"keySource,omitempty"`
// KeyVaultProperties: Properties of KeyVault
KeyVaultProperties []KeyVaultProperties `json:"keyVaultProperties,omitempty"`
// RequireInfrastructureEncryption: Enable Infrastructure Encryption (Double Encryption)
RequireInfrastructureEncryption *bool `json:"requireInfrastructureEncryption,omitempty"`
}
Properties to configure Encryption
type Encryption_KeySource ¶
type Encryption_KeySource string
+kubebuilder:validation:Enum={"Microsoft.KeyVault"}
type Encryption_KeySource_STATUS ¶
type Encryption_KeySource_STATUS string
type Encryption_STATUS ¶
type Encryption_STATUS struct {
// KeySource: Enumerates the possible value of keySource for Encryption
KeySource *Encryption_KeySource_STATUS `json:"keySource,omitempty"`
// KeyVaultProperties: Properties of KeyVault
KeyVaultProperties []KeyVaultProperties_STATUS `json:"keyVaultProperties,omitempty"`
// RequireInfrastructureEncryption: Enable Infrastructure Encryption (Double Encryption)
RequireInfrastructureEncryption *bool `json:"requireInfrastructureEncryption,omitempty"`
}
Properties to configure Encryption
type FilterType ¶
type FilterType string
Rule filter types +kubebuilder:validation:Enum={"CorrelationFilter","SqlFilter"}
type Identity ¶
type Identity struct {
// Type: Type of managed service identity.
Type *Identity_Type `json:"type,omitempty"`
UserAssignedIdentities map[string]UserAssignedIdentityDetails `json:"userAssignedIdentities,omitempty"`
}
Properties to configure User Assigned Identities for Bring your Own Keys
type Identity_STATUS ¶
type Identity_STATUS struct {
// PrincipalId: ObjectId from the KeyVault
PrincipalId *string `json:"principalId,omitempty"`
// TenantId: TenantId from the KeyVault
TenantId *string `json:"tenantId,omitempty"`
// Type: Type of managed service identity.
Type *Identity_Type_STATUS `json:"type,omitempty"`
// UserAssignedIdentities: Properties for User Assigned Identities
UserAssignedIdentities map[string]UserAssignedIdentity_STATUS `json:"userAssignedIdentities,omitempty"`
}
Properties to configure User Assigned Identities for Bring your Own Keys
type Identity_Type ¶
type Identity_Type string
+kubebuilder:validation:Enum={"None","SystemAssigned","SystemAssigned, UserAssigned","UserAssigned"}
type Identity_Type_STATUS ¶
type Identity_Type_STATUS string
type KeyVaultProperties ¶
type KeyVaultProperties struct {
Identity *UserAssignedIdentityProperties `json:"identity,omitempty"`
// KeyName: Name of the Key from KeyVault
KeyName *string `json:"keyName,omitempty"`
// KeyVaultUri: Uri of KeyVault
KeyVaultUri *string `json:"keyVaultUri,omitempty"`
// KeyVersion: Version of KeyVault
KeyVersion *string `json:"keyVersion,omitempty"`
}
Properties to configure keyVault Properties
type KeyVaultProperties_STATUS ¶
type KeyVaultProperties_STATUS struct {
Identity *UserAssignedIdentityProperties_STATUS `json:"identity,omitempty"`
// KeyName: Name of the Key from KeyVault
KeyName *string `json:"keyName,omitempty"`
// KeyVaultUri: Uri of KeyVault
KeyVaultUri *string `json:"keyVaultUri,omitempty"`
// KeyVersion: Version of KeyVault
KeyVersion *string `json:"keyVersion,omitempty"`
}
Properties to configure keyVault Properties
type MessageCountDetails_STATUS ¶
type MessageCountDetails_STATUS struct {
// ActiveMessageCount: Number of active messages in the queue, topic, or subscription.
ActiveMessageCount *int `json:"activeMessageCount,omitempty"`
// DeadLetterMessageCount: Number of messages that are dead lettered.
DeadLetterMessageCount *int `json:"deadLetterMessageCount,omitempty"`
// ScheduledMessageCount: Number of scheduled messages.
ScheduledMessageCount *int `json:"scheduledMessageCount,omitempty"`
// TransferDeadLetterMessageCount: Number of messages transferred into dead letters.
TransferDeadLetterMessageCount *int `json:"transferDeadLetterMessageCount,omitempty"`
// TransferMessageCount: Number of messages transferred to another queue, topic, or subscription.
TransferMessageCount *int `json:"transferMessageCount,omitempty"`
}
Message Count Details.
type Namespace_STATUS ¶
type Namespace_STATUS struct {
// Id: Resource Id
Id *string `json:"id,omitempty"`
// Identity: Properties of BYOK Identity description
Identity *Identity_STATUS `json:"identity,omitempty"`
// Location: The Geo-location where the resource lives
Location *string `json:"location,omitempty"`
// Name: Resource name
Name *string `json:"name,omitempty"`
// Properties: Properties of the namespace.
Properties *SBNamespaceProperties_STATUS `json:"properties,omitempty"`
// Sku: Properties of SKU
Sku *SBSku_STATUS `json:"sku,omitempty"`
// SystemData: The system meta data relating to this resource.
SystemData *SystemData_STATUS `json:"systemData,omitempty"`
// Tags: Resource tags
Tags map[string]string `json:"tags,omitempty"`
// Type: Resource type
Type *string `json:"type,omitempty"`
}
type Namespace_Spec ¶
type Namespace_Spec struct {
// Identity: Properties of BYOK Identity description
Identity *Identity `json:"identity,omitempty"`
// Location: The Geo-location where the resource lives
Location *string `json:"location,omitempty"`
Name string `json:"name,omitempty"`
// Properties: Properties of the namespace.
Properties *SBNamespaceProperties `json:"properties,omitempty"`
// Sku: Properties of SKU
Sku *SBSku `json:"sku,omitempty"`
// Tags: Resource tags
Tags map[string]string `json:"tags,omitempty"`
}
func (Namespace_Spec) GetAPIVersion ¶
func (namespace Namespace_Spec) GetAPIVersion() string
GetAPIVersion returns the ARM API version of the resource. This is always "2021-11-01"
func (*Namespace_Spec) GetName ¶
func (namespace *Namespace_Spec) GetName() string
GetName returns the Name of the resource
func (*Namespace_Spec) GetType ¶
func (namespace *Namespace_Spec) GetType() string
GetType returns the ARM Type of the resource. This is always "Microsoft.ServiceBus/namespaces"
type NamespacesAuthorizationRule_STATUS ¶
type NamespacesAuthorizationRule_STATUS struct {
// Id: Fully qualified resource ID for the resource. Ex -
// /subscriptions/{subscriptionId}/resourceGroups/{resourceGroupName}/providers/{resourceProviderNamespace}/{resourceType}/{resourceName}
Id *string `json:"id,omitempty"`
// Location: The geo-location where the resource lives
Location *string `json:"location,omitempty"`
// Name: The name of the resource
Name *string `json:"name,omitempty"`
// Properties: AuthorizationRule properties.
Properties *Namespaces_AuthorizationRule_Properties_STATUS `json:"properties,omitempty"`
// SystemData: The system meta data relating to this resource.
SystemData *SystemData_STATUS `json:"systemData,omitempty"`
// Type: The type of the resource. E.g. "Microsoft.EventHub/Namespaces" or "Microsoft.EventHub/Namespaces/EventHubs"
Type *string `json:"type,omitempty"`
}
type NamespacesAuthorizationRule_Spec ¶
type NamespacesAuthorizationRule_Spec struct {
Name string `json:"name,omitempty"`
// Properties: AuthorizationRule properties.
Properties *Namespaces_AuthorizationRule_Properties_Spec `json:"properties,omitempty"`
}
func (NamespacesAuthorizationRule_Spec) GetAPIVersion ¶
func (rule NamespacesAuthorizationRule_Spec) GetAPIVersion() string
GetAPIVersion returns the ARM API version of the resource. This is always "2021-11-01"
func (*NamespacesAuthorizationRule_Spec) GetName ¶
func (rule *NamespacesAuthorizationRule_Spec) GetName() string
GetName returns the Name of the resource
func (*NamespacesAuthorizationRule_Spec) GetType ¶
func (rule *NamespacesAuthorizationRule_Spec) GetType() string
GetType returns the ARM Type of the resource. This is always "Microsoft.ServiceBus/namespaces/AuthorizationRules"
type NamespacesQueue_STATUS ¶
type NamespacesQueue_STATUS struct {
// Id: Fully qualified resource ID for the resource. Ex -
// /subscriptions/{subscriptionId}/resourceGroups/{resourceGroupName}/providers/{resourceProviderNamespace}/{resourceType}/{resourceName}
Id *string `json:"id,omitempty"`
// Location: The geo-location where the resource lives
Location *string `json:"location,omitempty"`
// Name: The name of the resource
Name *string `json:"name,omitempty"`
// Properties: Queue Properties
Properties *SBQueueProperties_STATUS `json:"properties,omitempty"`
// SystemData: The system meta data relating to this resource.
SystemData *SystemData_STATUS `json:"systemData,omitempty"`
// Type: The type of the resource. E.g. "Microsoft.EventHub/Namespaces" or "Microsoft.EventHub/Namespaces/EventHubs"
Type *string `json:"type,omitempty"`
}
type NamespacesQueue_Spec ¶
type NamespacesQueue_Spec struct {
Name string `json:"name,omitempty"`
// Properties: Queue Properties
Properties *SBQueueProperties `json:"properties,omitempty"`
}
func (NamespacesQueue_Spec) GetAPIVersion ¶
func (queue NamespacesQueue_Spec) GetAPIVersion() string
GetAPIVersion returns the ARM API version of the resource. This is always "2021-11-01"
func (*NamespacesQueue_Spec) GetName ¶
func (queue *NamespacesQueue_Spec) GetName() string
GetName returns the Name of the resource
func (*NamespacesQueue_Spec) GetType ¶
func (queue *NamespacesQueue_Spec) GetType() string
GetType returns the ARM Type of the resource. This is always "Microsoft.ServiceBus/namespaces/queues"
type NamespacesTopic_STATUS ¶
type NamespacesTopic_STATUS struct {
// Id: Fully qualified resource ID for the resource. Ex -
// /subscriptions/{subscriptionId}/resourceGroups/{resourceGroupName}/providers/{resourceProviderNamespace}/{resourceType}/{resourceName}
Id *string `json:"id,omitempty"`
// Location: The geo-location where the resource lives
Location *string `json:"location,omitempty"`
// Name: The name of the resource
Name *string `json:"name,omitempty"`
// Properties: Properties of topic resource.
Properties *SBTopicProperties_STATUS `json:"properties,omitempty"`
// SystemData: The system meta data relating to this resource.
SystemData *SystemData_STATUS `json:"systemData,omitempty"`
// Type: The type of the resource. E.g. "Microsoft.EventHub/Namespaces" or "Microsoft.EventHub/Namespaces/EventHubs"
Type *string `json:"type,omitempty"`
}
type NamespacesTopic_Spec ¶
type NamespacesTopic_Spec struct {
Name string `json:"name,omitempty"`
// Properties: Properties of topic resource.
Properties *SBTopicProperties `json:"properties,omitempty"`
}
func (NamespacesTopic_Spec) GetAPIVersion ¶
func (topic NamespacesTopic_Spec) GetAPIVersion() string
GetAPIVersion returns the ARM API version of the resource. This is always "2021-11-01"
func (*NamespacesTopic_Spec) GetName ¶
func (topic *NamespacesTopic_Spec) GetName() string
GetName returns the Name of the resource
func (*NamespacesTopic_Spec) GetType ¶
func (topic *NamespacesTopic_Spec) GetType() string
GetType returns the ARM Type of the resource. This is always "Microsoft.ServiceBus/namespaces/topics"
type NamespacesTopicsSubscription_STATUS ¶
type NamespacesTopicsSubscription_STATUS struct {
// Id: Fully qualified resource ID for the resource. Ex -
// /subscriptions/{subscriptionId}/resourceGroups/{resourceGroupName}/providers/{resourceProviderNamespace}/{resourceType}/{resourceName}
Id *string `json:"id,omitempty"`
// Location: The geo-location where the resource lives
Location *string `json:"location,omitempty"`
// Name: The name of the resource
Name *string `json:"name,omitempty"`
// Properties: Properties of subscriptions resource.
Properties *SBSubscriptionProperties_STATUS `json:"properties,omitempty"`
// SystemData: The system meta data relating to this resource.
SystemData *SystemData_STATUS `json:"systemData,omitempty"`
// Type: The type of the resource. E.g. "Microsoft.EventHub/Namespaces" or "Microsoft.EventHub/Namespaces/EventHubs"
Type *string `json:"type,omitempty"`
}
type NamespacesTopicsSubscription_Spec ¶
type NamespacesTopicsSubscription_Spec struct {
Name string `json:"name,omitempty"`
// Properties: Properties of subscriptions resource.
Properties *SBSubscriptionProperties `json:"properties,omitempty"`
}
func (NamespacesTopicsSubscription_Spec) GetAPIVersion ¶
func (subscription NamespacesTopicsSubscription_Spec) GetAPIVersion() string
GetAPIVersion returns the ARM API version of the resource. This is always "2021-11-01"
func (*NamespacesTopicsSubscription_Spec) GetName ¶
func (subscription *NamespacesTopicsSubscription_Spec) GetName() string
GetName returns the Name of the resource
func (*NamespacesTopicsSubscription_Spec) GetType ¶
func (subscription *NamespacesTopicsSubscription_Spec) GetType() string
GetType returns the ARM Type of the resource. This is always "Microsoft.ServiceBus/namespaces/topics/subscriptions"
type NamespacesTopicsSubscriptionsRule_STATUS ¶
type NamespacesTopicsSubscriptionsRule_STATUS struct {
// Id: Fully qualified resource ID for the resource. Ex -
// /subscriptions/{subscriptionId}/resourceGroups/{resourceGroupName}/providers/{resourceProviderNamespace}/{resourceType}/{resourceName}
Id *string `json:"id,omitempty"`
// Location: The geo-location where the resource lives
Location *string `json:"location,omitempty"`
// Name: The name of the resource
Name *string `json:"name,omitempty"`
// Properties: Properties of Rule resource
Properties *Ruleproperties_STATUS `json:"properties,omitempty"`
// SystemData: The system meta data relating to this resource.
SystemData *SystemData_STATUS `json:"systemData,omitempty"`
// Type: The type of the resource. E.g. "Microsoft.EventHub/Namespaces" or "Microsoft.EventHub/Namespaces/EventHubs"
Type *string `json:"type,omitempty"`
}
type NamespacesTopicsSubscriptionsRule_Spec ¶
type NamespacesTopicsSubscriptionsRule_Spec struct {
Name string `json:"name,omitempty"`
// Properties: Properties of Rule resource
Properties *Ruleproperties `json:"properties,omitempty"`
}
func (NamespacesTopicsSubscriptionsRule_Spec) GetAPIVersion ¶
func (rule NamespacesTopicsSubscriptionsRule_Spec) GetAPIVersion() string
GetAPIVersion returns the ARM API version of the resource. This is always "2021-11-01"
func (*NamespacesTopicsSubscriptionsRule_Spec) GetName ¶
func (rule *NamespacesTopicsSubscriptionsRule_Spec) GetName() string
GetName returns the Name of the resource
func (*NamespacesTopicsSubscriptionsRule_Spec) GetType ¶
func (rule *NamespacesTopicsSubscriptionsRule_Spec) GetType() string
GetType returns the ARM Type of the resource. This is always "Microsoft.ServiceBus/namespaces/topics/subscriptions/rules"
type Namespaces_AuthorizationRule_Properties_Rights_STATUS ¶
type Namespaces_AuthorizationRule_Properties_Rights_STATUS string
type Namespaces_AuthorizationRule_Properties_Rights_Spec ¶
type Namespaces_AuthorizationRule_Properties_Rights_Spec string
+kubebuilder:validation:Enum={"Listen","Manage","Send"}
type Namespaces_AuthorizationRule_Properties_STATUS ¶
type Namespaces_AuthorizationRule_Properties_STATUS struct {
// Rights: The rights associated with the rule.
Rights []Namespaces_AuthorizationRule_Properties_Rights_STATUS `json:"rights,omitempty"`
}
type Namespaces_AuthorizationRule_Properties_Spec ¶
type Namespaces_AuthorizationRule_Properties_Spec struct {
// Rights: The rights associated with the rule.
Rights []Namespaces_AuthorizationRule_Properties_Rights_Spec `json:"rights,omitempty"`
}
type PrivateEndpointConnection_STATUS ¶
type PrivateEndpointConnection_STATUS struct {
// Id: Fully qualified resource ID for the resource. Ex -
// /subscriptions/{subscriptionId}/resourceGroups/{resourceGroupName}/providers/{resourceProviderNamespace}/{resourceType}/{resourceName}
Id *string `json:"id,omitempty"`
}
Properties of the PrivateEndpointConnection.
type Ruleproperties ¶
type Ruleproperties struct {
// Action: Represents the filter actions which are allowed for the transformation of a message that have been matched by a
// filter expression.
Action *Action `json:"action,omitempty"`
// CorrelationFilter: Properties of correlationFilter
CorrelationFilter *CorrelationFilter `json:"correlationFilter,omitempty"`
// FilterType: Filter type that is evaluated against a BrokeredMessage.
FilterType *FilterType `json:"filterType,omitempty"`
// SqlFilter: Properties of sqlFilter
SqlFilter *SqlFilter `json:"sqlFilter,omitempty"`
}
Description of Rule Resource.
type Ruleproperties_STATUS ¶
type Ruleproperties_STATUS struct {
// Action: Represents the filter actions which are allowed for the transformation of a message that have been matched by a
// filter expression.
Action *Action_STATUS `json:"action,omitempty"`
// CorrelationFilter: Properties of correlationFilter
CorrelationFilter *CorrelationFilter_STATUS `json:"correlationFilter,omitempty"`
// FilterType: Filter type that is evaluated against a BrokeredMessage.
FilterType *FilterType_STATUS `json:"filterType,omitempty"`
// SqlFilter: Properties of sqlFilter
SqlFilter *SqlFilter_STATUS `json:"sqlFilter,omitempty"`
}
Description of Rule Resource.
type SBClientAffineProperties ¶
type SBClientAffineProperties struct {
// ClientId: Indicates the Client ID of the application that created the client-affine subscription.
ClientId *string `json:"clientId,omitempty"`
// IsDurable: For client-affine subscriptions, this value indicates whether the subscription is durable or not.
IsDurable *bool `json:"isDurable,omitempty"`
IsShared *bool `json:"isShared,omitempty"`
}
Properties specific to client affine subscriptions.
type SBClientAffineProperties_STATUS ¶
type SBClientAffineProperties_STATUS struct {
// ClientId: Indicates the Client ID of the application that created the client-affine subscription.
ClientId *string `json:"clientId,omitempty"`
// IsDurable: For client-affine subscriptions, this value indicates whether the subscription is durable or not.
IsDurable *bool `json:"isDurable,omitempty"`
IsShared *bool `json:"isShared,omitempty"`
}
Properties specific to client affine subscriptions.
type SBNamespaceProperties ¶
type SBNamespaceProperties struct {
// AlternateName: Alternate name for namespace
AlternateName *string `json:"alternateName,omitempty"`
// DisableLocalAuth: This property disables SAS authentication for the Service Bus namespace.
DisableLocalAuth *bool `json:"disableLocalAuth,omitempty"`
// Encryption: Properties of BYOK Encryption description
Encryption *Encryption `json:"encryption,omitempty"`
// ZoneRedundant: Enabling this property creates a Premium Service Bus Namespace in regions supported availability zones.
ZoneRedundant *bool `json:"zoneRedundant,omitempty"`
}
Properties of the namespace.
type SBNamespaceProperties_STATUS ¶
type SBNamespaceProperties_STATUS struct {
// AlternateName: Alternate name for namespace
AlternateName *string `json:"alternateName,omitempty"`
// CreatedAt: The time the namespace was created
CreatedAt *string `json:"createdAt,omitempty"`
// DisableLocalAuth: This property disables SAS authentication for the Service Bus namespace.
DisableLocalAuth *bool `json:"disableLocalAuth,omitempty"`
// Encryption: Properties of BYOK Encryption description
Encryption *Encryption_STATUS `json:"encryption,omitempty"`
// MetricId: Identifier for Azure Insights metrics
MetricId *string `json:"metricId,omitempty"`
// PrivateEndpointConnections: List of private endpoint connections.
PrivateEndpointConnections []PrivateEndpointConnection_STATUS `json:"privateEndpointConnections,omitempty"`
// ProvisioningState: Provisioning state of the namespace.
ProvisioningState *string `json:"provisioningState,omitempty"`
// ServiceBusEndpoint: Endpoint you can use to perform Service Bus operations.
ServiceBusEndpoint *string `json:"serviceBusEndpoint,omitempty"`
// Status: Status of the namespace.
Status *string `json:"status,omitempty"`
// UpdatedAt: The time the namespace was updated.
UpdatedAt *string `json:"updatedAt,omitempty"`
// ZoneRedundant: Enabling this property creates a Premium Service Bus Namespace in regions supported availability zones.
ZoneRedundant *bool `json:"zoneRedundant,omitempty"`
}
Properties of the namespace.
type SBQueueProperties ¶
type SBQueueProperties struct {
// AutoDeleteOnIdle: ISO 8061 timeSpan idle interval after which the queue is automatically deleted. The minimum duration
// is 5 minutes.
AutoDeleteOnIdle *string `json:"autoDeleteOnIdle,omitempty"`
// DeadLetteringOnMessageExpiration: A value that indicates whether this queue has dead letter support when a message
// expires.
DeadLetteringOnMessageExpiration *bool `json:"deadLetteringOnMessageExpiration,omitempty"`
// DefaultMessageTimeToLive: ISO 8601 default message timespan to live value. This is the duration after which the message
// expires, starting from when the message is sent to Service Bus. This is the default value used when TimeToLive is not
// set on a message itself.
DefaultMessageTimeToLive *string `json:"defaultMessageTimeToLive,omitempty"`
// DuplicateDetectionHistoryTimeWindow: ISO 8601 timeSpan structure that defines the duration of the duplicate detection
// history. The default value is 10 minutes.
DuplicateDetectionHistoryTimeWindow *string `json:"duplicateDetectionHistoryTimeWindow,omitempty"`
// EnableBatchedOperations: Value that indicates whether server-side batched operations are enabled.
EnableBatchedOperations *bool `json:"enableBatchedOperations,omitempty"`
// EnableExpress: A value that indicates whether Express Entities are enabled. An express queue holds a message in memory
// temporarily before writing it to persistent storage.
EnableExpress *bool `json:"enableExpress,omitempty"`
// EnablePartitioning: A value that indicates whether the queue is to be partitioned across multiple message brokers.
EnablePartitioning *bool `json:"enablePartitioning,omitempty"`
// ForwardDeadLetteredMessagesTo: Queue/Topic name to forward the Dead Letter message
ForwardDeadLetteredMessagesTo *string `json:"forwardDeadLetteredMessagesTo,omitempty"`
// ForwardTo: Queue/Topic name to forward the messages
ForwardTo *string `json:"forwardTo,omitempty"`
// LockDuration: ISO 8601 timespan duration of a peek-lock; that is, the amount of time that the message is locked for
// other receivers. The maximum value for LockDuration is 5 minutes; the default value is 1 minute.
LockDuration *string `json:"lockDuration,omitempty"`
// MaxDeliveryCount: The maximum delivery count. A message is automatically deadlettered after this number of deliveries.
// default value is 10.
MaxDeliveryCount *int `json:"maxDeliveryCount,omitempty"`
// MaxMessageSizeInKilobytes: Maximum size (in KB) of the message payload that can be accepted by the queue. This property
// is only used in Premium today and default is 1024.
MaxMessageSizeInKilobytes *int `json:"maxMessageSizeInKilobytes,omitempty"`
// MaxSizeInMegabytes: The maximum size of the queue in megabytes, which is the size of memory allocated for the queue.
// Default is 1024.
MaxSizeInMegabytes *int `json:"maxSizeInMegabytes,omitempty"`
// RequiresDuplicateDetection: A value indicating if this queue requires duplicate detection.
RequiresDuplicateDetection *bool `json:"requiresDuplicateDetection,omitempty"`
// RequiresSession: A value that indicates whether the queue supports the concept of sessions.
RequiresSession *bool `json:"requiresSession,omitempty"`
}
The Queue Properties definition.
type SBQueueProperties_STATUS ¶
type SBQueueProperties_STATUS struct {
// AccessedAt: Last time a message was sent, or the last time there was a receive request to this queue.
AccessedAt *string `json:"accessedAt,omitempty"`
// AutoDeleteOnIdle: ISO 8061 timeSpan idle interval after which the queue is automatically deleted. The minimum duration
// is 5 minutes.
AutoDeleteOnIdle *string `json:"autoDeleteOnIdle,omitempty"`
// CountDetails: Message Count Details.
CountDetails *MessageCountDetails_STATUS `json:"countDetails,omitempty"`
// CreatedAt: The exact time the message was created.
CreatedAt *string `json:"createdAt,omitempty"`
// DeadLetteringOnMessageExpiration: A value that indicates whether this queue has dead letter support when a message
// expires.
DeadLetteringOnMessageExpiration *bool `json:"deadLetteringOnMessageExpiration,omitempty"`
// DefaultMessageTimeToLive: ISO 8601 default message timespan to live value. This is the duration after which the message
// expires, starting from when the message is sent to Service Bus. This is the default value used when TimeToLive is not
// set on a message itself.
DefaultMessageTimeToLive *string `json:"defaultMessageTimeToLive,omitempty"`
// DuplicateDetectionHistoryTimeWindow: ISO 8601 timeSpan structure that defines the duration of the duplicate detection
// history. The default value is 10 minutes.
DuplicateDetectionHistoryTimeWindow *string `json:"duplicateDetectionHistoryTimeWindow,omitempty"`
// EnableBatchedOperations: Value that indicates whether server-side batched operations are enabled.
EnableBatchedOperations *bool `json:"enableBatchedOperations,omitempty"`
// EnableExpress: A value that indicates whether Express Entities are enabled. An express queue holds a message in memory
// temporarily before writing it to persistent storage.
EnableExpress *bool `json:"enableExpress,omitempty"`
// EnablePartitioning: A value that indicates whether the queue is to be partitioned across multiple message brokers.
EnablePartitioning *bool `json:"enablePartitioning,omitempty"`
// ForwardDeadLetteredMessagesTo: Queue/Topic name to forward the Dead Letter message
ForwardDeadLetteredMessagesTo *string `json:"forwardDeadLetteredMessagesTo,omitempty"`
// ForwardTo: Queue/Topic name to forward the messages
ForwardTo *string `json:"forwardTo,omitempty"`
// LockDuration: ISO 8601 timespan duration of a peek-lock; that is, the amount of time that the message is locked for
// other receivers. The maximum value for LockDuration is 5 minutes; the default value is 1 minute.
LockDuration *string `json:"lockDuration,omitempty"`
// MaxDeliveryCount: The maximum delivery count. A message is automatically deadlettered after this number of deliveries.
// default value is 10.
MaxDeliveryCount *int `json:"maxDeliveryCount,omitempty"`
// MaxMessageSizeInKilobytes: Maximum size (in KB) of the message payload that can be accepted by the queue. This property
// is only used in Premium today and default is 1024.
MaxMessageSizeInKilobytes *int `json:"maxMessageSizeInKilobytes,omitempty"`
// MaxSizeInMegabytes: The maximum size of the queue in megabytes, which is the size of memory allocated for the queue.
// Default is 1024.
MaxSizeInMegabytes *int `json:"maxSizeInMegabytes,omitempty"`
// MessageCount: The number of messages in the queue.
MessageCount *int `json:"messageCount,omitempty"`
// RequiresDuplicateDetection: A value indicating if this queue requires duplicate detection.
RequiresDuplicateDetection *bool `json:"requiresDuplicateDetection,omitempty"`
// RequiresSession: A value that indicates whether the queue supports the concept of sessions.
RequiresSession *bool `json:"requiresSession,omitempty"`
// SizeInBytes: The size of the queue, in bytes.
SizeInBytes *int `json:"sizeInBytes,omitempty"`
// Status: Enumerates the possible values for the status of a messaging entity.
Status *EntityStatus_STATUS `json:"status,omitempty"`
// UpdatedAt: The exact time the message was updated.
UpdatedAt *string `json:"updatedAt,omitempty"`
}
The Queue Properties definition.
type SBSku ¶
type SBSku struct {
// Capacity: The specified messaging units for the tier. For Premium tier, capacity are 1,2 and 4.
Capacity *int `json:"capacity,omitempty"`
// Name: Name of this SKU.
Name *SBSku_Name `json:"name,omitempty"`
// Tier: The billing tier of this particular SKU.
Tier *SBSku_Tier `json:"tier,omitempty"`
}
SKU of the namespace.
type SBSku_Name ¶
type SBSku_Name string
+kubebuilder:validation:Enum={"Basic","Premium","Standard"}
type SBSku_Name_STATUS ¶
type SBSku_Name_STATUS string
type SBSku_STATUS ¶
type SBSku_STATUS struct {
// Capacity: The specified messaging units for the tier. For Premium tier, capacity are 1,2 and 4.
Capacity *int `json:"capacity,omitempty"`
// Name: Name of this SKU.
Name *SBSku_Name_STATUS `json:"name,omitempty"`
// Tier: The billing tier of this particular SKU.
Tier *SBSku_Tier_STATUS `json:"tier,omitempty"`
}
SKU of the namespace.
type SBSku_Tier ¶
type SBSku_Tier string
+kubebuilder:validation:Enum={"Basic","Premium","Standard"}
type SBSku_Tier_STATUS ¶
type SBSku_Tier_STATUS string
type SBSubscriptionProperties ¶
type SBSubscriptionProperties struct {
// AutoDeleteOnIdle: ISO 8061 timeSpan idle interval after which the topic is automatically deleted. The minimum duration
// is 5 minutes.
AutoDeleteOnIdle *string `json:"autoDeleteOnIdle,omitempty"`
// ClientAffineProperties: Properties specific to client affine subscriptions.
ClientAffineProperties *SBClientAffineProperties `json:"clientAffineProperties,omitempty"`
// DeadLetteringOnFilterEvaluationExceptions: Value that indicates whether a subscription has dead letter support on filter
// evaluation exceptions.
DeadLetteringOnFilterEvaluationExceptions *bool `json:"deadLetteringOnFilterEvaluationExceptions,omitempty"`
// DeadLetteringOnMessageExpiration: Value that indicates whether a subscription has dead letter support when a message
// expires.
DeadLetteringOnMessageExpiration *bool `json:"deadLetteringOnMessageExpiration,omitempty"`
// DefaultMessageTimeToLive: ISO 8061 Default message timespan to live value. This is the duration after which the message
// expires, starting from when the message is sent to Service Bus. This is the default value used when TimeToLive is not
// set on a message itself.
DefaultMessageTimeToLive *string `json:"defaultMessageTimeToLive,omitempty"`
// DuplicateDetectionHistoryTimeWindow: ISO 8601 timeSpan structure that defines the duration of the duplicate detection
// history. The default value is 10 minutes.
DuplicateDetectionHistoryTimeWindow *string `json:"duplicateDetectionHistoryTimeWindow,omitempty"`
// EnableBatchedOperations: Value that indicates whether server-side batched operations are enabled.
EnableBatchedOperations *bool `json:"enableBatchedOperations,omitempty"`
// ForwardDeadLetteredMessagesTo: Queue/Topic name to forward the Dead Letter message
ForwardDeadLetteredMessagesTo *string `json:"forwardDeadLetteredMessagesTo,omitempty"`
// ForwardTo: Queue/Topic name to forward the messages
ForwardTo *string `json:"forwardTo,omitempty"`
// IsClientAffine: Value that indicates whether the subscription has an affinity to the client id.
IsClientAffine *bool `json:"isClientAffine,omitempty"`
// LockDuration: ISO 8061 lock duration timespan for the subscription. The default value is 1 minute.
LockDuration *string `json:"lockDuration,omitempty"`
// MaxDeliveryCount: Number of maximum deliveries.
MaxDeliveryCount *int `json:"maxDeliveryCount,omitempty"`
// RequiresSession: Value indicating if a subscription supports the concept of sessions.
RequiresSession *bool `json:"requiresSession,omitempty"`
}
Description of Subscription Resource.
type SBSubscriptionProperties_STATUS ¶
type SBSubscriptionProperties_STATUS struct {
// AccessedAt: Last time there was a receive request to this subscription.
AccessedAt *string `json:"accessedAt,omitempty"`
// AutoDeleteOnIdle: ISO 8061 timeSpan idle interval after which the topic is automatically deleted. The minimum duration
// is 5 minutes.
AutoDeleteOnIdle *string `json:"autoDeleteOnIdle,omitempty"`
// ClientAffineProperties: Properties specific to client affine subscriptions.
ClientAffineProperties *SBClientAffineProperties_STATUS `json:"clientAffineProperties,omitempty"`
// CountDetails: Message count details
CountDetails *MessageCountDetails_STATUS `json:"countDetails,omitempty"`
// CreatedAt: Exact time the message was created.
CreatedAt *string `json:"createdAt,omitempty"`
// DeadLetteringOnFilterEvaluationExceptions: Value that indicates whether a subscription has dead letter support on filter
// evaluation exceptions.
DeadLetteringOnFilterEvaluationExceptions *bool `json:"deadLetteringOnFilterEvaluationExceptions,omitempty"`
// DeadLetteringOnMessageExpiration: Value that indicates whether a subscription has dead letter support when a message
// expires.
DeadLetteringOnMessageExpiration *bool `json:"deadLetteringOnMessageExpiration,omitempty"`
// DefaultMessageTimeToLive: ISO 8061 Default message timespan to live value. This is the duration after which the message
// expires, starting from when the message is sent to Service Bus. This is the default value used when TimeToLive is not
// set on a message itself.
DefaultMessageTimeToLive *string `json:"defaultMessageTimeToLive,omitempty"`
// DuplicateDetectionHistoryTimeWindow: ISO 8601 timeSpan structure that defines the duration of the duplicate detection
// history. The default value is 10 minutes.
DuplicateDetectionHistoryTimeWindow *string `json:"duplicateDetectionHistoryTimeWindow,omitempty"`
// EnableBatchedOperations: Value that indicates whether server-side batched operations are enabled.
EnableBatchedOperations *bool `json:"enableBatchedOperations,omitempty"`
// ForwardDeadLetteredMessagesTo: Queue/Topic name to forward the Dead Letter message
ForwardDeadLetteredMessagesTo *string `json:"forwardDeadLetteredMessagesTo,omitempty"`
// ForwardTo: Queue/Topic name to forward the messages
ForwardTo *string `json:"forwardTo,omitempty"`
// IsClientAffine: Value that indicates whether the subscription has an affinity to the client id.
IsClientAffine *bool `json:"isClientAffine,omitempty"`
// LockDuration: ISO 8061 lock duration timespan for the subscription. The default value is 1 minute.
LockDuration *string `json:"lockDuration,omitempty"`
// MaxDeliveryCount: Number of maximum deliveries.
MaxDeliveryCount *int `json:"maxDeliveryCount,omitempty"`
// MessageCount: Number of messages.
MessageCount *int `json:"messageCount,omitempty"`
// RequiresSession: Value indicating if a subscription supports the concept of sessions.
RequiresSession *bool `json:"requiresSession,omitempty"`
// Status: Enumerates the possible values for the status of a messaging entity.
Status *EntityStatus_STATUS `json:"status,omitempty"`
// UpdatedAt: The exact time the message was updated.
UpdatedAt *string `json:"updatedAt,omitempty"`
}
Description of Subscription Resource.
type SBTopicProperties ¶
type SBTopicProperties struct {
// AutoDeleteOnIdle: ISO 8601 timespan idle interval after which the topic is automatically deleted. The minimum duration
// is 5 minutes.
AutoDeleteOnIdle *string `json:"autoDeleteOnIdle,omitempty"`
// DefaultMessageTimeToLive: ISO 8601 Default message timespan to live value. This is the duration after which the message
// expires, starting from when the message is sent to Service Bus. This is the default value used when TimeToLive is not
// set on a message itself.
DefaultMessageTimeToLive *string `json:"defaultMessageTimeToLive,omitempty"`
// DuplicateDetectionHistoryTimeWindow: ISO8601 timespan structure that defines the duration of the duplicate detection
// history. The default value is 10 minutes.
DuplicateDetectionHistoryTimeWindow *string `json:"duplicateDetectionHistoryTimeWindow,omitempty"`
// EnableBatchedOperations: Value that indicates whether server-side batched operations are enabled.
EnableBatchedOperations *bool `json:"enableBatchedOperations,omitempty"`
// EnableExpress: Value that indicates whether Express Entities are enabled. An express topic holds a message in memory
// temporarily before writing it to persistent storage.
EnableExpress *bool `json:"enableExpress,omitempty"`
// EnablePartitioning: Value that indicates whether the topic to be partitioned across multiple message brokers is enabled.
EnablePartitioning *bool `json:"enablePartitioning,omitempty"`
// MaxMessageSizeInKilobytes: Maximum size (in KB) of the message payload that can be accepted by the topic. This property
// is only used in Premium today and default is 1024.
MaxMessageSizeInKilobytes *int `json:"maxMessageSizeInKilobytes,omitempty"`
// MaxSizeInMegabytes: Maximum size of the topic in megabytes, which is the size of the memory allocated for the topic.
// Default is 1024.
MaxSizeInMegabytes *int `json:"maxSizeInMegabytes,omitempty"`
// RequiresDuplicateDetection: Value indicating if this topic requires duplicate detection.
RequiresDuplicateDetection *bool `json:"requiresDuplicateDetection,omitempty"`
// SupportOrdering: Value that indicates whether the topic supports ordering.
SupportOrdering *bool `json:"supportOrdering,omitempty"`
}
The Topic Properties definition.
type SBTopicProperties_STATUS ¶
type SBTopicProperties_STATUS struct {
// AccessedAt: Last time the message was sent, or a request was received, for this topic.
AccessedAt *string `json:"accessedAt,omitempty"`
// AutoDeleteOnIdle: ISO 8601 timespan idle interval after which the topic is automatically deleted. The minimum duration
// is 5 minutes.
AutoDeleteOnIdle *string `json:"autoDeleteOnIdle,omitempty"`
// CountDetails: Message count details
CountDetails *MessageCountDetails_STATUS `json:"countDetails,omitempty"`
// CreatedAt: Exact time the message was created.
CreatedAt *string `json:"createdAt,omitempty"`
// DefaultMessageTimeToLive: ISO 8601 Default message timespan to live value. This is the duration after which the message
// expires, starting from when the message is sent to Service Bus. This is the default value used when TimeToLive is not
// set on a message itself.
DefaultMessageTimeToLive *string `json:"defaultMessageTimeToLive,omitempty"`
// DuplicateDetectionHistoryTimeWindow: ISO8601 timespan structure that defines the duration of the duplicate detection
// history. The default value is 10 minutes.
DuplicateDetectionHistoryTimeWindow *string `json:"duplicateDetectionHistoryTimeWindow,omitempty"`
// EnableBatchedOperations: Value that indicates whether server-side batched operations are enabled.
EnableBatchedOperations *bool `json:"enableBatchedOperations,omitempty"`
// EnableExpress: Value that indicates whether Express Entities are enabled. An express topic holds a message in memory
// temporarily before writing it to persistent storage.
EnableExpress *bool `json:"enableExpress,omitempty"`
// EnablePartitioning: Value that indicates whether the topic to be partitioned across multiple message brokers is enabled.
EnablePartitioning *bool `json:"enablePartitioning,omitempty"`
// MaxMessageSizeInKilobytes: Maximum size (in KB) of the message payload that can be accepted by the topic. This property
// is only used in Premium today and default is 1024.
MaxMessageSizeInKilobytes *int `json:"maxMessageSizeInKilobytes,omitempty"`
// MaxSizeInMegabytes: Maximum size of the topic in megabytes, which is the size of the memory allocated for the topic.
// Default is 1024.
MaxSizeInMegabytes *int `json:"maxSizeInMegabytes,omitempty"`
// RequiresDuplicateDetection: Value indicating if this topic requires duplicate detection.
RequiresDuplicateDetection *bool `json:"requiresDuplicateDetection,omitempty"`
// SizeInBytes: Size of the topic, in bytes.
SizeInBytes *int `json:"sizeInBytes,omitempty"`
// Status: Enumerates the possible values for the status of a messaging entity.
Status *EntityStatus_STATUS `json:"status,omitempty"`
// SubscriptionCount: Number of subscriptions.
SubscriptionCount *int `json:"subscriptionCount,omitempty"`
// SupportOrdering: Value that indicates whether the topic supports ordering.
SupportOrdering *bool `json:"supportOrdering,omitempty"`
// UpdatedAt: The exact time the message was updated.
UpdatedAt *string `json:"updatedAt,omitempty"`
}
The Topic Properties definition.
type SqlFilter ¶
type SqlFilter struct {
// CompatibilityLevel: This property is reserved for future use. An integer value showing the compatibility level,
// currently hard-coded to 20.
CompatibilityLevel *int `json:"compatibilityLevel,omitempty"`
// RequiresPreprocessing: Value that indicates whether the rule action requires preprocessing.
RequiresPreprocessing *bool `json:"requiresPreprocessing,omitempty"`
// SqlExpression: The SQL expression. e.g. MyProperty='ABC'
SqlExpression *string `json:"sqlExpression,omitempty"`
}
Represents a filter which is a composition of an expression and an action that is executed in the pub/sub pipeline.
type SqlFilter_STATUS ¶
type SqlFilter_STATUS struct {
// CompatibilityLevel: This property is reserved for future use. An integer value showing the compatibility level,
// currently hard-coded to 20.
CompatibilityLevel *int `json:"compatibilityLevel,omitempty"`
// RequiresPreprocessing: Value that indicates whether the rule action requires preprocessing.
RequiresPreprocessing *bool `json:"requiresPreprocessing,omitempty"`
// SqlExpression: The SQL expression. e.g. MyProperty='ABC'
SqlExpression *string `json:"sqlExpression,omitempty"`
}
Represents a filter which is a composition of an expression and an action that is executed in the pub/sub pipeline.
type SystemData_CreatedByType_STATUS ¶
type SystemData_CreatedByType_STATUS string
type SystemData_LastModifiedByType_STATUS ¶
type SystemData_LastModifiedByType_STATUS string
type SystemData_STATUS ¶
type SystemData_STATUS struct {
// CreatedAt: The timestamp of resource creation (UTC).
CreatedAt *string `json:"createdAt,omitempty"`
// CreatedBy: The identity that created the resource.
CreatedBy *string `json:"createdBy,omitempty"`
// CreatedByType: The type of identity that created the resource.
CreatedByType *SystemData_CreatedByType_STATUS `json:"createdByType,omitempty"`
// LastModifiedAt: The type of identity that last modified the resource.
LastModifiedAt *string `json:"lastModifiedAt,omitempty"`
// LastModifiedBy: The identity that last modified the resource.
LastModifiedBy *string `json:"lastModifiedBy,omitempty"`
// LastModifiedByType: The type of identity that last modified the resource.
LastModifiedByType *SystemData_LastModifiedByType_STATUS `json:"lastModifiedByType,omitempty"`
}
Metadata pertaining to creation and last modification of the resource.
type UserAssignedIdentityDetails ¶
type UserAssignedIdentityDetails struct {
}
Information about the user assigned identity for the resource
type UserAssignedIdentityProperties ¶
type UserAssignedIdentityProperties struct {
UserAssignedIdentity *string `json:"userAssignedIdentity,omitempty"`
}
type UserAssignedIdentityProperties_STATUS ¶
type UserAssignedIdentityProperties_STATUS struct {
// UserAssignedIdentity: ARM ID of user Identity selected for encryption
UserAssignedIdentity *string `json:"userAssignedIdentity,omitempty"`
}
type UserAssignedIdentity_STATUS ¶
type UserAssignedIdentity_STATUS struct {
// ClientId: Client Id of user assigned identity
ClientId *string `json:"clientId,omitempty"`
// PrincipalId: Principal Id of user assigned identity
PrincipalId *string `json:"principalId,omitempty"`
}
Recognized Dictionary value.
Source Files
¶
- namespace_spec_types_gen.go
- namespace_status_types_gen.go
- namespaces_authorization_rule_spec_types_gen.go
- namespaces_authorization_rule_status_types_gen.go
- namespaces_queue_spec_types_gen.go
- namespaces_queue_status_types_gen.go
- namespaces_topic_spec_types_gen.go
- namespaces_topic_status_types_gen.go
- namespaces_topics_subscription_spec_types_gen.go
- namespaces_topics_subscription_status_types_gen.go
- namespaces_topics_subscriptions_rule_spec_types_gen.go
- namespaces_topics_subscriptions_rule_status_types_gen.go